@@ -29,8 +29,7 @@
 #ifndef AGG_RASTERIZER_CELLS_AA_INCLUDED
 #define AGG_RASTERIZER_CELLS_AA_INCLUDED
 
-#include "CXX/Exception.hxx"
-#include <exception>
+#include <stdexcept>
 #include <string.h>
 #include <math.h>
 #include "agg_math.h"
@@ -183,14 +182,9 @@ namespace agg
         {
             if((m_num_cells & cell_block_mask) == 0)
             {
-                if(m_num_blocks >= cell_block_limit) {
-                    static Py::Exception e(
-                        Py::OverflowError(
-                            "Agg rendering complexity exceeded. Consider downsampling or decimating your data."));
-
-                    /* If this exception is thrown too often, one can
-                       increase cell_block_limit */
-                    throw e;
+                if (m_num_blocks >= cell_block_limit)
+                {
+                    throw std::overflow_error("Allocated too many blocks");
                 }
                 allocate_block();
             }
