@@ -1,21 +1,23 @@
 # For detailed comments on animation and the techniqes used here, see
 # the wiki entry http://www.scipy.org/Cookbook/Matplotlib/Animations
 
+from __future__ import print_function
+
 import matplotlib
 matplotlib.use('TkAgg')
 
 import sys
-import pylab as p
+import matplotlib.pyplot as plt
 import numpy as npy
 import time
 
-ax = p.subplot(111)
-canvas = ax.figure.canvas
+fig, ax = plt.subplots()
+canvas = fig.canvas
 
 
 # create the initial line
 x = npy.arange(0,2*npy.pi,0.01)
-line, = p.plot(x, npy.sin(x), animated=True, lw=2)
+line, = plt.plot(x, npy.sin(x), animated=True, lw=2)
 
 def run(*args):
     background = canvas.copy_from_bbox(ax.bbox)
@@ -34,19 +36,19 @@ def run(*args):
 
         if run.cnt==1000:
             # print the timing info and quit
-            print 'FPS:' , 1000/(time.time()-tstart)
+            print('FPS:', 1000/(time.time()-tstart))
             sys.exit()
 
         run.cnt += 1
 run.cnt = 0
 
 
-p.subplots_adjust(left=0.3, bottom=0.3) # check for flipy bugs
-p.grid() # to ensure proper background restore
-manager = p.get_current_fig_manager()
+plt.subplots_adjust(left=0.3, bottom=0.3) # check for flipy bugs
+plt.grid() # to ensure proper background restore
+manager = plt.get_current_fig_manager()
 manager.window.after(100, run)
 
-p.show()
+plt.show()
 
 
 
