@@ -1,13 +1,12 @@
 import matplotlib.pyplot as plt
 
-
-ax = plt.subplot(111)
+fig, ax = plt.subplots()
 ax.plot([1,2,3], label="test")
 
 l = ax.legend()
 d1 = l.draggable()
 
-xy = 1, 2        
+xy = 1, 2
 txt = ax.annotate("Test", xy, xytext=(-30, 30),
                   textcoords="offset points",
                   bbox=dict(boxstyle="round",fc=(0.2, 1, 1)),
@@ -20,10 +19,10 @@ from matplotlib.cbook import get_sample_data
 
 from matplotlib.offsetbox import OffsetImage, AnnotationBbox
 
-fn = get_sample_data("lena.png", asfileobj=False)
-arr_lena = read_png(fn)
+fn = get_sample_data("ada.png", asfileobj=False)
+arr_ada = read_png(fn)
 
-imagebox = OffsetImage(arr_lena, zoom=0.2)
+imagebox = OffsetImage(arr_ada, zoom=0.2)
 
 ab = AnnotationBbox(imagebox, xy,
                     xybox=(120., -80.),
