@@ -1,12 +1,10 @@
-import numpy as np
 import matplotlib.path as mpath
 import matplotlib.patches as mpatches
 import matplotlib.pyplot as plt
 
 Path = mpath.Path
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 pp1 = mpatches.PathPatch(
     Path([(0, 0), (1, 0), (1, 1), (0, 0)],
          [Path.MOVETO, Path.CURVE3, Path.CURVE3, Path.CLOSEPOLY]),
@@ -16,5 +14,5 @@ ax.add_patch(pp1)
 ax.plot([0.75], [0.25], "ro")
 ax.set_title('The red point should be on the path')
 
-plt.draw()
+plt.show()
 
