@@ -1,23 +1,27 @@
 #!/usr/bin/env python
+
 """
 Show how to connect to keypress events
 """
-import numpy as n
-from pylab import figure, show
+from __future__ import print_function
+import sys
+import numpy as np
+import matplotlib.pyplot as plt
+
 
 def press(event):
-    print 'press', event.key
+    print('press', event.key)
+    sys.stdout.flush()
     if event.key=='x':
         visible = xl.get_visible()
         xl.set_visible(not visible)
         fig.canvas.draw()
 
-fig = figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 
 fig.canvas.mpl_connect('key_press_event', press)
 
-ax.plot(n.random.rand(12), n.random.rand(12), 'go')
+ax.plot(np.random.rand(12), np.random.rand(12), 'go')
 xl = ax.set_xlabel('easy come, easy go')
 
-show()
+plt.show()
