@@ -1,12 +1,13 @@
 """
 Grab mpl data from the ~/.matplotlib/sample_data cache if it exists, else
-fetch it from svn and cache it
+fetch it from github and cache it
 """
+from __future__ import print_function
 import matplotlib.cbook as cbook
 import matplotlib.pyplot as plt
-fname = cbook.get_sample_data('lena.png', asfileobj=False)
+fname = cbook.get_sample_data('ada.png', asfileobj=False)
 
-print 'fname', fname
+print('fname', fname)
 im = plt.imread(fname)
 plt.imshow(im)
 plt.show()
