@@ -7,8 +7,8 @@ import numpy as np
 from matplotlib import cm
 from mpl_toolkits.mplot3d.axes3d import get_test_data
 
-
-fig = plt.figure(figsize=(9.5,5.0))
+# Twice as wide as it is tall.
+fig = plt.figure(figsize=plt.figaspect(0.5))
 
 #---- First subplot
 ax = fig.add_subplot(1, 2, 1, projection='3d')
@@ -17,7 +17,7 @@ Y = np.arange(-5, 5, 0.25)
 X, Y = np.meshgrid(X, Y)
 R = np.sqrt(X**2 + Y**2)
 Z = np.sin(R)
-surf = ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=cm.jet,
+surf = ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=cm.coolwarm,
         linewidth=0, antialiased=False)
 ax.set_zlim3d(-1.01, 1.01)
 
