@@ -10,7 +10,7 @@ s = sin(2*pi*t)
 plot(t, s)
 grid(True)
 
-# matlab style
+# MATLAB style
 xticklines = getp(gca(), 'xticklines')
 yticklines = getp(gca(), 'yticklines')
 xgridlines = getp(gca(), 'xgridlines')
@@ -36,7 +36,7 @@ from pylab import *
 
 t = arange(0.0, 2.0, 0.01)
 s = sin(2*pi*t)
-ax = subplot(111)
+fig, ax = plt.subplots()
 ax.plot(t, s)
 ax.grid(True)
 
