@@ -1,4 +1,4 @@
-import pylab
+import matplotlib.pyplot as plt
 
 DATA = ((1, 3),
         (2, 4),
@@ -15,13 +15,11 @@ dash_style = (
     (1, 20, 30, 60, 10),
     )
 
-fig = pylab.figure()
-ax = fig.add_subplot(111)
-
+fig, ax = plt.subplots()
 
 (x,y) = zip(*DATA)
 ax.plot(x, y, marker='o')
-for i in xrange(len(DATA)):
+for i in range(len(DATA)):
     (x,y) = DATA[i]
     (dd, dl, r, dr, dp) = dash_style[i]
     #print 'dashlen call', dl
@@ -35,7 +33,6 @@ for i in xrange(len(DATA)):
 
 ax.set_xlim((0.0, 5.0))
 ax.set_ylim((0.0, 5.0))
-#if save:
-#    pylab.savefig('dashpointlabel')
-pylab.show()
+
+plt.show()
 
