@@ -14,7 +14,7 @@ This example requires an active internet connection since it uses
 yahoo finance to get the data for plotting
 """
 
-from pylab import figure, show
+import matplotlib.pyplot as plt
 from matplotlib.finance import quotes_historical_yahoo
 from matplotlib.dates import YearLocator, MonthLocator, DateFormatter
 import datetime
@@ -27,14 +27,13 @@ yearsFmt = DateFormatter('%Y')
 
 quotes = quotes_historical_yahoo(
     'INTC', date1, date2)
-if not quotes:
+if len(quotes) == 0:
     raise SystemExit
 
 dates = [q[0] for q in quotes]
 opens = [q[1] for q in quotes]
 
-fig = figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.plot_date(dates, opens, '-')
 
 # format the ticks
@@ -49,4 +48,5 @@ ax.fmt_xdata = DateFormatter('%Y-%m-%d')
 ax.fmt_ydata = price
 ax.grid(True)
 
-show()
+fig.autofmt_xdate()
+plt.show()
