@@ -8,14 +8,15 @@ to simply use the integer index for the xdata and a custom tick
 Formatter to get the appropriate date string for a given index.
 """
 
+from __future__ import print_function
 import numpy
 from matplotlib.mlab import csv2rec
-from pylab import figure, show
+import matplotlib.pyplot as plt
 import matplotlib.cbook as cbook
 from matplotlib.ticker import Formatter
 
 datafile = cbook.get_sample_data('msft.csv', asfileobj=False)
-print 'loading', datafile
+print ('loading %s' % datafile)
 r = csv2rec(datafile)[-40:]
 
 class MyFormatter(Formatter):
@@ -32,9 +33,8 @@ class MyFormatter(Formatter):
 
 formatter = MyFormatter(r.date)
 
-fig = figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.xaxis.set_major_formatter(formatter)
 ax.plot(numpy.arange(len(r)), r.close, 'o-')
 fig.autofmt_xdate()
-show()
+plt.show()
