@@ -1,5 +1,5 @@
 """
-Recursuvely find all objects that match some criteria
+Recursively find all objects that match some criteria
 """
 import numpy as np
 import matplotlib.pyplot as plt
@@ -10,8 +10,7 @@ b = np.arange(0,3,.02)
 c = np.exp(a)
 d = c[::-1]
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 plt.plot(a,c,'k--',a,d,'k:',a,c+d,'k')
 plt.legend(('Model length', 'Data length', 'Total message length'),
            'upper center', shadow=True)
@@ -23,7 +22,7 @@ plt.title('Minimum Message Length')
 
 # match on arbitrary function
 def myfunc(x):
-    return hasattr(x, 'set_color')
+    return hasattr(x, 'set_color') and not hasattr(x, 'set_facecolor')
 
 for o in fig.findobj(myfunc):
     o.set_color('blue')
