@@ -1,13 +1,14 @@
-'''
+"""
 hexbin is an axes method or pyplot function that is essentially
 a pcolor of a 2-D histogram with hexagonal cells.  It can be
 much more informative than a scatter plot; in the first subplot
 below, try substituting 'scatter' for 'hexbin'.
-'''
+"""
 
-from matplotlib.pyplot import *
 import numpy as np
+import matplotlib.pyplot as plt
 
+np.random.seed(0)
 n = 100000
 x = np.random.standard_normal(n)
 y = 2.0 + 3.0 * x + 4.0 * np.random.standard_normal(n)
@@ -16,19 +17,19 @@ xmax = x.max()
 ymin = y.min()
 ymax = y.max()
 
-subplot(121)
-hexbin(x,y)
-axis([xmin, xmax, ymin, ymax])
-title("Hexagon binning")
-cb = colorbar()
+plt.subplots_adjust(hspace=0.5)
+plt.subplot(121)
+plt.hexbin(x,y, cmap=plt.cm.YlOrRd_r)
+plt.axis([xmin, xmax, ymin, ymax])
+plt.title("Hexagon binning")
+cb = plt.colorbar()
 cb.set_label('counts')
 
-subplot(122)
-hexbin(x,y,bins='log')
-axis([xmin, xmax, ymin, ymax])
-title("With a log color scale")
-cb = colorbar()
+plt.subplot(122)
+plt.hexbin(x,y,bins='log', cmap=plt.cm.YlOrRd_r)
+plt.axis([xmin, xmax, ymin, ymax])
+plt.title("With a log color scale")
+cb = plt.colorbar()
 cb.set_label('log10(N)')
 
-show()
-
+plt.show()
