@@ -3,7 +3,7 @@
 You can specify whether images should be plotted with the array origin
 x[0,0] in the upper left or upper right by using the origin parameter.
 You can also control the default be setting image.origin in your
-matplotlibrc file; see http://matplotlib.sourceforge.net/matplotlibrc
+matplotlibrc file; see http://matplotlib.org/matplotlibrc
 """
 from pylab import *
 
@@ -21,5 +21,4 @@ subplot(212, axisbg='y')
 title('blue should be down')
 imshow(x, origin='lower', interpolation=interp)
 #axis(lim)
-savefig('image_origin')
 show()
