@@ -1,5 +1,5 @@
-from matplotlib.pyplot import figure, show
-from numpy import arange, pi, cos, sin, pi
+import matplotlib.pyplot as plt
+from numpy import arange, pi, cos, sin
 from numpy.random import rand
 
 # unit area ellipse
@@ -11,8 +11,7 @@ verts = list(zip(rx/area*cos(theta), ry/area*sin(theta)))
 x,y,s,c = rand(4, 30)
 s*= 10**2.
 
-fig = figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.scatter(x,y,s,c,marker=None,verts =verts)
 
-show()
+plt.show()
