@@ -1,8 +1,11 @@
 #!/usr/bin/env python
+
 """
 Example: simple line plot.
 Show how to make and save a simple line plot with labels, title and grid
 """
+# -*- noplot -*-
+from __future__ import print_function
 from pylab import *
 
 ion()
@@ -16,19 +19,16 @@ ylabel('voltage (mV)')
 title('About as simple as it gets, folks')
 grid(True)
 
-#savefig('simple_plot.png')
-#savefig('simple_plot')
-
 import time
 
 frames = 100.0
 t = time.time()
 c = time.clock()
-for i in xrange(int(frames)):
+for i in range(int(frames)):
     part = i / frames
     axis([0.0, 1.0 - part, -1.0 + part, 1.0 - part])
 wallclock = time.time() - t
 user = time.clock() - c
-print "wallclock:", wallclock
-print "user:", user
-print "fps:", frames / wallclock
+print ("wallclock:", wallclock)
+print ("user:", user)
+print ("fps:", frames / wallclock)
