@@ -1,16 +1,21 @@
 #!/usr/bin/env python
 """
 Use backend agg to access the figure canvas as an RGB string and then
-convert it to a Numeric array and pass the string it to PIL for
+convert it to an array and pass the string it to PIL for
 rendering
 """
 
-from pylab import *
+import pylab
 from matplotlib.backends.backend_agg import FigureCanvasAgg
 
-plot([1,2,3])
+try:
+    from PIL import Image
+except ImportError:
+    raise SystemExit("PIL must be installed to run this example")
 
-canvas = get_current_fig_manager().canvas
+pylab.plot([1,2,3])
+
+canvas = pylab.get_current_fig_manager().canvas
 
 agg = canvas.switch_backends(FigureCanvasAgg)
 agg.draw()
@@ -21,10 +26,11 @@ l,b,w,h = agg.figure.bbox.bounds
 w, h = int(w), int(h)
 
 
-X = fromstring(s, UInt8)
+X = pylab.fromstring(s, pylab.uint8)
 X.shape = h, w, 3
 
-import Image
 im = Image.fromstring( "RGB", (w,h), s)
-im.show()
 
+# Uncomment this line to display the image using ImageMagick's
+# `display` tool.
+# im.show()
