@@ -1,4 +1,6 @@
 #!/usr/bin/env python
+
+from __future__ import print_function, division
 """
 This is used to drive many of the examples across the backends, for
 regression testing, and comparing backend efficiency.
@@ -7,11 +9,10 @@ You can specify the backends to be tested either via the --backends
 switch, which takes a comma-separated list, or as separate arguments,
 e.g.
 
-    python backend_driver.py agg ps cairo.png cairo.ps
+    python backend_driver.py agg ps
 
-would test the agg and ps backends, and the cairo backend with output
-to png and ps files. If no arguments are given, a default list of
-backends will be tested.
+would test the agg and ps backends. If no arguments are given, a
+default list of backends will be tested.
 
 Interspersed with the backend arguments can be switches for the Python
 interpreter executing the tests. If entering such arguments causes an
@@ -19,23 +20,87 @@ option parsing error with the driver script, separate them from driver
 switches with a --.
 """
 
-from __future__ import division
-import os, time, sys, glob, string
+import os
+import time
+import sys
+import glob
 from optparse import OptionParser
+
 import matplotlib.rcsetup as rcsetup
 from matplotlib.cbook import Bunch, dedent
 
+
 all_backends = list(rcsetup.all_backends)  # to leave the original list alone
-all_backends.extend(['cairo.png', 'cairo.ps', 'cairo.pdf', 'cairo.svg'])
 
 # actual physical directory for each dir
-dirs = dict(pylab = os.path.join('..', 'pylab_examples'),
+dirs = dict(files=os.path.join('..', 'lines_bars_and_markers'),
+            shapes=os.path.join('..', 'shapes_and_collections'),
+            images=os.path.join('..', 'images_contours_and_fields'),
+            pie=os.path.join('..', 'pie_and_polar_charts'),
+            text=os.path.join('..', 'text_labels_and_annotations'),
+            ticks=os.path.join('..', 'ticks_and_spines'),
+            subplots=os.path.join('..', 'subplots_axes_and_figures'),
+            specialty=os.path.join('..', 'specialty_plots'),
+            showcase=os.path.join('..', 'showcase'),
+            pylab = os.path.join('..', 'pylab_examples'),
             api = os.path.join('..', 'api'),
             units = os.path.join('..', 'units'),
             mplot3d = os.path.join('..', 'mplot3d'))
 
+
 # files in each dir
 files = dict()
+
+files['lines'] = [
+    'barh_demo.py',
+    'fill_demo.py',
+    'fill_demo_features.py',
+    'line_demo_dash_control.py',
+    ]
+
+files['shapes'] = [
+    'path_patch_demo.py',
+    'scatter_demo.py',
+    ]
+
+files['colors'] = [
+    'color_cycle_demo.py',
+    ]
+
+files['images'] = [
+    'imshow_demo.py',
+    ]
+
+files['statistics'] = [
+    'errorbar_demo.py',
+    'errorbar_demo_features.py',
+    'histogram_demo_features.py',
+    ]
+
+files['pie'] = [
+    'pie_demo.py',
+    'polar_bar_demo.py',
+    'polar_scatter_demo.py',
+    ]
+
+files['text_labels_and_annotations'] = [
+    'text_demo_fontdict.py',
+    'unicode_demo.py',
+    ]
+
+files['ticks_and_spines'] = [
+    'spines_demo_bounds.py',
+    'ticklabels_demo_rotation.py',
+    ]
+
+files['subplots_axes_and_figures'] = [
+    'subplot_demo.py',
+    ]
+
+files['showcase'] = [
+    'integral_demo.py',
+    ]
+
 files['pylab'] = [
     'accented_text.py',
     'alignment_test.py',
@@ -54,7 +119,6 @@ files['pylab'] = [
     'barb_demo.py',
     'barchart_demo.py',
     'barcode_demo.py',
-    'barh_demo.py',
     'boxplot_demo.py',
     'broken_barh.py',
     'clippedline.py',
@@ -75,7 +139,6 @@ files['pylab'] = [
     'custom_figure_class.py',
     'custom_ticker1.py',
     'customize_rc.py',
-    'dash_control.py',
     'dashpointlabel.py',
     'date_demo1.py',
     'date_demo2.py',
@@ -87,7 +150,6 @@ files['pylab'] = [
     'ellipse_demo.py',
     'ellipse_rotated.py',
     'equal_aspect_ratio.py',
-    'errorbar_demo.py',
     'errorbar_limits.py',
     'fancyarrow_demo.py',
     'fancybox_demo.py',
@@ -97,8 +159,6 @@ files['pylab'] = [
     'figlegend_demo.py',
     'figure_title.py',
     'fill_between_demo.py',
-    'fill_demo.py',
-    'fill_demo2.py',
     'fill_spiral.py',
     'finance_demo.py',
     'findobj_demo.py',
@@ -112,20 +172,17 @@ files['pylab'] = [
     'hexbin_demo.py',
     'hexbin_demo2.py',
     'hist_colormapped.py',
-    'histogram_demo.py',
     'histogram_demo_extended.py',
-    'hline_demo.py',
+    'vline_hline_demo.py',
 
     'image_clip_path.py',
     'image_demo.py',
     'image_demo2.py',
-    'image_demo3.py',
     'image_interp.py',
     'image_masked.py',
     'image_nonuniform.py',
     'image_origin.py',
     'image_slices_viewer.py',
-    'integral_demo.py',
     'interp_demo.py',
     'invert_axes.py',
     'layer_images.py',
@@ -156,23 +213,18 @@ files['pylab'] = [
     'nan_test.py',
     'newscalarformatter_demo.py',
     'pcolor_demo.py',
-    'pcolor_demo2.py',
     'pcolor_log.py',
     'pcolor_small.py',
-    'pie_demo.py',
+    'pie_demo2.py',
     'plotfile_demo.py',
-    'polar_bar.py',
     'polar_demo.py',
     'polar_legend.py',
-    'polar_scatter.py',
-    'poormans_contour.py',
     'psd_demo.py',
     'psd_demo2.py',
     'psd_demo3.py',
     'quadmesh_demo.py',
     'quiver_demo.py',
     'scatter_custom_symbol.py',
-    'scatter_demo.py',
     'scatter_demo2.py',
     'scatter_masked.py',
     'scatter_profile.py',
@@ -188,18 +240,13 @@ files['pylab'] = [
     'step_demo.py',
     'stix_fonts_demo.py',
     'stock_demo.py',
-    'subplot_demo.py',
     'subplots_adjust.py',
     'symlog_demo.py',
     'table_demo.py',
     'text_handles.py',
     'text_rotation.py',
     'text_rotation_relative_to_line.py',
-    'text_themes.py',
     'transoffset.py',
-    'unicode_demo.py',
-    'vertical_ticklabels.py',
-    'vline_demo.py',
     'xcorr_demo.py',
     'zorder_demo.py',
     ]
@@ -210,7 +257,6 @@ files['api'] = [
     'barchart_demo.py',
     'bbox_intersect.py',
     'collections_demo.py',
-    'color_cycle.py',
     'colorbar_only.py',
     'custom_projection_example.py',
     'custom_scale_example.py',
@@ -218,7 +264,6 @@ files['api'] = [
     'date_index_formatter.py',
     'donut_demo.py',
     'font_family_rc.py',
-    'histogram_demo.py',
     'image_zcoord.py',
     'joinstyle.py',
     'legend_demo.py',
@@ -226,7 +271,6 @@ files['api'] = [
     'logo2.py',
     'mathtext_asarray.py',
     'patch_collection.py',
-    'path_patch_demo.py',
     'quad_bezier.py',
     'scatter_piecharts.py',
     'span_regions.py',
@@ -285,7 +329,7 @@ def report_missing(dir, flist):
     missing = list(pyfiles-flist-exclude)
     missing.sort()
     if missing:
-        print '%s files not tested: %s'%(dir, ', '.join(missing))
+        print ('%s files not tested: %s'%(dir, ', '.join(missing)))
 
 def report_all_missing(directories):
     for f in directories:
@@ -323,7 +367,7 @@ def drive(backend, directories, python=['python'], switches = []):
     if os.path.exists(path):
         import glob
         for fname in os.listdir(path):
-            os.unlink(os.path.join(path,fname))
+            os.unlink(os.path.join(path, fname))
     else:
         os.mkdir(backend)
     failures = []
@@ -338,34 +382,35 @@ def drive(backend, directories, python=['python'], switches = []):
         fpath, fname = os.path.split(fullpath)
 
         if fname in exclude:
-            print '\tSkipping %s, known to fail on backend: %s'%backend
+            print ('\tSkipping %s, known to fail on backend: %s'%backend)
             continue
 
         basename, ext = os.path.splitext(fname)
-        outfile = os.path.join(path,basename)
+        outfile = os.path.join(path, basename)
         tmpfile_name = '_tmp_%s.py' % basename
-        tmpfile = file(tmpfile_name, 'w')
+        tmpfile = open(tmpfile_name, 'w')
 
-        for line in file(fullpath):
+        future_imports = 'from __future__ import division, print_function'
+        for line in open(fullpath):
             line_lstrip = line.lstrip()
             if line_lstrip.startswith("#"):
                 tmpfile.write(line)
-            else:
-                break
+            elif 'unicode_literals' in line:
+                future_imports = future_imports + ', unicode_literals'
 
         tmpfile.writelines((
-            'from __future__ import division\n',
+            future_imports+'\n',
             'import sys\n',
-            'sys.path.append("%s")\n'%fpath,
+            'sys.path.append("%s")\n' % fpath.replace('\\', '\\\\'),
             'import matplotlib\n',
             'matplotlib.use("%s")\n' % backend,
             'from pylab import savefig\n',
             'import numpy\n',
             'numpy.seterr(invalid="ignore")\n',
             ))
-        for line in file(fullpath):
+        for line in open(fullpath):
             line_lstrip = line.lstrip()
-            if (line_lstrip.startswith('from __future__ import division') or
+            if (line_lstrip.startswith('from __future__ import') or
                 line_lstrip.startswith('matplotlib.use') or
                 line_lstrip.startswith('savefig') or
                 line_lstrip.startswith('show')):
@@ -381,7 +426,7 @@ def drive(backend, directories, python=['python'], switches = []):
         program = [x % {'name': basename} for x in python]
         ret = run(program + [tmpfile_name] + switches)
         end_time = time.time()
-        print (end_time - start_time), ret
+        print ("%s %s" % ((end_time - start_time), ret))
         #os.system('%s %s %s' % (python, tmpfile_name, ' '.join(switches)))
         os.remove(tmpfile_name)
         if ret:
@@ -405,8 +450,7 @@ def parse_options():
                   help=dedent('''
       Run tests only for these backends; comma-separated list of
       one or more of: agg, ps, svg, pdf, template, cairo,
-      cairo.png, cairo.ps, cairo.pdf, cairo.svg. Default is everything
-      except cairo.'''))
+      Default is everything except cairo.'''))
     op.add_option('--clean', action='store_true', dest='clean',
                   help='Remove result directories, run no tests')
     op.add_option('-c', '--coverage', action='store_true', dest='coverage',
@@ -418,7 +462,7 @@ def parse_options():
     switches = [x for x in args if x.startswith('--')]
     backends = [x.lower() for x in args if not x.startswith('--')]
     if options.backends:
-        backends += map(string.lower, options.backends.split(','))
+        backends += [be.lower() for be in options.backends.split(',')]
 
     result = Bunch(
         dirs = options.dirs.split(','),
@@ -430,7 +474,7 @@ def parse_options():
     if 'pylab_examples' in result.dirs:
         result.dirs[result.dirs.index('pylab_examples')] = 'pylab'
     #print result
-    return result
+    return (result)
 
 if __name__ == '__main__':
     times = {}
@@ -443,28 +487,28 @@ if __name__ == '__main__':
         for d in localdirs:
             if d.lower() not in all_backends_set:
                 continue
-            print 'removing %s'%d
+            print ('removing %s'%d)
             for fname in glob.glob(os.path.join(d, '*')):
                 os.remove(fname)
             os.rmdir(d)
         for fname in glob.glob('_tmp*.py'):
             os.remove(fname)
 
-        print 'all clean...'
+        print ('all clean...')
         raise SystemExit
     if options.coverage:
         python = ['coverage.py', '-x']
     elif options.valgrind:
         python = ['valgrind', '--tool=memcheck', '--leak-check=yes',
-                  '--log-file=%(name)s', 'python']
+                  '--log-file=%(name)s', sys.executable]
     elif sys.platform == 'win32':
         python = [sys.executable]
     else:
-        python = ['python']
+        python = [sys.executable]
 
     report_all_missing(options.dirs)
     for backend in options.backends:
-        print 'testing %s %s' % (backend, ' '.join(options.switches))
+        print ('testing %s %s' % (backend, ' '.join(options.switches)))
         t0 = time.time()
         failures[backend] = \
             drive(backend, options.dirs, python, options.switches)
@@ -473,10 +517,10 @@ if __name__ == '__main__':
 
     # print times
     for backend, elapsed in times.items():
-        print 'Backend %s took %1.2f minutes to complete' % (backend, elapsed)
+        print ('Backend %s took %1.2f minutes to complete' % (backend, elapsed))
         failed = failures[backend]
         if failed:
-            print '  Failures: ', failed
+            print ('  Failures: %s' % failed)
         if 'template' in times:
-            print '\ttemplate ratio %1.3f, template residual %1.3f' % (
-                elapsed/times['template'], elapsed-times['template'])
+            print ('\ttemplate ratio %1.3f, template residual %1.3f' % (
+                elapsed/times['template'], elapsed-times['template']))
