@@ -1,10 +1,7 @@
-
-import pylab
+import matplotlib.pyplot as plt
 from basic_units import cm
 
-fig = pylab.figure()
-ax = fig.add_subplot(111)
-
+fig, ax = plt.subplots()
 
 ax.annotate( "Note 01", [0.5*cm,  0.5*cm] )
 
@@ -23,5 +20,5 @@ ax.annotate('local max', xy=(3*cm, 1*cm),  xycoords='data',
 
 ax.set_xlim(0*cm, 4*cm)
 ax.set_ylim(0*cm, 4*cm)
-pylab.show()
+plt.show()
 
