@@ -2,33 +2,44 @@
 Nothing here but dictionaries for generating LinearSegmentedColormaps,
 and a dictionary of these dictionaries.
 
+Documentation for each is in pyplot.colormaps()
 """
 
 from __future__ import print_function, division
 import numpy as np
 
 _binary_data = {
-    'red'  :  ((0., 1., 1.), (1., 0., 0.)),
+    'red':    ((0., 1., 1.), (1., 0., 0.)),
     'green':  ((0., 1., 1.), (1., 0., 0.)),
-    'blue' :  ((0., 1., 1.), (1., 0., 0.))
+    'blue':   ((0., 1., 1.), (1., 0., 0.))
     }
 
-_autumn_data = {'red':   ((0., 1.0, 1.0),(1.0, 1.0, 1.0)),
-                'green': ((0., 0., 0.),(1.0, 1.0, 1.0)),
-                'blue':  ((0., 0., 0.),(1.0, 0., 0.))}
+_autumn_data = {'red':   ((0., 1.0, 1.0), (1.0, 1.0, 1.0)),
+                'green': ((0., 0., 0.), (1.0, 1.0, 1.0)),
+                'blue':  ((0., 0., 0.), (1.0, 0., 0.))}
 
-_bone_data = {'red':   ((0., 0., 0.),(0.746032, 0.652778, 0.652778),(1.0, 1.0, 1.0)),
-              'green': ((0., 0., 0.),(0.365079, 0.319444, 0.319444),
-                        (0.746032, 0.777778, 0.777778),(1.0, 1.0, 1.0)),
-              'blue':  ((0., 0., 0.),(0.365079, 0.444444, 0.444444),(1.0, 1.0, 1.0))}
+_bone_data = {'red':   ((0., 0., 0.),
+                        (0.746032, 0.652778, 0.652778),
+                        (1.0, 1.0, 1.0)),
+              'green': ((0., 0., 0.),
+                        (0.365079, 0.319444, 0.319444),
+                        (0.746032, 0.777778, 0.777778),
+                        (1.0, 1.0, 1.0)),
+              'blue':  ((0., 0., 0.),
+                        (0.365079, 0.444444, 0.444444),
+                        (1.0, 1.0, 1.0))}
 
 _cool_data = {'red':   ((0., 0., 0.), (1.0, 1.0, 1.0)),
               'green': ((0., 1., 1.), (1.0, 0.,  0.)),
               'blue':  ((0., 1., 1.), (1.0, 1.,  1.))}
 
-_copper_data = {'red':   ((0., 0., 0.),(0.809524, 1.000000, 1.000000),(1.0, 1.0, 1.0)),
-                'green': ((0., 0., 0.),(1.0, 0.7812, 0.7812)),
-                'blue':  ((0., 0., 0.),(1.0, 0.4975, 0.4975))}
+_copper_data = {'red':   ((0., 0., 0.),
+                          (0.809524, 1.000000, 1.000000),
+                          (1.0, 1.0, 1.0)),
+                'green': ((0., 0., 0.),
+                          (1.0, 0.7812, 0.7812)),
+                'blue':  ((0., 0., 0.),
+                          (1.0, 0.4975, 0.4975))}
 
 _flag_data = {
         'red': lambda x: 0.75 * np.sin((x * 31.5 + 0.25) * np.pi) + 0.5,
@@ -42,6 +53,7 @@ _prism_data = {
         'blue': lambda x: -1.1 * np.sin((x * 20.9) * np.pi),
 }
 
+
 def cubehelix(gamma=1.0, s=0.5, r=-1.5, h=1.0):
     """Return custom data dictionary of (r,g,b) conversion functions, which
     can be used with :func:`register_cmap`, for the cubehelix color scheme.
@@ -82,9 +94,10 @@ def cubehelix(gamma=1.0, s=0.5, r=-1.5, h=1.0):
     """
 
     def get_color_function(p0, p1):
+
         def color(x):
             # Apply gamma factor to emphasise low or high intensity values
-            xg = x**gamma
+            xg = x ** gamma
 
             # Calculate amplitude and angle of deviation from the black
             # to white diagonal in the plane of constant
@@ -113,15 +126,15 @@ gfunc = {
         1: lambda x: 0.5,
         2: lambda x: 1,
         3: lambda x: x,
-        4: lambda x: x**2,
-        5: lambda x: x**3,
-        6: lambda x: x**4,
+        4: lambda x: x ** 2,
+        5: lambda x: x ** 3,
+        6: lambda x: x ** 4,
         7: lambda x: np.sqrt(x),
         8: lambda x: np.sqrt(np.sqrt(x)),
         9: lambda x: np.sin(x * np.pi / 2),
         10: lambda x: np.cos(x * np.pi / 2),
         11: lambda x: np.abs(x - 0.5),
-        12: lambda x: (2 * x - 1)**2,
+        12: lambda x: (2 * x - 1) ** 2,
         13: lambda x: np.sin(x * np.pi),
         14: lambda x: np.abs(np.cos(x * np.pi)),
         15: lambda x: np.sin(x * 2 * np.pi),
@@ -137,8 +150,8 @@ gfunc = {
         25: lambda x: np.abs(3 * x - 2),
         26: lambda x: (3 * x - 1) / 2,
         27: lambda x: (3 * x - 2) / 2,
-        28: lambda x: np.abs((3 * x  - 1) / 2),
-        29: lambda x: np.abs((3 * x  - 2) / 2),
+        28: lambda x: np.abs((3 * x - 1) / 2),
+        29: lambda x: np.abs((3 * x - 2) / 2),
         30: lambda x: x / 0.32 - 0.78125,
         31: lambda x: 2 * x - 0.84,
         32: lambda x: gfunc32(x),
@@ -148,6 +161,7 @@ gfunc = {
         36: lambda x: 2 * x - 1.
 }
 
+
 def gfunc32(x):
     ret = np.zeros(len(x))
     m = (x < 0.25)
@@ -201,180 +215,289 @@ _terrain_data = (
         (0.75, (0.5, 0.36, 0.33)),
         (1.00, (1.0, 1.0, 1.0)))
 
-_gray_data =  {'red':   ((0., 0, 0), (1., 1, 1)),
-               'green': ((0., 0, 0), (1., 1, 1)),
-               'blue':  ((0., 0, 0), (1., 1, 1))}
+_gray_data = {'red':   ((0., 0, 0), (1., 1, 1)),
+              'green': ((0., 0, 0), (1., 1, 1)),
+              'blue':  ((0., 0, 0), (1., 1, 1))}
 
-_hot_data = {'red':   ((0., 0.0416, 0.0416),(0.365079, 1.000000, 1.000000),(1.0, 1.0, 1.0)),
-             'green': ((0., 0., 0.),(0.365079, 0.000000, 0.000000),
-                       (0.746032, 1.000000, 1.000000),(1.0, 1.0, 1.0)),
-             'blue':  ((0., 0., 0.),(0.746032, 0.000000, 0.000000),(1.0, 1.0, 1.0))}
+_hot_data = {'red':   ((0., 0.0416, 0.0416),
+                       (0.365079, 1.000000, 1.000000),
+                       (1.0, 1.0, 1.0)),
+             'green': ((0., 0., 0.),
+                       (0.365079, 0.000000, 0.000000),
+                       (0.746032, 1.000000, 1.000000),
+                       (1.0, 1.0, 1.0)),
+             'blue':  ((0., 0., 0.),
+                       (0.746032, 0.000000, 0.000000),
+                       (1.0, 1.0, 1.0))}
 
-_hsv_data = {'red':   ((0., 1., 1.),(0.158730, 1.000000, 1.000000),
-                       (0.174603, 0.968750, 0.968750),(0.333333, 0.031250, 0.031250),
-                       (0.349206, 0.000000, 0.000000),(0.666667, 0.000000, 0.000000),
-                       (0.682540, 0.031250, 0.031250),(0.841270, 0.968750, 0.968750),
-                       (0.857143, 1.000000, 1.000000),(1.0, 1.0, 1.0)),
-             'green': ((0., 0., 0.),(0.158730, 0.937500, 0.937500),
-                       (0.174603, 1.000000, 1.000000),(0.507937, 1.000000, 1.000000),
-                       (0.666667, 0.062500, 0.062500),(0.682540, 0.000000, 0.000000),
+_hsv_data = {'red':   ((0., 1., 1.),
+                       (0.158730, 1.000000, 1.000000),
+                       (0.174603, 0.968750, 0.968750),
+                       (0.333333, 0.031250, 0.031250),
+                       (0.349206, 0.000000, 0.000000),
+                       (0.666667, 0.000000, 0.000000),
+                       (0.682540, 0.031250, 0.031250),
+                       (0.841270, 0.968750, 0.968750),
+                       (0.857143, 1.000000, 1.000000),
+                       (1.0, 1.0, 1.0)),
+             'green': ((0., 0., 0.),
+                       (0.158730, 0.937500, 0.937500),
+                       (0.174603, 1.000000, 1.000000),
+                       (0.507937, 1.000000, 1.000000),
+                       (0.666667, 0.062500, 0.062500),
+                       (0.682540, 0.000000, 0.000000),
                        (1.0, 0., 0.)),
-             'blue':  ((0., 0., 0.),(0.333333, 0.000000, 0.000000),
-                       (0.349206, 0.062500, 0.062500),(0.507937, 1.000000, 1.000000),
-                       (0.841270, 1.000000, 1.000000),(0.857143, 0.937500, 0.937500),
+             'blue':  ((0., 0., 0.),
+                       (0.333333, 0.000000, 0.000000),
+                       (0.349206, 0.062500, 0.062500),
+                       (0.507937, 1.000000, 1.000000),
+                       (0.841270, 1.000000, 1.000000),
+                       (0.857143, 0.937500, 0.937500),
                        (1.0, 0.09375, 0.09375))}
 
-_jet_data =   {'red':   ((0., 0, 0), (0.35, 0, 0), (0.66, 1, 1), (0.89,1, 1),
+_jet_data = {'red':   ((0., 0, 0), (0.35, 0, 0), (0.66, 1, 1), (0.89, 1, 1),
                          (1, 0.5, 0.5)),
-               'green': ((0., 0, 0), (0.125,0, 0), (0.375,1, 1), (0.64,1, 1),
-                         (0.91,0,0), (1, 0, 0)),
-               'blue':  ((0., 0.5, 0.5), (0.11, 1, 1), (0.34, 1, 1), (0.65,0, 0),
-                         (1, 0, 0))}
+             'green': ((0., 0, 0), (0.125, 0, 0), (0.375, 1, 1), (0.64, 1, 1),
+                         (0.91, 0, 0), (1, 0, 0)),
+             'blue':  ((0., 0.5, 0.5), (0.11, 1, 1), (0.34, 1, 1),
+                         (0.65, 0, 0), (1, 0, 0))}
 
-_pink_data = {'red':   ((0., 0.1178, 0.1178),(0.015873, 0.195857, 0.195857),
-                        (0.031746, 0.250661, 0.250661),(0.047619, 0.295468, 0.295468),
-                        (0.063492, 0.334324, 0.334324),(0.079365, 0.369112, 0.369112),
-                        (0.095238, 0.400892, 0.400892),(0.111111, 0.430331, 0.430331),
-                        (0.126984, 0.457882, 0.457882),(0.142857, 0.483867, 0.483867),
-                        (0.158730, 0.508525, 0.508525),(0.174603, 0.532042, 0.532042),
-                        (0.190476, 0.554563, 0.554563),(0.206349, 0.576204, 0.576204),
-                        (0.222222, 0.597061, 0.597061),(0.238095, 0.617213, 0.617213),
-                        (0.253968, 0.636729, 0.636729),(0.269841, 0.655663, 0.655663),
-                        (0.285714, 0.674066, 0.674066),(0.301587, 0.691980, 0.691980),
-                        (0.317460, 0.709441, 0.709441),(0.333333, 0.726483, 0.726483),
-                        (0.349206, 0.743134, 0.743134),(0.365079, 0.759421, 0.759421),
-                        (0.380952, 0.766356, 0.766356),(0.396825, 0.773229, 0.773229),
-                        (0.412698, 0.780042, 0.780042),(0.428571, 0.786796, 0.786796),
-                        (0.444444, 0.793492, 0.793492),(0.460317, 0.800132, 0.800132),
-                        (0.476190, 0.806718, 0.806718),(0.492063, 0.813250, 0.813250),
-                        (0.507937, 0.819730, 0.819730),(0.523810, 0.826160, 0.826160),
-                        (0.539683, 0.832539, 0.832539),(0.555556, 0.838870, 0.838870),
-                        (0.571429, 0.845154, 0.845154),(0.587302, 0.851392, 0.851392),
-                        (0.603175, 0.857584, 0.857584),(0.619048, 0.863731, 0.863731),
-                        (0.634921, 0.869835, 0.869835),(0.650794, 0.875897, 0.875897),
-                        (0.666667, 0.881917, 0.881917),(0.682540, 0.887896, 0.887896),
-                        (0.698413, 0.893835, 0.893835),(0.714286, 0.899735, 0.899735),
-                        (0.730159, 0.905597, 0.905597),(0.746032, 0.911421, 0.911421),
-                        (0.761905, 0.917208, 0.917208),(0.777778, 0.922958, 0.922958),
-                        (0.793651, 0.928673, 0.928673),(0.809524, 0.934353, 0.934353),
-                        (0.825397, 0.939999, 0.939999),(0.841270, 0.945611, 0.945611),
-                        (0.857143, 0.951190, 0.951190),(0.873016, 0.956736, 0.956736),
-                        (0.888889, 0.962250, 0.962250),(0.904762, 0.967733, 0.967733),
-                        (0.920635, 0.973185, 0.973185),(0.936508, 0.978607, 0.978607),
-                        (0.952381, 0.983999, 0.983999),(0.968254, 0.989361, 0.989361),
-                        (0.984127, 0.994695, 0.994695),(1.0, 1.0, 1.0)),
-              'green': ((0., 0., 0.),(0.015873, 0.102869, 0.102869),
-                        (0.031746, 0.145479, 0.145479),(0.047619, 0.178174, 0.178174),
-                        (0.063492, 0.205738, 0.205738),(0.079365, 0.230022, 0.230022),
-                        (0.095238, 0.251976, 0.251976),(0.111111, 0.272166, 0.272166),
-                        (0.126984, 0.290957, 0.290957),(0.142857, 0.308607, 0.308607),
-                        (0.158730, 0.325300, 0.325300),(0.174603, 0.341178, 0.341178),
-                        (0.190476, 0.356348, 0.356348),(0.206349, 0.370899, 0.370899),
-                        (0.222222, 0.384900, 0.384900),(0.238095, 0.398410, 0.398410),
-                        (0.253968, 0.411476, 0.411476),(0.269841, 0.424139, 0.424139),
-                        (0.285714, 0.436436, 0.436436),(0.301587, 0.448395, 0.448395),
-                        (0.317460, 0.460044, 0.460044),(0.333333, 0.471405, 0.471405),
-                        (0.349206, 0.482498, 0.482498),(0.365079, 0.493342, 0.493342),
-                        (0.380952, 0.517549, 0.517549),(0.396825, 0.540674, 0.540674),
-                        (0.412698, 0.562849, 0.562849),(0.428571, 0.584183, 0.584183),
-                        (0.444444, 0.604765, 0.604765),(0.460317, 0.624669, 0.624669),
-                        (0.476190, 0.643958, 0.643958),(0.492063, 0.662687, 0.662687),
-                        (0.507937, 0.680900, 0.680900),(0.523810, 0.698638, 0.698638),
-                        (0.539683, 0.715937, 0.715937),(0.555556, 0.732828, 0.732828),
-                        (0.571429, 0.749338, 0.749338),(0.587302, 0.765493, 0.765493),
-                        (0.603175, 0.781313, 0.781313),(0.619048, 0.796819, 0.796819),
-                        (0.634921, 0.812029, 0.812029),(0.650794, 0.826960, 0.826960),
-                        (0.666667, 0.841625, 0.841625),(0.682540, 0.856040, 0.856040),
-                        (0.698413, 0.870216, 0.870216),(0.714286, 0.884164, 0.884164),
-                        (0.730159, 0.897896, 0.897896),(0.746032, 0.911421, 0.911421),
-                        (0.761905, 0.917208, 0.917208),(0.777778, 0.922958, 0.922958),
-                        (0.793651, 0.928673, 0.928673),(0.809524, 0.934353, 0.934353),
-                        (0.825397, 0.939999, 0.939999),(0.841270, 0.945611, 0.945611),
-                        (0.857143, 0.951190, 0.951190),(0.873016, 0.956736, 0.956736),
-                        (0.888889, 0.962250, 0.962250),(0.904762, 0.967733, 0.967733),
-                        (0.920635, 0.973185, 0.973185),(0.936508, 0.978607, 0.978607),
-                        (0.952381, 0.983999, 0.983999),(0.968254, 0.989361, 0.989361),
-                        (0.984127, 0.994695, 0.994695),(1.0, 1.0, 1.0)),
-              'blue':  ((0., 0., 0.),(0.015873, 0.102869, 0.102869),
-                        (0.031746, 0.145479, 0.145479),(0.047619, 0.178174, 0.178174),
-                        (0.063492, 0.205738, 0.205738),(0.079365, 0.230022, 0.230022),
-                        (0.095238, 0.251976, 0.251976),(0.111111, 0.272166, 0.272166),
-                        (0.126984, 0.290957, 0.290957),(0.142857, 0.308607, 0.308607),
-                        (0.158730, 0.325300, 0.325300),(0.174603, 0.341178, 0.341178),
-                        (0.190476, 0.356348, 0.356348),(0.206349, 0.370899, 0.370899),
-                        (0.222222, 0.384900, 0.384900),(0.238095, 0.398410, 0.398410),
-                        (0.253968, 0.411476, 0.411476),(0.269841, 0.424139, 0.424139),
-                        (0.285714, 0.436436, 0.436436),(0.301587, 0.448395, 0.448395),
-                        (0.317460, 0.460044, 0.460044),(0.333333, 0.471405, 0.471405),
-                        (0.349206, 0.482498, 0.482498),(0.365079, 0.493342, 0.493342),
-                        (0.380952, 0.503953, 0.503953),(0.396825, 0.514344, 0.514344),
-                        (0.412698, 0.524531, 0.524531),(0.428571, 0.534522, 0.534522),
-                        (0.444444, 0.544331, 0.544331),(0.460317, 0.553966, 0.553966),
-                        (0.476190, 0.563436, 0.563436),(0.492063, 0.572750, 0.572750),
-                        (0.507937, 0.581914, 0.581914),(0.523810, 0.590937, 0.590937),
-                        (0.539683, 0.599824, 0.599824),(0.555556, 0.608581, 0.608581),
-                        (0.571429, 0.617213, 0.617213),(0.587302, 0.625727, 0.625727),
-                        (0.603175, 0.634126, 0.634126),(0.619048, 0.642416, 0.642416),
-                        (0.634921, 0.650600, 0.650600),(0.650794, 0.658682, 0.658682),
-                        (0.666667, 0.666667, 0.666667),(0.682540, 0.674556, 0.674556),
-                        (0.698413, 0.682355, 0.682355),(0.714286, 0.690066, 0.690066),
-                        (0.730159, 0.697691, 0.697691),(0.746032, 0.705234, 0.705234),
-                        (0.761905, 0.727166, 0.727166),(0.777778, 0.748455, 0.748455),
-                        (0.793651, 0.769156, 0.769156),(0.809524, 0.789314, 0.789314),
-                        (0.825397, 0.808969, 0.808969),(0.841270, 0.828159, 0.828159),
-                        (0.857143, 0.846913, 0.846913),(0.873016, 0.865261, 0.865261),
-                        (0.888889, 0.883229, 0.883229),(0.904762, 0.900837, 0.900837),
-                        (0.920635, 0.918109, 0.918109),(0.936508, 0.935061, 0.935061),
-                        (0.952381, 0.951711, 0.951711),(0.968254, 0.968075, 0.968075),
-                        (0.984127, 0.984167, 0.984167),(1.0, 1.0, 1.0))}
+_pink_data = {'red':   ((0., 0.1178, 0.1178), (0.015873, 0.195857, 0.195857),
+                        (0.031746, 0.250661, 0.250661),
+                        (0.047619, 0.295468, 0.295468),
+                        (0.063492, 0.334324, 0.334324),
+                        (0.079365, 0.369112, 0.369112),
+                        (0.095238, 0.400892, 0.400892),
+                        (0.111111, 0.430331, 0.430331),
+                        (0.126984, 0.457882, 0.457882),
+                        (0.142857, 0.483867, 0.483867),
+                        (0.158730, 0.508525, 0.508525),
+                        (0.174603, 0.532042, 0.532042),
+                        (0.190476, 0.554563, 0.554563),
+                        (0.206349, 0.576204, 0.576204),
+                        (0.222222, 0.597061, 0.597061),
+                        (0.238095, 0.617213, 0.617213),
+                        (0.253968, 0.636729, 0.636729),
+                        (0.269841, 0.655663, 0.655663),
+                        (0.285714, 0.674066, 0.674066),
+                        (0.301587, 0.691980, 0.691980),
+                        (0.317460, 0.709441, 0.709441),
+                        (0.333333, 0.726483, 0.726483),
+                        (0.349206, 0.743134, 0.743134),
+                        (0.365079, 0.759421, 0.759421),
+                        (0.380952, 0.766356, 0.766356),
+                        (0.396825, 0.773229, 0.773229),
+                        (0.412698, 0.780042, 0.780042),
+                        (0.428571, 0.786796, 0.786796),
+                        (0.444444, 0.793492, 0.793492),
+                        (0.460317, 0.800132, 0.800132),
+                        (0.476190, 0.806718, 0.806718),
+                        (0.492063, 0.813250, 0.813250),
+                        (0.507937, 0.819730, 0.819730),
+                        (0.523810, 0.826160, 0.826160),
+                        (0.539683, 0.832539, 0.832539),
+                        (0.555556, 0.838870, 0.838870),
+                        (0.571429, 0.845154, 0.845154),
+                        (0.587302, 0.851392, 0.851392),
+                        (0.603175, 0.857584, 0.857584),
+                        (0.619048, 0.863731, 0.863731),
+                        (0.634921, 0.869835, 0.869835),
+                        (0.650794, 0.875897, 0.875897),
+                        (0.666667, 0.881917, 0.881917),
+                        (0.682540, 0.887896, 0.887896),
+                        (0.698413, 0.893835, 0.893835),
+                        (0.714286, 0.899735, 0.899735),
+                        (0.730159, 0.905597, 0.905597),
+                        (0.746032, 0.911421, 0.911421),
+                        (0.761905, 0.917208, 0.917208),
+                        (0.777778, 0.922958, 0.922958),
+                        (0.793651, 0.928673, 0.928673),
+                        (0.809524, 0.934353, 0.934353),
+                        (0.825397, 0.939999, 0.939999),
+                        (0.841270, 0.945611, 0.945611),
+                        (0.857143, 0.951190, 0.951190),
+                        (0.873016, 0.956736, 0.956736),
+                        (0.888889, 0.962250, 0.962250),
+                        (0.904762, 0.967733, 0.967733),
+                        (0.920635, 0.973185, 0.973185),
+                        (0.936508, 0.978607, 0.978607),
+                        (0.952381, 0.983999, 0.983999),
+                        (0.968254, 0.989361, 0.989361),
+                        (0.984127, 0.994695, 0.994695), (1.0, 1.0, 1.0)),
+              'green': ((0., 0., 0.), (0.015873, 0.102869, 0.102869),
+                        (0.031746, 0.145479, 0.145479),
+                        (0.047619, 0.178174, 0.178174),
+                        (0.063492, 0.205738, 0.205738),
+                        (0.079365, 0.230022, 0.230022),
+                        (0.095238, 0.251976, 0.251976),
+                        (0.111111, 0.272166, 0.272166),
+                        (0.126984, 0.290957, 0.290957),
+                        (0.142857, 0.308607, 0.308607),
+                        (0.158730, 0.325300, 0.325300),
+                        (0.174603, 0.341178, 0.341178),
+                        (0.190476, 0.356348, 0.356348),
+                        (0.206349, 0.370899, 0.370899),
+                        (0.222222, 0.384900, 0.384900),
+                        (0.238095, 0.398410, 0.398410),
+                        (0.253968, 0.411476, 0.411476),
+                        (0.269841, 0.424139, 0.424139),
+                        (0.285714, 0.436436, 0.436436),
+                        (0.301587, 0.448395, 0.448395),
+                        (0.317460, 0.460044, 0.460044),
+                        (0.333333, 0.471405, 0.471405),
+                        (0.349206, 0.482498, 0.482498),
+                        (0.365079, 0.493342, 0.493342),
+                        (0.380952, 0.517549, 0.517549),
+                        (0.396825, 0.540674, 0.540674),
+                        (0.412698, 0.562849, 0.562849),
+                        (0.428571, 0.584183, 0.584183),
+                        (0.444444, 0.604765, 0.604765),
+                        (0.460317, 0.624669, 0.624669),
+                        (0.476190, 0.643958, 0.643958),
+                        (0.492063, 0.662687, 0.662687),
+                        (0.507937, 0.680900, 0.680900),
+                        (0.523810, 0.698638, 0.698638),
+                        (0.539683, 0.715937, 0.715937),
+                        (0.555556, 0.732828, 0.732828),
+                        (0.571429, 0.749338, 0.749338),
+                        (0.587302, 0.765493, 0.765493),
+                        (0.603175, 0.781313, 0.781313),
+                        (0.619048, 0.796819, 0.796819),
+                        (0.634921, 0.812029, 0.812029),
+                        (0.650794, 0.826960, 0.826960),
+                        (0.666667, 0.841625, 0.841625),
+                        (0.682540, 0.856040, 0.856040),
+                        (0.698413, 0.870216, 0.870216),
+                        (0.714286, 0.884164, 0.884164),
+                        (0.730159, 0.897896, 0.897896),
+                        (0.746032, 0.911421, 0.911421),
+                        (0.761905, 0.917208, 0.917208),
+                        (0.777778, 0.922958, 0.922958),
+                        (0.793651, 0.928673, 0.928673),
+                        (0.809524, 0.934353, 0.934353),
+                        (0.825397, 0.939999, 0.939999),
+                        (0.841270, 0.945611, 0.945611),
+                        (0.857143, 0.951190, 0.951190),
+                        (0.873016, 0.956736, 0.956736),
+                        (0.888889, 0.962250, 0.962250),
+                        (0.904762, 0.967733, 0.967733),
+                        (0.920635, 0.973185, 0.973185),
+                        (0.936508, 0.978607, 0.978607),
+                        (0.952381, 0.983999, 0.983999),
+                        (0.968254, 0.989361, 0.989361),
+                        (0.984127, 0.994695, 0.994695), (1.0, 1.0, 1.0)),
+              'blue':  ((0., 0., 0.), (0.015873, 0.102869, 0.102869),
+                        (0.031746, 0.145479, 0.145479),
+                        (0.047619, 0.178174, 0.178174),
+                        (0.063492, 0.205738, 0.205738),
+                        (0.079365, 0.230022, 0.230022),
+                        (0.095238, 0.251976, 0.251976),
+                        (0.111111, 0.272166, 0.272166),
+                        (0.126984, 0.290957, 0.290957),
+                        (0.142857, 0.308607, 0.308607),
+                        (0.158730, 0.325300, 0.325300),
+                        (0.174603, 0.341178, 0.341178),
+                        (0.190476, 0.356348, 0.356348),
+                        (0.206349, 0.370899, 0.370899),
+                        (0.222222, 0.384900, 0.384900),
+                        (0.238095, 0.398410, 0.398410),
+                        (0.253968, 0.411476, 0.411476),
+                        (0.269841, 0.424139, 0.424139),
+                        (0.285714, 0.436436, 0.436436),
+                        (0.301587, 0.448395, 0.448395),
+                        (0.317460, 0.460044, 0.460044),
+                        (0.333333, 0.471405, 0.471405),
+                        (0.349206, 0.482498, 0.482498),
+                        (0.365079, 0.493342, 0.493342),
+                        (0.380952, 0.503953, 0.503953),
+                        (0.396825, 0.514344, 0.514344),
+                        (0.412698, 0.524531, 0.524531),
+                        (0.428571, 0.534522, 0.534522),
+                        (0.444444, 0.544331, 0.544331),
+                        (0.460317, 0.553966, 0.553966),
+                        (0.476190, 0.563436, 0.563436),
+                        (0.492063, 0.572750, 0.572750),
+                        (0.507937, 0.581914, 0.581914),
+                        (0.523810, 0.590937, 0.590937),
+                        (0.539683, 0.599824, 0.599824),
+                        (0.555556, 0.608581, 0.608581),
+                        (0.571429, 0.617213, 0.617213),
+                        (0.587302, 0.625727, 0.625727),
+                        (0.603175, 0.634126, 0.634126),
+                        (0.619048, 0.642416, 0.642416),
+                        (0.634921, 0.650600, 0.650600),
+                        (0.650794, 0.658682, 0.658682),
+                        (0.666667, 0.666667, 0.666667),
+                        (0.682540, 0.674556, 0.674556),
+                        (0.698413, 0.682355, 0.682355),
+                        (0.714286, 0.690066, 0.690066),
+                        (0.730159, 0.697691, 0.697691),
+                        (0.746032, 0.705234, 0.705234),
+                        (0.761905, 0.727166, 0.727166),
+                        (0.777778, 0.748455, 0.748455),
+                        (0.793651, 0.769156, 0.769156),
+                        (0.809524, 0.789314, 0.789314),
+                        (0.825397, 0.808969, 0.808969),
+                        (0.841270, 0.828159, 0.828159),
+                        (0.857143, 0.846913, 0.846913),
+                        (0.873016, 0.865261, 0.865261),
+                        (0.888889, 0.883229, 0.883229),
+                        (0.904762, 0.900837, 0.900837),
+                        (0.920635, 0.918109, 0.918109),
+                        (0.936508, 0.935061, 0.935061),
+                        (0.952381, 0.951711, 0.951711),
+                        (0.968254, 0.968075, 0.968075),
+                        (0.984127, 0.984167, 0.984167), (1.0, 1.0, 1.0))}
 
-_spring_data = {'red':   ((0., 1., 1.),(1.0, 1.0, 1.0)),
-                'green': ((0., 0., 0.),(1.0, 1.0, 1.0)),
-                'blue':  ((0., 1., 1.),(1.0, 0.0, 0.0))}
+_spring_data = {'red':   ((0., 1., 1.), (1.0, 1.0, 1.0)),
+                'green': ((0., 0., 0.), (1.0, 1.0, 1.0)),
+                'blue':  ((0., 1., 1.), (1.0, 0.0, 0.0))}
 
 
-_summer_data = {'red':   ((0., 0., 0.),(1.0, 1.0, 1.0)),
-                'green': ((0., 0.5, 0.5),(1.0, 1.0, 1.0)),
-                'blue':  ((0., 0.4, 0.4),(1.0, 0.4, 0.4))}
+_summer_data = {'red':   ((0., 0., 0.), (1.0, 1.0, 1.0)),
+                'green': ((0., 0.5, 0.5), (1.0, 1.0, 1.0)),
+                'blue':  ((0., 0.4, 0.4), (1.0, 0.4, 0.4))}
 
 
-_winter_data = {'red':   ((0., 0., 0.),(1.0, 0.0, 0.0)),
-                'green': ((0., 0., 0.),(1.0, 1.0, 1.0)),
-                'blue':  ((0., 1., 1.),(1.0, 0.5, 0.5))}
+_winter_data = {'red':   ((0., 0., 0.), (1.0, 0.0, 0.0)),
+                'green': ((0., 0., 0.), (1.0, 1.0, 1.0)),
+                'blue':  ((0., 1., 1.), (1.0, 0.5, 0.5))}
 
-_spectral_data = {'red': [(0.0, 0.0, 0.0), (0.05, 0.4667, 0.4667),
-                          (0.10, 0.5333, 0.5333), (0.15, 0.0, 0.0),
-                          (0.20, 0.0, 0.0), (0.25, 0.0, 0.0),
-                          (0.30, 0.0, 0.0), (0.35, 0.0, 0.0),
-                          (0.40, 0.0, 0.0), (0.45, 0.0, 0.0),
-                          (0.50, 0.0, 0.0), (0.55, 0.0, 0.0),
-                          (0.60, 0.0, 0.0), (0.65, 0.7333, 0.7333),
-                          (0.70, 0.9333, 0.9333), (0.75, 1.0, 1.0),
-                          (0.80, 1.0, 1.0), (0.85, 1.0, 1.0),
-                          (0.90, 0.8667, 0.8667), (0.95, 0.80, 0.80),
-                          (1.0, 0.80, 0.80)],
-                  'green': [(0.0, 0.0, 0.0), (0.05, 0.0, 0.0),
-                            (0.10, 0.0, 0.0), (0.15, 0.0, 0.0),
-                            (0.20, 0.0, 0.0), (0.25, 0.4667, 0.4667),
-                            (0.30, 0.6000, 0.6000), (0.35, 0.6667, 0.6667),
-                            (0.40, 0.6667, 0.6667), (0.45, 0.6000, 0.6000),
-                            (0.50, 0.7333, 0.7333), (0.55, 0.8667, 0.8667),
-                            (0.60, 1.0, 1.0), (0.65, 1.0, 1.0),
-                            (0.70, 0.9333, 0.9333), (0.75, 0.8000, 0.8000),
-                            (0.80, 0.6000, 0.6000), (0.85, 0.0, 0.0),
-                            (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
-                            (1.0, 0.80, 0.80)],
-                  'blue': [(0.0, 0.0, 0.0), (0.05, 0.5333, 0.5333),
-                           (0.10, 0.6000, 0.6000), (0.15, 0.6667, 0.6667),
-                           (0.20, 0.8667, 0.8667), (0.25, 0.8667, 0.8667),
-                           (0.30, 0.8667, 0.8667), (0.35, 0.6667, 0.6667),
-                           (0.40, 0.5333, 0.5333), (0.45, 0.0, 0.0),
-                           (0.5, 0.0, 0.0), (0.55, 0.0, 0.0),
-                           (0.60, 0.0, 0.0), (0.65, 0.0, 0.0),
-                           (0.70, 0.0, 0.0), (0.75, 0.0, 0.0),
-                           (0.80, 0.0, 0.0), (0.85, 0.0, 0.0),
-                           (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
-                           (1.0, 0.80, 0.80)]}
+_nipy_spectral_data = {
+      'red': [(0.0, 0.0, 0.0), (0.05, 0.4667, 0.4667),
+              (0.10, 0.5333, 0.5333), (0.15, 0.0, 0.0),
+              (0.20, 0.0, 0.0), (0.25, 0.0, 0.0),
+              (0.30, 0.0, 0.0), (0.35, 0.0, 0.0),
+              (0.40, 0.0, 0.0), (0.45, 0.0, 0.0),
+              (0.50, 0.0, 0.0), (0.55, 0.0, 0.0),
+              (0.60, 0.0, 0.0), (0.65, 0.7333, 0.7333),
+              (0.70, 0.9333, 0.9333), (0.75, 1.0, 1.0),
+              (0.80, 1.0, 1.0), (0.85, 1.0, 1.0),
+              (0.90, 0.8667, 0.8667), (0.95, 0.80, 0.80),
+              (1.0, 0.80, 0.80)],
+    'green': [(0.0, 0.0, 0.0), (0.05, 0.0, 0.0),
+              (0.10, 0.0, 0.0), (0.15, 0.0, 0.0),
+              (0.20, 0.0, 0.0), (0.25, 0.4667, 0.4667),
+              (0.30, 0.6000, 0.6000), (0.35, 0.6667, 0.6667),
+              (0.40, 0.6667, 0.6667), (0.45, 0.6000, 0.6000),
+              (0.50, 0.7333, 0.7333), (0.55, 0.8667, 0.8667),
+              (0.60, 1.0, 1.0), (0.65, 1.0, 1.0),
+              (0.70, 0.9333, 0.9333), (0.75, 0.8000, 0.8000),
+              (0.80, 0.6000, 0.6000), (0.85, 0.0, 0.0),
+              (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
+              (1.0, 0.80, 0.80)],
+     'blue': [(0.0, 0.0, 0.0), (0.05, 0.5333, 0.5333),
+              (0.10, 0.6000, 0.6000), (0.15, 0.6667, 0.6667),
+              (0.20, 0.8667, 0.8667), (0.25, 0.8667, 0.8667),
+              (0.30, 0.8667, 0.8667), (0.35, 0.6667, 0.6667),
+              (0.40, 0.5333, 0.5333), (0.45, 0.0, 0.0),
+              (0.5, 0.0, 0.0), (0.55, 0.0, 0.0),
+              (0.60, 0.0, 0.0), (0.65, 0.0, 0.0),
+              (0.70, 0.0, 0.0), (0.75, 0.0, 0.0),
+              (0.80, 0.0, 0.0), (0.85, 0.0, 0.0),
+              (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
+              (1.0, 0.80, 0.80)],
+}
 
 
 # 34 colormaps based on color specifications and designs
@@ -1610,7 +1733,7 @@ _gist_rainbow_data = (
 _gist_stern_data = {
         'red': (
             (0.000, 0.000, 0.000), (0.0547, 1.000, 1.000),
-            (0.250, 0.027, 0.250), #(0.2500, 0.250, 0.250),
+            (0.250, 0.027, 0.250),  # (0.2500, 0.250, 0.250),
             (1.000, 1.000, 1.000)),
         'green': ((0, 0, 0), (1, 1, 1)),
         'blue': (
@@ -1733,35 +1856,36 @@ _coolwarm_data = {
     }
 
 # Implementation of Carey Rappaport's CMRmap.
-# See `A Color Map for Effective Black-and-White Rendering of Color-Scale Images' by Carey Rappaport
+# See `A Color Map for Effective Black-and-White Rendering of Color-Scale
+# Images' by Carey Rappaport
 # http://www.mathworks.com/matlabcentral/fileexchange/2662-cmrmap-m
-_CMRmap_data = {'red'   : ( (0.000, 0.00, 0.00),
-                            (0.125, 0.15, 0.15),
-                            (0.250, 0.30, 0.30),
-                            (0.375, 0.60, 0.60),
-                            (0.500, 1.00, 1.00),
-                            (0.625, 0.90, 0.90),
-                            (0.750, 0.90, 0.90),
-                            (0.875, 0.90, 0.90),
-                            (1.000, 1.00, 1.00) ),
-                'green' : ( (0.000, 0.00, 0.00),
-                            (0.125, 0.15, 0.15),
-                            (0.250, 0.15, 0.15),
-                            (0.375, 0.20, 0.20),
-                            (0.500, 0.25, 0.25),
-                            (0.625, 0.50, 0.50),
-                            (0.750, 0.75, 0.75),
-                            (0.875, 0.90, 0.90),
-                            (1.000, 1.00, 1.00) ),
-                'blue':   ( (0.000, 0.00, 0.00),
-                            (0.125, 0.50, 0.50),
-                            (0.250, 0.75, 0.75),
-                            (0.375, 0.50, 0.50),
-                            (0.500, 0.15, 0.15),
-                            (0.625, 0.00, 0.00),
-                            (0.750, 0.10, 0.10),
-                            (0.875, 0.50, 0.50),
-                            (1.000, 1.00, 1.00) )}
+_CMRmap_data = {'red':     ((0.000, 0.00, 0.00),
+                           (0.125, 0.15, 0.15),
+                           (0.250, 0.30, 0.30),
+                           (0.375, 0.60, 0.60),
+                           (0.500, 1.00, 1.00),
+                           (0.625, 0.90, 0.90),
+                           (0.750, 0.90, 0.90),
+                           (0.875, 0.90, 0.90),
+                           (1.000, 1.00, 1.00)),
+                'green':  ((0.000, 0.00, 0.00),
+                           (0.125, 0.15, 0.15),
+                           (0.250, 0.15, 0.15),
+                           (0.375, 0.20, 0.20),
+                           (0.500, 0.25, 0.25),
+                           (0.625, 0.50, 0.50),
+                           (0.750, 0.75, 0.75),
+                           (0.875, 0.90, 0.90),
+                           (1.000, 1.00, 1.00)),
+                'blue':   ((0.000, 0.00, 0.00),
+                           (0.125, 0.50, 0.50),
+                           (0.250, 0.75, 0.75),
+                           (0.375, 0.50, 0.50),
+                           (0.500, 0.15, 0.15),
+                           (0.625, 0.00, 0.00),
+                           (0.750, 0.10, 0.10),
+                           (0.875, 0.50, 0.50),
+                           (1.000, 1.00, 1.00))}
 
 datad = {
     'afmhot': _afmhot_data,
@@ -1777,10 +1901,10 @@ datad = {
     'flag':   _flag_data,
     'gnuplot': _gnuplot_data,
     'gnuplot2': _gnuplot2_data,
-    'gray' :  _gray_data,
+    'gray':  _gray_data,
     'hot':    _hot_data,
     'hsv':    _hsv_data,
-    'jet' :   _jet_data,
+    'jet':   _jet_data,
     'ocean':  _ocean_data,
     'pink':   _pink_data,
     'prism':  _prism_data,
@@ -1790,50 +1914,51 @@ datad = {
     'summer': _summer_data,
     'terrain': _terrain_data,
     'winter': _winter_data,
-    'spectral': _spectral_data
+    'nipy_spectral': _nipy_spectral_data,
+    'spectral': _nipy_spectral_data, # alias for backward compatibility
     }
 
 
-datad['Accent']=_Accent_data
-datad['Blues']=_Blues_data
-datad['BrBG']=_BrBG_data
-datad['BuGn']=_BuGn_data
-datad['BuPu']=_BuPu_data
-datad['Dark2']=_Dark2_data
-datad['GnBu']=_GnBu_data
-datad['Greens']=_Greens_data
-datad['Greys']=_Greys_data
-datad['Oranges']=_Oranges_data
-datad['OrRd']=_OrRd_data
-datad['Paired']=_Paired_data
-datad['Pastel1']=_Pastel1_data
-datad['Pastel2']=_Pastel2_data
-datad['PiYG']=_PiYG_data
-datad['PRGn']=_PRGn_data
-datad['PuBu']=_PuBu_data
-datad['PuBuGn']=_PuBuGn_data
-datad['PuOr']=_PuOr_data
-datad['PuRd']=_PuRd_data
-datad['Purples']=_Purples_data
-datad['RdBu']=_RdBu_data
-datad['RdGy']=_RdGy_data
-datad['RdPu']=_RdPu_data
-datad['RdYlBu']=_RdYlBu_data
-datad['RdYlGn']=_RdYlGn_data
-datad['Reds']=_Reds_data
-datad['Set1']=_Set1_data
-datad['Set2']=_Set2_data
-datad['Set3']=_Set3_data
-datad['Spectral']=_Spectral_data
-datad['YlGn']=_YlGn_data
-datad['YlGnBu']=_YlGnBu_data
-datad['YlOrBr']=_YlOrBr_data
-datad['YlOrRd']=_YlOrRd_data
-datad['gist_earth']=_gist_earth_data
-datad['gist_gray']=_gist_gray_data
-datad['gist_heat']=_gist_heat_data
-datad['gist_ncar']=_gist_ncar_data
-datad['gist_rainbow']=_gist_rainbow_data
-datad['gist_stern']=_gist_stern_data
-datad['gist_yarg']=_gist_yarg_data
-datad['coolwarm']=_coolwarm_data
+datad['Accent'] = _Accent_data
+datad['Blues'] = _Blues_data
+datad['BrBG'] = _BrBG_data
+datad['BuGn'] = _BuGn_data
+datad['BuPu'] = _BuPu_data
+datad['Dark2'] = _Dark2_data
+datad['GnBu'] = _GnBu_data
+datad['Greens'] = _Greens_data
+datad['Greys'] = _Greys_data
+datad['Oranges'] = _Oranges_data
+datad['OrRd'] = _OrRd_data
+datad['Paired'] = _Paired_data
+datad['Pastel1'] = _Pastel1_data
+datad['Pastel2'] = _Pastel2_data
+datad['PiYG'] = _PiYG_data
+datad['PRGn'] = _PRGn_data
+datad['PuBu'] = _PuBu_data
+datad['PuBuGn'] = _PuBuGn_data
+datad['PuOr'] = _PuOr_data
+datad['PuRd'] = _PuRd_data
+datad['Purples'] = _Purples_data
+datad['RdBu'] = _RdBu_data
+datad['RdGy'] = _RdGy_data
+datad['RdPu'] = _RdPu_data
+datad['RdYlBu'] = _RdYlBu_data
+datad['RdYlGn'] = _RdYlGn_data
+datad['Reds'] = _Reds_data
+datad['Set1'] = _Set1_data
+datad['Set2'] = _Set2_data
+datad['Set3'] = _Set3_data
+datad['Spectral'] = _Spectral_data
+datad['YlGn'] = _YlGn_data
+datad['YlGnBu'] = _YlGnBu_data
+datad['YlOrBr'] = _YlOrBr_data
+datad['YlOrRd'] = _YlOrRd_data
+datad['gist_earth'] = _gist_earth_data
+datad['gist_gray'] = _gist_gray_data
+datad['gist_heat'] = _gist_heat_data
+datad['gist_ncar'] = _gist_ncar_data
+datad['gist_rainbow'] = _gist_rainbow_data
+datad['gist_stern'] = _gist_stern_data
+datad['gist_yarg'] = _gist_yarg_data
+datad['coolwarm'] = _coolwarm_data
