@@ -1,19 +1,19 @@
 """
 Manage figures for pyplot interface.
 """
+from __future__ import print_function
 
 import sys, gc
 
 import atexit
-import traceback
 
 
 def error_msg(msg):
-    print >>sys.stderr, msg
+    print(msg, file=sys.stderr)
 
 class Gcf(object):
     """
-    Manage a set of integer-numbered figures.
+    Singleton to manage a set of integer-numbered figures.
 
     This class is never instantiated; it consists of two class
     attributes (a list and a dictionary), and a set of static
@@ -71,15 +71,23 @@ class Gcf(object):
     @staticmethod
     def destroy_fig(fig):
         "*fig* is a Figure instance"
-        for manager in Gcf.figs.values():
+        num = None
+        for manager in Gcf.figs.itervalues():
             if manager.canvas.figure == fig:
-                Gcf.destroy(manager.num)
+                num = manager.num
+                break
+        if num is not None:
+            Gcf.destroy(num)
 
     @staticmethod
     def destroy_all():
         for manager in Gcf.figs.values():
-            Gcf.destroy(manager.num)
+            manager.canvas.mpl_disconnect(manager._cidgcf)
+            manager.destroy()
 
+        Gcf._activeQue = []
+        Gcf.figs.clear()
+        gc.collect()
 
     @staticmethod
     def has_fignum(num):
@@ -123,6 +131,7 @@ class Gcf(object):
         Gcf._activeQue.append(manager)
         Gcf.figs[manager.num] = manager
 
+
 atexit.register(Gcf.destroy_all)
 
 
