@@ -1,4 +1,4 @@
-
+from __future__ import print_function
 import matplotlib
 import inspect
 import warnings
@@ -21,8 +21,11 @@ def pylab_setup():
         backend_name = 'backend_'+backend
         backend_name = backend_name.lower() # until we banish mixed case
         backend_name = 'matplotlib.backends.%s'%backend_name.lower()
+
+    # the last argument is specifies whether to use absolute or relative
+    # imports. 0 means only perform absolute imports.
     backend_mod = __import__(backend_name,
-                             globals(),locals(),[backend_name])
+                             globals(),locals(),[backend_name],0)
 
     # Things we pull in from all backends
     new_figure_manager = backend_mod.new_figure_manager
@@ -52,6 +55,6 @@ or with matplotlib.use()""" %
 
     matplotlib.verbose.report('backend %s version %s' % (backend,backend_version))
 
-    return new_figure_manager, draw_if_interactive, show
+    return backend_mod, new_figure_manager, draw_if_interactive, show
 
 
