@@ -16,12 +16,11 @@ Features that are implemented
 
 TODO:
 
-  * allow save to file handle
-
   * integrate screen dpi w/ ppi and text
+
 """
 from __future__ import division
-
+import threading
 import numpy as np
 
 from matplotlib import verbose, rcParams
@@ -30,27 +29,53 @@ from matplotlib.backend_bases import RendererBase,\
 from matplotlib.cbook import is_string_like, maxdict
 from matplotlib.figure import Figure
 from matplotlib.font_manager import findfont
-from matplotlib.ft2font import FT2Font, LOAD_FORCE_AUTOHINT, LOAD_NO_HINTING
+from matplotlib.ft2font import FT2Font, LOAD_FORCE_AUTOHINT, LOAD_NO_HINTING, \
+     LOAD_DEFAULT, LOAD_NO_AUTOHINT
 from matplotlib.mathtext import MathTextParser
 from matplotlib.path import Path
 from matplotlib.transforms import Bbox, BboxBase
 
-from _backend_agg import RendererAgg as _RendererAgg
+from matplotlib.backends._backend_agg import RendererAgg as _RendererAgg
 from matplotlib import _png
 
 backend_version = 'v2.2'
 
+def get_hinting_flag():
+    mapping = {
+        True: LOAD_FORCE_AUTOHINT,
+        False: LOAD_NO_HINTING,
+        'either': LOAD_DEFAULT,
+        'native': LOAD_NO_AUTOHINT,
+        'auto': LOAD_FORCE_AUTOHINT,
+        'none': LOAD_NO_HINTING
+        }
+    return mapping[rcParams['text.hinting']]
+
+
 class RendererAgg(RendererBase):
     """
     The renderer handles all the drawing primitives using a graphics
     context instance that controls the colors/styles
     """
     debug=1
+
+    # we want to cache the fonts at the class level so that when
+    # multiple figures are created we can reuse them.  This helps with
+    # a bug on windows where the creation of too many figures leads to
+    # too many open file handles.  However, storing them at the class
+    # level is not thread safe.  The solution here is to let the
+    # FigureCanvas acquire a lock on the fontd at the start of the
+    # draw, and release it when it is done.  This allows multiple
+    # renderers to share the cached fonts, but only one figure can
+    # draw at at time and so the font cache is used by only one
+    # renderer at a time
+
+    lock = threading.RLock()
+    _fontd = maxdict(50)
     def __init__(self, width, height, dpi):
         if __debug__: verbose.report('RendererAgg.__init__', 'debug-annoying')
         RendererBase.__init__(self)
         self.texd = maxdict(50)  # a cache of tex image rasters
-        self._fontd = maxdict(50)
 
         self.dpi = dpi
         self.width = width
@@ -82,7 +107,7 @@ class RendererAgg(RendererBase):
 
     def draw_path_collection(self, *kl, **kw):
         return self._renderer.draw_path_collection(*kl, **kw)
-        
+
     def _update_methods(self):
         #self.draw_path = self._renderer.draw_path  # see below
         #self.draw_markers = self._renderer.draw_markers
@@ -128,11 +153,13 @@ class RendererAgg(RendererBase):
         ox, oy, width, height, descent, font_image, used_characters = \
             self.mathtext_parser.parse(s, self.dpi, prop)
 
-        x = int(x) + ox
-        y = int(y) - oy
+        xd = descent * np.sin(np.deg2rad(angle))
+        yd = descent * np.cos(np.deg2rad(angle))
+        x = np.round(x + ox + xd)
+        y = np.round(y - oy + yd)
         self._renderer.draw_text_image(font_image, x, y + 1, angle, gc)
 
-    def draw_text(self, gc, x, y, s, prop, angle, ismath):
+    def draw_text(self, gc, x, y, s, prop, angle, ismath=False, mtext=None):
         """
         Render the text
         """
@@ -141,7 +168,7 @@ class RendererAgg(RendererBase):
         if ismath:
             return self.draw_mathtext(gc, x, y, s, prop, angle)
 
-        flags = self._get_hinting_flag()
+        flags = get_hinting_flag()
         font = self._get_agg_font(prop)
         if font is None: return None
         if len(s) == 1 and ord(s) > 127:
@@ -150,11 +177,15 @@ class RendererAgg(RendererBase):
             # We pass '0' for angle here, since it will be rotated (in raster
             # space) in the following call to draw_text_image).
             font.set_text(s, 0, flags=flags)
-        font.draw_glyphs_to_bitmap()
+        font.draw_glyphs_to_bitmap(antialiased=rcParams['text.antialiased'])
+        d = font.get_descent() / 64.0
+        # The descent needs to be adjusted for the angle
+        xd = -d * np.sin(np.deg2rad(angle))
+        yd = d * np.cos(np.deg2rad(angle))
 
         #print x, y, int(x), int(y), s
-
-        self._renderer.draw_text_image(font.get_image(), int(x), int(y) + 1, angle, gc)
+        self._renderer.draw_text_image(
+            font.get_image(), np.round(x - xd), np.round(y + yd) + 1, angle, gc)
 
     def get_text_width_height_descent(self, s, prop, ismath):
         """
@@ -179,7 +210,7 @@ class RendererAgg(RendererBase):
                 self.mathtext_parser.parse(s, self.dpi, prop)
             return width, height, descent
 
-        flags = self._get_hinting_flag()
+        flags = get_hinting_flag()
         font = self._get_agg_font(prop)
         font.set_text(s, 0.0, flags=flags)  # the width and height of unrotated string
         w, h = font.get_width_height()
@@ -190,7 +221,7 @@ class RendererAgg(RendererBase):
         return w, h, d
 
 
-    def draw_tex(self, gc, x, y, s, prop, angle):
+    def draw_tex(self, gc, x, y, s, prop, angle, ismath='TeX!', mtext=None):
         # todo, handle props, angle, origins
         size = prop.get_size_in_points()
 
@@ -201,6 +232,12 @@ class RendererAgg(RendererBase):
             Z = texmanager.get_grey(s, size, self.dpi)
             Z = np.array(Z * 255.0, np.uint8)
 
+        w, h, d = self.get_text_width_height_descent(s, prop, ismath)
+        xd = d * np.sin(np.deg2rad(angle))
+        yd = d * np.cos(np.deg2rad(angle))
+        x = np.round(x + xd)
+        y = np.round(y + yd)
+
         self._renderer.draw_text_image(Z, x, y, angle, gc)
 
     def get_canvas_width_height(self):
@@ -215,15 +252,17 @@ class RendererAgg(RendererBase):
                                      'debug-annoying')
 
         key = hash(prop)
-        font = self._fontd.get(key)
+        font = RendererAgg._fontd.get(key)
 
         if font is None:
             fname = findfont(prop)
-            font = self._fontd.get(fname)
+            font = RendererAgg._fontd.get(fname)
             if font is None:
-                font = FT2Font(str(fname))
-                self._fontd[fname] = font
-            self._fontd[key] = font
+                font = FT2Font(
+                    str(fname),
+                    hinting_factor=rcParams['text.hinting_factor'])
+                RendererAgg._fontd[fname] = font
+            RendererAgg._fontd[key] = font
 
         font.clear()
         size = prop.get_size_in_points()
@@ -250,10 +289,10 @@ class RendererAgg(RendererBase):
                                      'debug-annoying')
         return self._renderer.tostring_argb()
 
-    def buffer_rgba(self,x,y):
+    def buffer_rgba(self):
         if __debug__: verbose.report('RendererAgg.buffer_rgba',
                                      'debug-annoying')
-        return self._renderer.buffer_rgba(x,y)
+        return self._renderer.buffer_rgba()
 
     def clear(self):
         self._renderer.clear()
@@ -281,7 +320,7 @@ class RendererAgg(RendererBase):
         >>> region = renderer.copy_from_bbox()
         >>> x1, y1, x2, y2 = region.get_extents()
         >>> renderer.restore_region(region, bbox=(x1+dx, y1, x2, y2),
-                                    xy=(x1-dx, y1))
+        ...                         xy=(x1-dx, y1))
 
         """
         if bbox is not None or xy is not None:
@@ -368,7 +407,14 @@ def new_figure_manager(num, *args, **kwargs):
 
     FigureClass = kwargs.pop('FigureClass', Figure)
     thisFig = FigureClass(*args, **kwargs)
-    canvas = FigureCanvasAgg(thisFig)
+    return new_figure_manager_given_figure(num, thisFig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    canvas = FigureCanvasAgg(figure)
     manager = FigureManagerBase(canvas, num)
     return manager
 
@@ -397,10 +443,18 @@ class FigureCanvasAgg(FigureCanvasBase):
         """
         if __debug__: verbose.report('FigureCanvasAgg.draw', 'debug-annoying')
 
-        self.renderer = self.get_renderer()
-        self.figure.draw(self.renderer)
+        self.renderer = self.get_renderer(cleared=True)
+        # acquire a lock on the shared font cache
+        RendererAgg.lock.acquire()
 
-    def get_renderer(self):
+        try:
+            self.figure.draw(self.renderer)
+        finally:
+            RendererAgg.lock.release()
+
+
+
+    def get_renderer(self, cleared=False):
         l, b, w, h = self.figure.bbox.bounds
         key = w, h, self.figure.dpi
         try: self._lastKey, self.renderer
@@ -410,6 +464,8 @@ class FigureCanvasAgg(FigureCanvasBase):
         if need_new_renderer:
             self.renderer = RendererAgg(w, h, self.figure.dpi)
             self._lastKey = key
+        elif cleared:
+            self.renderer.clear()
         return self.renderer
 
     def tostring_rgb(self):
@@ -422,13 +478,10 @@ class FigureCanvasAgg(FigureCanvasBase):
                                      'debug-annoying')
         return self.renderer.tostring_argb()
 
-    def buffer_rgba(self,x,y):
+    def buffer_rgba(self):
         if __debug__: verbose.report('FigureCanvasAgg.buffer_rgba',
                                      'debug-annoying')
-        return self.renderer.buffer_rgba(x,y)
-
-    def get_default_filetype(self):
-        return 'png'
+        return self.renderer.buffer_rgba()
 
     def print_raw(self, filename_or_obj, *args, **kwargs):
         FigureCanvasAgg.draw(self)
@@ -436,8 +489,15 @@ class FigureCanvasAgg(FigureCanvasBase):
         original_dpi = renderer.dpi
         renderer.dpi = self.figure.dpi
         if is_string_like(filename_or_obj):
-            filename_or_obj = file(filename_or_obj, 'wb')
-        renderer._renderer.write_rgba(filename_or_obj)
+            filename_or_obj = open(filename_or_obj, 'wb')
+            close = True
+        else:
+            close = False
+        try:
+            renderer._renderer.write_rgba(filename_or_obj)
+        finally:
+            if close:
+                filename_or_obj.close()
         renderer.dpi = original_dpi
     print_rgba = print_raw
 
@@ -447,10 +507,17 @@ class FigureCanvasAgg(FigureCanvasBase):
         original_dpi = renderer.dpi
         renderer.dpi = self.figure.dpi
         if is_string_like(filename_or_obj):
-            filename_or_obj = file(filename_or_obj, 'wb')
-        _png.write_png(renderer._renderer.buffer_rgba(0, 0),
-                       renderer.width, renderer.height,
-                       filename_or_obj, self.figure.dpi)
+            filename_or_obj = open(filename_or_obj, 'wb')
+            close = True
+        else:
+            close = False
+        try:
+            _png.write_png(renderer._renderer.buffer_rgba(),
+                           renderer.width, renderer.height,
+                           filename_or_obj, self.figure.dpi)
+        finally:
+            if close:
+                filename_or_obj.close()
         renderer.dpi = original_dpi
 
     def print_to_buffer(self):
@@ -458,7 +525,7 @@ class FigureCanvasAgg(FigureCanvasBase):
         renderer = self.get_renderer()
         original_dpi = renderer.dpi
         renderer.dpi = self.figure.dpi
-        result = (renderer._renderer.buffer_rgba(0, 0),
+        result = (renderer._renderer.buffer_rgba(),
                   (int(renderer.width), int(renderer.height)))
         renderer.dpi = original_dpi
         return result
