@@ -18,7 +18,7 @@ Naming Conventions
   * functions underscore_separated
 """
 
-from __future__ import division
+from __future__ import division, print_function
 import os, sys, warnings, gzip
 
 import numpy as np
@@ -26,15 +26,15 @@ import numpy as np
 def _fn_name(): return sys._getframe(1).f_code.co_name
 
 try:
-   import cairo
+    import cairo
 except ImportError:
-   raise ImportError("Cairo backend requires that pycairo is installed.")
+    raise ImportError("Cairo backend requires that pycairo is installed.")
 
 _version_required = (1,2,0)
 if cairo.version_info < _version_required:
-   raise ImportError ("Pycairo %d.%d.%d is installed\n"
-                     "Pycairo %d.%d.%d or later is required"
-                     % (cairo.version_info + _version_required))
+    raise ImportError ("Pycairo %d.%d.%d is installed\n"
+                       "Pycairo %d.%d.%d or later is required"
+                        % (cairo.version_info + _version_required))
 backend_version = cairo.version
 del _version_required
 
@@ -46,7 +46,6 @@ from matplotlib.mathtext     import MathTextParser
 from matplotlib.path         import Path
 from matplotlib.transforms   import Bbox, Affine2D
 from matplotlib.font_manager import ttfFontProperty
-from matplotlib import rcParams
 
 _debug = False
 #_debug = True
@@ -89,7 +88,7 @@ class RendererCairo(RendererBase):
     def __init__(self, dpi):
         """
         """
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         self.dpi = dpi
         self.gc = GraphicsContextCairo (renderer=self)
         self.text_ctx = cairo.Context (
@@ -111,13 +110,13 @@ class RendererCairo(RendererBase):
         # font transform?
 
 
-    def _fill_and_stroke (self, ctx, fill_c, alpha):
+    def _fill_and_stroke (self, ctx, fill_c, alpha, alpha_overrides):
         if fill_c is not None:
             ctx.save()
-            if len(fill_c) == 3:
+            if len(fill_c) == 3 or alpha_overrides:
                 ctx.set_source_rgba (fill_c[0], fill_c[1], fill_c[2], alpha)
             else:
-                ctx.set_source_rgba (fill_c[0], fill_c[1], fill_c[2], alpha*fill_c[3])
+                ctx.set_source_rgba (fill_c[0], fill_c[1], fill_c[2], fill_c[3])
             ctx.fill_preserve()
             ctx.restore()
         ctx.stroke()
@@ -127,6 +126,8 @@ class RendererCairo(RendererBase):
         for points, code in path.iter_segments(transform):
             if code == Path.MOVETO:
                 ctx.move_to(*points)
+            elif code == Path.CLOSEPOLY:
+                ctx.close_path()
             elif code == Path.LINETO:
                 ctx.line_to(*points)
             elif code == Path.CURVE3:
@@ -135,8 +136,6 @@ class RendererCairo(RendererBase):
                              points[2], points[3])
             elif code == Path.CURVE4:
                 ctx.curve_to(*points)
-            elif code == Path.CLOSEPOLY:
-                ctx.close_path()
 
 
     def draw_path(self, gc, path, transform, rgbFace=None):
@@ -151,60 +150,57 @@ class RendererCairo(RendererBase):
         ctx.new_path()
         self.convert_path(ctx, path, transform)
 
-        self._fill_and_stroke(ctx, rgbFace, gc.get_alpha())
+        self._fill_and_stroke(ctx, rgbFace, gc.get_alpha(), gc.get_forced_alpha())
 
     def draw_image(self, gc, x, y, im):
         # bbox - not currently used
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
-
-        clippath, clippath_trans = gc.get_clip_path()
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
 
         im.flipud_out()
 
         rows, cols, buf = im.color_conv (BYTE_FORMAT)
         surface = cairo.ImageSurface.create_for_data (
                       buf, cairo.FORMAT_ARGB32, cols, rows, cols*4)
-        # function does not pass a 'gc' so use renderer.ctx
-        ctx = self.gc.ctx
-        ctx.save()
-        if clippath is not None:
-            ctx.new_path()
-            RendererCairo.convert_path(ctx, clippath, clippath_trans)
-            ctx.clip()
+        ctx = gc.ctx
         y = self.height - y - rows
+
+        ctx.save()
         ctx.set_source_surface (surface, x, y)
         ctx.paint()
         ctx.restore()
 
         im.flipud_out()
 
-    def draw_text(self, gc, x, y, s, prop, angle, ismath=False):
+    def draw_text(self, gc, x, y, s, prop, angle, ismath=False, mtext=None):
         # Note: x,y are device/display coords, not user-coords, unlike other
         # draw_* methods
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
 
         if ismath:
-           self._draw_mathtext(gc, x, y, s, prop, angle)
+            self._draw_mathtext(gc, x, y, s, prop, angle)
 
         else:
-           ctx = gc.ctx
-           ctx.new_path()
-           ctx.move_to (x, y)
-           ctx.select_font_face (prop.get_name(),
-                                 self.fontangles [prop.get_style()],
-                                 self.fontweights[prop.get_weight()])
+            ctx = gc.ctx
+            ctx.new_path()
+            ctx.move_to (x, y)
+            ctx.select_font_face (prop.get_name(),
+                                  self.fontangles [prop.get_style()],
+                                  self.fontweights[prop.get_weight()])
 
-           size = prop.get_size_in_points() * self.dpi / 72.0
+            size = prop.get_size_in_points() * self.dpi / 72.0
 
-           ctx.save()
-           if angle:
-              ctx.rotate (-angle * np.pi / 180)
-           ctx.set_font_size (size)
-           ctx.show_text (s.encode("utf-8"))
-           ctx.restore()
+            ctx.save()
+            if angle:
+                ctx.rotate (-angle * np.pi / 180)
+            ctx.set_font_size (size)
+            if sys.version_info[0] < 3:
+                ctx.show_text(s.encode("utf-8"))
+            else:
+                ctx.show_text(s)
+            ctx.restore()
 
     def _draw_mathtext(self, gc, x, y, s, prop, angle):
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
 
         ctx = gc.ctx
         width, height, descent, glyphs, rects = self.mathtext_parser.parse(
@@ -213,46 +209,49 @@ class RendererCairo(RendererBase):
         ctx.save()
         ctx.translate(x, y)
         if angle:
-           ctx.rotate (-angle * np.pi / 180)
+            ctx.rotate (-angle * np.pi / 180)
 
         for font, fontsize, s, ox, oy in glyphs:
-           ctx.new_path()
-           ctx.move_to(ox, oy)
+            ctx.new_path()
+            ctx.move_to(ox, oy)
 
-           fontProp = ttfFontProperty(font)
-           ctx.save()
-           ctx.select_font_face (fontProp.name,
-                                 self.fontangles [fontProp.style],
-                                 self.fontweights[fontProp.weight])
+            fontProp = ttfFontProperty(font)
+            ctx.save()
+            ctx.select_font_face (fontProp.name,
+                                  self.fontangles [fontProp.style],
+                                  self.fontweights[fontProp.weight])
 
-           size = fontsize * self.dpi / 72.0
-           ctx.set_font_size(size)
-           ctx.show_text(s.encode("utf-8"))
-           ctx.restore()
+            size = fontsize * self.dpi / 72.0
+            ctx.set_font_size(size)
+            if sys.version_info[0] < 3:
+                ctx.show_text(s.encode("utf-8"))
+            else:
+                ctx.show_text(s)
+            ctx.restore()
 
         for ox, oy, w, h in rects:
-           ctx.new_path()
-           ctx.rectangle (ox, oy, w, h)
-           ctx.set_source_rgb (0, 0, 0)
-           ctx.fill_preserve()
+            ctx.new_path()
+            ctx.rectangle (ox, oy, w, h)
+            ctx.set_source_rgb (0, 0, 0)
+            ctx.fill_preserve()
 
         ctx.restore()
 
 
     def flipy(self):
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         return True
         #return False # tried - all draw objects ok except text (and images?)
         # which comes out mirrored!
 
 
     def get_canvas_width_height(self):
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         return self.width, self.height
 
 
     def get_text_width_height_descent(self, s, prop, ismath):
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         if ismath:
             width, height, descent, fonts, used_characters = self.mathtext_parser.parse(
                s, self.dpi, prop)
@@ -281,7 +280,7 @@ class RendererCairo(RendererBase):
 
 
     def new_gc(self):
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         self.gc.ctx.save()
         self.gc._alpha = 1.0
         self.gc._forced_alpha = False # if True, _alpha overrides A from RGBA
@@ -289,7 +288,7 @@ class RendererCairo(RendererBase):
 
 
     def points_to_pixels(self, points):
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         return points/72.0 * self.dpi
 
 
@@ -320,7 +319,10 @@ class GraphicsContextCairo(GraphicsContextBase):
         GraphicsContextBase.set_alpha(self, alpha)
         _alpha = self.get_alpha()
         rgb = self._rgb
-        self.ctx.set_source_rgba (rgb[0], rgb[1], rgb[2], _alpha)
+        if self.get_forced_alpha():
+            self.ctx.set_source_rgba (rgb[0], rgb[1], rgb[2], _alpha)
+        else:
+            self.ctx.set_source_rgba (rgb[0], rgb[1], rgb[2], rgb[3])
 
 
     #def set_antialiased(self, b):
@@ -363,8 +365,8 @@ class GraphicsContextCairo(GraphicsContextBase):
                self.renderer.points_to_pixels (np.asarray(dashes)), offset)
 
 
-    def set_foreground(self, fg, isRGB=None):
-        GraphicsContextBase.set_foreground(self, fg, isRGB)
+    def set_foreground(self, fg, isRGBA=None):
+        GraphicsContextBase.set_foreground(self, fg, isRGBA)
         if len(self._rgb) == 3:
             self.ctx.set_source_rgb(*self._rgb)
         else:
@@ -395,10 +397,17 @@ def new_figure_manager(num, *args, **kwargs): # called by backends/__init__.py
     """
     Create a new figure manager instance
     """
-    if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+    if _debug: print('%s()' % (_fn_name()))
     FigureClass = kwargs.pop('FigureClass', Figure)
     thisFig = FigureClass(*args, **kwargs)
-    canvas  = FigureCanvasCairo(thisFig)
+    return new_figure_manager_given_figure(num, thisFig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    canvas  = FigureCanvasCairo(figure)
     manager = FigureManagerBase(canvas, num)
     return manager
 
@@ -427,9 +436,6 @@ class FigureCanvasCairo (FigureCanvasBase):
     def print_svgz(self, fobj, *args, **kwargs):
         return self._save(fobj, 'svgz', *args, **kwargs)
 
-    def get_default_filetype(self):
-        return rcParams['cairo.format']
-
     def _save (self, fo, format, **kwargs):
         # save PDF/PS/SVG
         orientation = kwargs.get('orientation', 'portrait')
@@ -461,7 +467,14 @@ class FigureCanvasCairo (FigureCanvasBase):
                 filename = fo
                 if is_string_like(fo):
                     fo = open(fo, 'wb')
-                fo = gzip.GzipFile(None, 'wb', fileobj=fo)
+                    close = True
+                else:
+                    close = False
+                try:
+                    fo = gzip.GzipFile(None, 'wb', fileobj=fo)
+                finally:
+                    if close:
+                        fo.close()
             surface = cairo.SVGSurface (fo, width_in_points, height_in_points)
         else:
            warnings.warn ("unknown format: %s" % format)
