@@ -1,4 +1,4 @@
-from __future__ import division
+from __future__ import division, print_function
 """
  backend_cocoaagg.py
 
@@ -18,15 +18,19 @@ import os, sys
 
 try:
     import objc
-except:
-    print >>sys.stderr, 'The CococaAgg backend required PyObjC to be installed!'
-    print >>sys.stderr, '  (currently testing v1.3.7)'
-    sys.exit()
+except ImportError:
+    raise ImportError('The CococaAgg backend required PyObjC to be installed!')
 
 from Foundation import *
 from AppKit import *
 from PyObjCTools import NibClassBuilder, AppHelper
 
+from matplotlib import cbook
+cbook.warn_deprecated(
+    '1.3',
+    message="The CocoaAgg backend is not a fully-functioning backend. "
+            "It may be removed in matplotlib 1.4.")
+
 import matplotlib
 from matplotlib.figure import Figure
 from matplotlib.backend_bases import FigureManagerBase, FigureCanvasBase
@@ -37,12 +41,21 @@ from matplotlib._pylab_helpers import Gcf
 
 mplBundle = NSBundle.bundleWithPath_(os.path.dirname(__file__))
 
+
 def new_figure_manager(num, *args, **kwargs):
     FigureClass = kwargs.pop('FigureClass', Figure)
     thisFig = FigureClass( *args, **kwargs )
-    canvas = FigureCanvasCocoaAgg(thisFig)
+    return new_figure_manager_given_figure(num, thisFig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    canvas = FigureCanvasCocoaAgg(figure)
     return FigureManagerCocoaAgg(canvas, num)
 
+
 ## Below is the original show() function:
 #def show():
 #    for manager in Gcf.get_all_fig_managers():
@@ -144,7 +157,7 @@ class PlotView(NibClassBuilder.AutoBaseClass):
         self.image_.setSize_((w,h))
 
         brep = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_(
-            (self.canvas.buffer_rgba(0,0),'','','',''), # Image data
+            (self.canvas.buffer_rgba(),'','','',''), # Image data
             w, # width
             h, # height
             8, # bits per pixel
@@ -166,14 +179,15 @@ class PlotView(NibClassBuilder.AutoBaseClass):
         self.updatePlot()
 
     def mouseDown_(self, event):
+        dblclick = (event.clickCount() == 2)
         loc = self.convertPoint_fromView_(event.locationInWindow(), None)
         type = event.type()
         if (type == NSLeftMouseDown):
             button = 1
         else:
-            print >>sys.stderr, 'Unknown mouse event type:', type
+            print('Unknown mouse event type:', type, file=sys.stderr)
             button = -1
-        self.canvas.button_press_event(loc.x, loc.y, button)
+        self.canvas.button_press_event(loc.x, loc.y, button, dblclick=dblclick)
         self.updatePlot()
 
     def mouseDragged_(self, event):
@@ -187,7 +201,7 @@ class PlotView(NibClassBuilder.AutoBaseClass):
         if (type == NSLeftMouseUp):
             button = 1
         else:
-            print >>sys.stderr, 'Unknown mouse event type:', type
+            print('Unknown mouse event type:', type, file=sys.stderr)
             button = -1
         self.canvas.button_release_event(loc.x, loc.y, button)
         self.updatePlot()
@@ -205,7 +219,7 @@ class MPLBootstrap(NSObject):
     def startWithBundle_(self, bundle):
         #NSApplicationLoad()
         if not bundle.loadNibFile_externalNameTable_withZone_('Matplotlib.nib', {}, None):
-            print >>sys.stderr, 'Unable to load Matplotlib Cocoa UI!'
+            print('Unable to load Matplotlib Cocoa UI!', file=sys.stderr)
             sys.exit()
 
 class FigureManagerCocoaAgg(FigureManagerBase):
@@ -259,21 +273,21 @@ def WMEnable(name='Python'):
         return True
     bndl = NSBundle.bundleWithPath_(objc.pathForFramework('/System/Library/Frameworks/ApplicationServices.framework'))
     if bndl is None:
-        print >>sys.stderr, 'ApplicationServices missing'
+        print('ApplicationServices missing', file=sys.stderr)
         return False
     d = {}
     objc.loadBundleFunctions(bndl, d, FUNCTIONS)
     for (fn, sig) in FUNCTIONS:
         if fn not in d:
-            print >>sys.stderr, 'Missing', fn
+            print('Missing', fn, file=sys.stderr)
             return False
     err, psn = d['GetCurrentProcess']()
     if err:
-        print >>sys.stderr, 'GetCurrentProcess', (err, psn)
+        print('GetCurrentProcess', (err, psn), file=sys.stderr)
         return False
     err = d['CPSSetProcessName'](psn, name)
     if err:
-        print >>sys.stderr, 'CPSSetProcessName', (err, psn)
+        print('CPSSetProcessName', (err, psn), file=sys.stderr)
         return False
     err = d['CPSEnableForegroundOperation'](psn)
     if err:
@@ -281,7 +295,6 @@ def WMEnable(name='Python'):
         return False
     err = d['SetFrontProcess'](psn)
     if err:
-        print >>sys.stderr, 'SetFrontProcess', (err, psn)
+        print('SetFrontProcess', (err, psn), file=sys.stderr)
         return False
     return True
-
