@@ -1,4 +1,4 @@
-from __future__ import division
+from __future__ import division, print_function
 
 import math
 import os
@@ -11,14 +11,15 @@ import gtk; gdk = gtk.gdk
 import pango
 pygtk_version_required = (2,2,0)
 if gtk.pygtk_version < pygtk_version_required:
-    raise SystemExit ("PyGTK %d.%d.%d is installed\n"
+    raise ImportError ("PyGTK %d.%d.%d is installed\n"
                       "PyGTK %d.%d.%d or later is required"
                       % (gtk.pygtk_version + pygtk_version_required))
 del pygtk_version_required
 
-import numpy as npy
+import numpy as np
 
 import matplotlib
+from matplotlib import rcParams
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase, \
      FigureManagerBase, FigureCanvasBase
@@ -28,7 +29,6 @@ from matplotlib.mathtext import MathTextParser
 from matplotlib.transforms import Affine2D
 from matplotlib.backends._backend_gdk import pixbuf_get_pixels_array
 
-
 backend_version = "%d.%d.%d" % gtk.pygtk_version
 _debug = False
 
@@ -97,7 +97,9 @@ class RendererGDK(RendererBase):
             if gc.gdkGC.line_width > 0:
                 self.gdkDrawable.draw_lines(gc.gdkGC, polygon)
 
-    def draw_image(self, x, y, im, bbox, clippath=None, clippath_trans=None):
+    def draw_image(self, gc, x, y, im):
+        bbox = gc.get_clip_rectangle()
+
         if bbox != None:
             l,b,w,h = bbox.bounds
             #rectangle = (int(l), self.height-int(b+h),
@@ -107,7 +109,7 @@ class RendererGDK(RendererBase):
         im.flipud_out()
         rows, cols, image_str = im.as_rgba_str()
 
-        image_array = npy.fromstring(image_str, npy.uint8)
+        image_array = np.fromstring(image_str, np.uint8)
         image_array.shape = rows, cols, 4
 
         pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB,
@@ -137,10 +139,10 @@ class RendererGDK(RendererBase):
         im.flipud_out()
 
 
-    def draw_text(self, gc, x, y, s, prop, angle, ismath):
+    def draw_text(self, gc, x, y, s, prop, angle, ismath=False, mtext=None):
         x, y = int(x), int(y)
 
-        if x <0 or y <0: # window has shrunk and text is off the edge
+        if x < 0 or y < 0: # window has shrunk and text is off the edge
             return
 
         if angle not in (0,90):
@@ -155,6 +157,9 @@ class RendererGDK(RendererBase):
         else:
             layout, inkRect, logicalRect = self._get_pango_layout(s, prop)
             l, b, w, h = inkRect
+            if (x + w > self.width or y + h > self.height):
+                return
+
             self.gdkDrawable.draw_layout(gc.gdkGC, x, y-h-b, layout)
 
 
@@ -172,13 +177,13 @@ class RendererGDK(RendererBase):
         N = imw * imh
 
         # a numpixels by num fonts array
-        Xall = npy.zeros((N,1), npy.uint8)
+        Xall = np.zeros((N,1), np.uint8)
 
         image_str = font_image.as_str()
-        Xall[:,0] = npy.fromstring(image_str, npy.uint8)
+        Xall[:,0] = np.fromstring(image_str, np.uint8)
 
         # get the max alpha at each pixel
-        Xs = npy.amax(Xall,axis=1)
+        Xs = np.amax(Xall,axis=1)
 
         # convert it to it's proper shape
         Xs.shape = imh, imw
@@ -223,7 +228,8 @@ class RendererGDK(RendererBase):
         x = int(x-h)
         y = int(y-w)
 
-        if x < 0 or y < 0: # window has shrunk and text is off the edge
+        if (x < 0 or y < 0 or # window has shrunk and text is off the edge
+            x + w > self.width or y + h > self.height):
             return
 
         key = (x,y,s,angle,hash(prop))
@@ -306,7 +312,9 @@ class RendererGDK(RendererBase):
 
         layout, inkRect, logicalRect = self._get_pango_layout(s, prop)
         l, b, w, h = inkRect
-        return w, h+1, h + 1
+        ll, lb, lw, lh = logicalRect
+
+        return w, h + 1, h - lh
 
     def new_gc(self):
         return GraphicsContextGDK(renderer=self)
@@ -379,14 +387,14 @@ class GraphicsContextGDK(GraphicsContextBase):
         if dash_list == None:
             self.gdkGC.line_style = gdk.LINE_SOLID
         else:
-            pixels = self.renderer.points_to_pixels(npy.asarray(dash_list))
+            pixels = self.renderer.points_to_pixels(np.asarray(dash_list))
             dl = [max(1, int(round(val))) for val in pixels]
             self.gdkGC.set_dashes(dash_offset, dl)
             self.gdkGC.line_style = gdk.LINE_ON_OFF_DASH
 
 
-    def set_foreground(self, fg, isRGB=False):
-        GraphicsContextBase.set_foreground(self, fg, isRGB)
+    def set_foreground(self, fg, isRGBA=False):
+        GraphicsContextBase.set_foreground(self, fg, isRGBA)
         self.gdkGC.foreground = self.rgb_to_gdk_color(self.get_rgb())
 
 
@@ -415,11 +423,15 @@ def new_figure_manager(num, *args, **kwargs):
     """
     FigureClass = kwargs.pop('FigureClass', Figure)
     thisFig = FigureClass(*args, **kwargs)
-    canvas  = FigureCanvasGDK(thisFig)
+    return new_figure_manager_given_figure(num, thisFig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    canvas  = FigureCanvasGDK(figure)
     manager = FigureManagerBase(canvas, num)
-    # equals:
-    #manager = FigureManagerBase (FigureCanvasGDK (Figure(*args, **kwargs),
-    #                             num)
     return manager
 
 
@@ -460,7 +472,13 @@ class FigureCanvasGDK (FigureCanvasBase):
         pixbuf.get_from_drawable(pixmap, pixmap.get_colormap(),
                                  0, 0, 0, 0, width, height)
 
-        pixbuf.save(filename, format)
+        # set the default quality, if we are writing a JPEG.
+        # http://www.pygtk.org/docs/pygtk/class-gdkpixbuf.html#method-gdkpixbuf--save
+        options = cbook.restrict_dict(kwargs, ['quality'])
+        if format in ['jpg','jpeg']:
+           if 'quality' not in options:
+              options['quality'] = rcParams['savefig.jpeg_quality']
+           options['quality'] = str(options['quality'])
+            
+        pixbuf.save(filename, format, options=options)
 
-    def get_default_filetype(self):
-        return 'png'
