@@ -2,15 +2,17 @@
 GTK+ Matplotlib interface using cairo (not GDK) drawing operations.
 Author: Steve Chaplin
 """
+from __future__ import print_function
+
 import gtk
 if gtk.pygtk_version < (2,7,0):
     import cairo.gtk
 
-import matplotlib.backends.backend_cairo as be_cairo
-from   matplotlib.backends.backend_gtk import *
+from matplotlib.backends import backend_cairo
+from matplotlib.backends.backend_gtk import *
 
 backend_version = 'PyGTK(%d.%d.%d) ' % gtk.pygtk_version + \
-                  'Pycairo(%s)' % be_cairo.backend_version
+                  'Pycairo(%s)' % backend_cairo.backend_version
 
 
 _debug = False
@@ -21,26 +23,36 @@ def new_figure_manager(num, *args, **kwargs):
     """
     Create a new figure manager instance
     """
-    if _debug: print 'backend_gtkcairo.%s()' % fn_name()
+    if _debug: print('backend_gtkcairo.%s()' % fn_name())
     FigureClass = kwargs.pop('FigureClass', Figure)
     thisFig = FigureClass(*args, **kwargs)
-    canvas = FigureCanvasGTKCairo(thisFig)
+    return new_figure_manager_given_figure(num, thisFig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    canvas = FigureCanvasGTKCairo(figure)
     return FigureManagerGTK(canvas, num)
 
 
-class RendererGTKCairo (be_cairo.RendererCairo):
-    def set_pixmap (self, pixmap):
-        if gtk.pygtk_version >= (2,7,0):
-            self.ctx = pixmap.cairo_create()
-        else:
-            self.ctx = cairo.gtk.gdk_cairo_create (pixmap)
-        self.ctx.save()  # restore, save  - when call new_gc()
+class RendererGTKCairo (backend_cairo.RendererCairo):
+    if gtk.pygtk_version >= (2,7,0):
+        def set_pixmap (self, pixmap):
+            self.gc.ctx = pixmap.cairo_create()
+    else:
+        def set_pixmap (self, pixmap):
+            self.gc.ctx = cairo.gtk.gdk_cairo_create (pixmap)
 
 
-class FigureCanvasGTKCairo(FigureCanvasGTK):
+class FigureCanvasGTKCairo(backend_cairo.FigureCanvasCairo, FigureCanvasGTK):
+    filetypes = FigureCanvasGTK.filetypes.copy()
+    filetypes.update(backend_cairo.FigureCanvasCairo.filetypes)
+
     def _renderer_init(self):
         """Override to use cairo (rather than GDK) renderer"""
-        if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
+        if _debug: print('%s.%s()' % (self.__class__.__name__, _fn_name()))
         self._renderer = RendererGTKCairo (self.figure.dpi)
 
 
