@@ -1,11 +1,11 @@
-from __future__ import division
+from __future__ import division, print_function
 
 import os
 import numpy
 
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
-     FigureManagerBase, FigureCanvasBase, NavigationToolbar2
+     FigureManagerBase, FigureCanvasBase, NavigationToolbar2, TimerBase
 from matplotlib.backend_bases import ShowBase
 
 from matplotlib.cbook import maxdict
@@ -13,20 +13,20 @@ from matplotlib.figure import Figure
 from matplotlib.path import Path
 from matplotlib.mathtext import MathTextParser
 from matplotlib.colors import colorConverter
-
-
+from matplotlib import rcParams
 
 from matplotlib.widgets import SubplotTool
 
 import matplotlib
 from matplotlib.backends import _macosx
 
+
 class Show(ShowBase):
     def mainloop(self):
         _macosx.show()
-
 show = Show()
 
+
 class RendererMac(RendererBase):
     """
     The renderer handles drawing/rendering operations. Most of the renderer's
@@ -42,6 +42,7 @@ class RendererMac(RendererBase):
         self.width = width
         self.height = height
         self.gc = GraphicsContextMac()
+        self.gc.set_dpi(self.dpi)
         self.mathtext_parser = MathTextParser('MacOSX')
 
     def set_width_height (self, width, height):
@@ -49,69 +50,67 @@ class RendererMac(RendererBase):
 
     def draw_path(self, gc, path, transform, rgbFace=None):
         if rgbFace is not None:
-            rgbFace = tuple(rgbFace[:3])
+            rgbFace = tuple(rgbFace)
         linewidth = gc.get_linewidth()
         gc.draw_path(path, transform, linewidth, rgbFace)
 
     def draw_markers(self, gc, marker_path, marker_trans, path, trans, rgbFace=None):
         if rgbFace is not None:
-            rgbFace = tuple(rgbFace[:3])
+            rgbFace = tuple(rgbFace)
         linewidth = gc.get_linewidth()
         gc.draw_markers(marker_path, marker_trans, path, trans, linewidth, rgbFace)
 
     def draw_path_collection(self, gc, master_transform, paths, all_transforms,
                              offsets, offsetTrans, facecolors, edgecolors,
-                             linewidths, linestyles, antialiaseds, urls):
-        cliprect = gc.get_clip_rectangle()
-        clippath, clippath_transform = gc.get_clip_path()
-        if all_transforms:
-            transforms = [numpy.dot(master_transform, t) for t in all_transforms]
+                             linewidths, linestyles, antialiaseds, urls,
+                             offset_position):
+        if offset_position=='data':
+            offset_position = True
         else:
-            transforms = [master_transform]
-        gc.draw_path_collection(cliprect,
-                                clippath,
-                                clippath_transform,
-                                paths,
-                                transforms,
-                                offsets,
-                                offsetTrans,
-                                facecolors,
-                                edgecolors,
-                                linewidths,
-                                linestyles,
-                                antialiaseds)
+            offset_position = False
+        path_ids = []
+        for path, transform in self._iter_collection_raw_paths(
+            master_transform, paths, all_transforms):
+            path_ids.append((path, transform))
+        master_transform = master_transform.get_matrix()
+        all_transforms = [t.get_matrix() for t in all_transforms]
+        offsetTrans = offsetTrans.get_matrix()
+        gc.draw_path_collection(master_transform, path_ids, all_transforms,
+                             offsets, offsetTrans, facecolors, edgecolors,
+                             linewidths, linestyles, antialiaseds,
+                             offset_position)
 
     def draw_quad_mesh(self, gc, master_transform, meshWidth, meshHeight,
                        coordinates, offsets, offsetTrans, facecolors,
-                       antialiased, showedges):
-        cliprect = gc.get_clip_rectangle()
-        clippath, clippath_transform = gc.get_clip_path()
-        gc.draw_quad_mesh(master_transform,
-                          cliprect,
-                          clippath,
-                          clippath_transform,
+                       antialiased, edgecolors):
+        gc.draw_quad_mesh(master_transform.get_matrix(),
                           meshWidth,
                           meshHeight,
                           coordinates,
                           offsets,
-                          offsetTrans,
+                          offsetTrans.get_matrix(),
                           facecolors,
                           antialiased,
-                          showedges)
+                          edgecolors)
 
     def new_gc(self):
         self.gc.save()
         self.gc.set_hatch(None)
+        self.gc._alpha = 1.0
+        self.gc._forced_alpha = False # if True, _alpha overrides A from RGBA
         return self.gc
 
+    def draw_gouraud_triangle(self, gc, points, colors, transform):
+        points = transform.transform(points)
+        gc.draw_gouraud_triangle(points, colors)
+
     def draw_image(self, gc, x, y, im):
         im.flipud_out()
         nrows, ncols, data = im.as_rgba_str()
-        gc.draw_image(x, y, nrows, ncols, data, gc.get_clip_rectangle(),
-                      *gc.get_clip_path())
+        gc.draw_image(x, y, nrows, ncols, data)
         im.flipud_out()
 
-    def draw_tex(self, gc, x, y, s, prop, angle):
+    def draw_tex(self, gc, x, y, s, prop, angle, ismath='TeX!', mtext=None):
         # todo, handle props, angle, origins
         size = prop.get_size_in_points()
         texmanager = self.get_texmanager()
@@ -128,9 +127,9 @@ class RendererMac(RendererBase):
             self.mathtext_parser.parse(s, self.dpi, prop)
         gc.draw_mathtext(x, y, angle, 255 - image.as_array())
 
-    def draw_text(self, gc, x, y, s, prop, angle, ismath=False):
+    def draw_text(self, gc, x, y, s, prop, angle, ismath=False, mtext=None):
         if ismath:
-           self._draw_mathtext(gc, x, y, s, prop, angle)
+            self._draw_mathtext(gc, x, y, s, prop, angle)
         else:
             family =  prop.get_family()
             weight = prop.get_weight()
@@ -168,6 +167,7 @@ class RendererMac(RendererBase):
     def option_image_nocomposite(self):
         return True
 
+
 class GraphicsContextMac(_macosx.GraphicsContext, GraphicsContextBase):
     """
     The GraphicsContext wraps a Quartz graphics context. All methods
@@ -183,12 +183,14 @@ class GraphicsContextMac(_macosx.GraphicsContext, GraphicsContextBase):
     def set_alpha(self, alpha):
         GraphicsContextBase.set_alpha(self, alpha)
         _alpha = self.get_alpha()
-        _macosx.GraphicsContext.set_alpha(self, _alpha)
-
-    def set_foreground(self, fg, isRGB=False):
-        GraphicsContextBase.set_foreground(self, fg, isRGB)
+        _macosx.GraphicsContext.set_alpha(self, _alpha, self.get_forced_alpha())
         rgb = self.get_rgb()
-        _macosx.GraphicsContext.set_foreground(self, rgb[:3])
+        _macosx.GraphicsContext.set_foreground(self, rgb)
+
+    def set_foreground(self, fg, isRGBA=False):
+        GraphicsContextBase.set_foreground(self, fg, isRGBA)
+        rgb = self.get_rgb()
+        _macosx.GraphicsContext.set_foreground(self, rgb)
 
     def set_graylevel(self, fg):
         GraphicsContextBase.set_graylevel(self, fg)
@@ -205,6 +207,7 @@ class GraphicsContextMac(_macosx.GraphicsContext, GraphicsContextBase):
         path = path.get_fully_transformed_path()
         _macosx.GraphicsContext.set_clip_path(self, path)
 
+
 ########################################################################
 #
 # The following functions and classes are for pylab and implement
@@ -220,23 +223,47 @@ def draw_if_interactive():
     This function should be called after each draw event, even if
     matplotlib is not running interactively.
     """
-    figManager =  Gcf.get_active()
-    if figManager is not None:
-        figManager.canvas.invalidate()
+    if matplotlib.is_interactive():
+        figManager =  Gcf.get_active()
+        if figManager is not None:
+            figManager.canvas.invalidate()
+
 
 def new_figure_manager(num, *args, **kwargs):
     """
     Create a new figure manager instance
     """
-    if not _macosx.verify_main_display():
-        import warnings
-        warnings.warn("Python is not installed as a framework. The MacOSX backend may not work correctly if Python is not installed as a framework. Please see the Python documentation for more information on installing Python as a framework on Mac OS X")
     FigureClass = kwargs.pop('FigureClass', Figure)
     figure = FigureClass(*args, **kwargs)
+    return new_figure_manager_given_figure(num, figure)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
     canvas = FigureCanvasMac(figure)
     manager = FigureManagerMac(canvas, num)
     return manager
 
+
+class TimerMac(_macosx.Timer, TimerBase):
+    '''
+    Subclass of :class:`backend_bases.TimerBase` that uses CoreFoundation
+    run loops for timer events.
+
+    Attributes:
+    * interval: The time between timer events in milliseconds. Default
+        is 1000 ms.
+    * single_shot: Boolean flag indicating whether this timer should
+        operate as single shot (run once and then stop). Defaults to False.
+    * callbacks: Stores list of (func, args) tuples that will be called
+        upon timer events. This list can be manipulated directly, or the
+        functions add_callback and remove_callback can be used.
+    '''
+    # completely implemented at the C-level (in _macosx.Timer)
+
+
 class FigureCanvasMac(_macosx.FigureCanvas, FigureCanvasBase):
     """
     The canvas the figure renders into.  Calls the draw and print fig
@@ -283,7 +310,7 @@ class FigureCanvasMac(_macosx.FigureCanvas, FigureCanvasBase):
         width, height = self.figure.get_size_inches()
         width, height = width*dpi, height*dpi
         filename = unicode(filename)
-        self.write_bitmap(filename, width, height)
+        self.write_bitmap(filename, width, height, dpi)
         self.figure.dpi = old_dpi
 
     def print_bmp(self, filename, *args, **kwargs):
@@ -304,8 +331,21 @@ class FigureCanvasMac(_macosx.FigureCanvas, FigureCanvasBase):
     def print_gif(self, filename, *args, **kwargs):
         self._print_bitmap(filename, *args, **kwargs)
 
-    def get_default_filetype(self):
-        return 'png'
+    def new_timer(self, *args, **kwargs):
+        """
+        Creates a new backend-specific subclass of :class:`backend_bases.Timer`.
+        This is useful for getting periodic events through the backend's native
+        event loop. Implemented only for backends with GUIs.
+
+        optional arguments:
+
+        *interval*
+          Timer interval in milliseconds
+        *callbacks*
+          Sequence of (func, args, kwargs) where func(*args, **kwargs) will
+          be executed by the timer every *interval*.
+        """
+        return TimerMac(*args, **kwargs)
 
 
 class FigureManagerMac(_macosx.FigureManager, FigureManagerBase):
@@ -316,9 +356,9 @@ class FigureManagerMac(_macosx.FigureManager, FigureManagerBase):
         FigureManagerBase.__init__(self, canvas, num)
         title = "Figure %d" % num
         _macosx.FigureManager.__init__(self, canvas, title)
-        if matplotlib.rcParams['toolbar']=='classic':
+        if rcParams['toolbar']=='classic':
             self.toolbar = NavigationToolbarMac(canvas)
-        elif matplotlib.rcParams['toolbar']=='toolbar2':
+        elif rcParams['toolbar']=='toolbar2':
             self.toolbar = NavigationToolbar2Mac(canvas)
         else:
             self.toolbar = None
@@ -330,21 +370,18 @@ class FigureManagerMac(_macosx.FigureManager, FigureManagerBase):
             if self.toolbar != None: self.toolbar.update()
         self.canvas.figure.add_axobserver(notify_axes_change)
 
-        # This is ugly, but this is what tkagg and gtk are doing.
-        # It is needed to get ginput() working.
-        self.canvas.figure.show = lambda *args: self.show()
-
-    def show(self):
-        self.canvas.draw()
+        if matplotlib.is_interactive():
+            self.show()
 
     def close(self):
         Gcf.destroy(self.num)
 
+
 class NavigationToolbarMac(_macosx.NavigationToolbar):
 
     def __init__(self, canvas):
         self.canvas = canvas
-        basedir = os.path.join(matplotlib.rcParams['datapath'], "images")
+        basedir = os.path.join(rcParams['datapath'], "images")
         images = {}
         for imagename in ("stock_left",
                           "stock_right",
@@ -402,22 +439,24 @@ class NavigationToolbarMac(_macosx.NavigationToolbar):
         self.canvas.invalidate()
 
     def save_figure(self, *args):
-        filename = _macosx.choose_save_file('Save the figure')
+        filename = _macosx.choose_save_file('Save the figure',
+                                            self.canvas.get_default_filename())
         if filename is None: # Cancel
             return
         self.canvas.print_figure(filename)
 
+
 class NavigationToolbar2Mac(_macosx.NavigationToolbar2, NavigationToolbar2):
 
     def __init__(self, canvas):
         NavigationToolbar2.__init__(self, canvas)
 
     def _init_toolbar(self):
-        basedir = os.path.join(matplotlib.rcParams['datapath'], "images")
+        basedir = os.path.join(rcParams['datapath'], "images")
         _macosx.NavigationToolbar2.__init__(self, basedir)
 
     def draw_rubberband(self, event, x0, y0, x1, y1):
-        self.canvas.set_rubberband(x0, y0, x1, y1)
+        self.canvas.set_rubberband(int(x0), int(y0), int(x1), int(y1))
 
     def release(self, event):
         self.canvas.remove_rubberband()
@@ -426,7 +465,8 @@ class NavigationToolbar2Mac(_macosx.NavigationToolbar2, NavigationToolbar2):
         _macosx.set_cursor(cursor)
 
     def save_figure(self, *args):
-        filename = _macosx.choose_save_file('Save the figure')
+        filename = _macosx.choose_save_file('Save the figure',
+                                            self.canvas.get_default_filename())
         if filename is None: # Cancel
             return
         self.canvas.print_figure(filename)
@@ -441,6 +481,9 @@ class NavigationToolbar2Mac(_macosx.NavigationToolbar2, NavigationToolbar2):
     def set_message(self, message):
         _macosx.NavigationToolbar2.set_message(self, message.encode('utf-8'))
 
+    def dynamic_update(self):
+        self.canvas.draw_idle()
+
 ########################################################################
 #
 # Now just provide the standard names that backend.__init__ is expecting
