@@ -17,7 +17,7 @@ except ImportError:
     from md5 import md5 #Deprecated in 2.5
 
 from tempfile import mkstemp
-from matplotlib import verbose, __version__, rcParams
+from matplotlib import verbose, __version__, rcParams, checkdep_ghostscript
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.afm import AFM
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
@@ -70,8 +70,9 @@ class PsBackendHelper(object):
         except KeyError:
             pass
 
-        if sys.platform == 'win32': gs_exe = 'gswin32c'
-        else: gs_exe = 'gs'
+        gs_exe, gs_version = checkdep_ghostscript()
+        if gs_exe is None:
+            gs_exe = 'gs'
 
         self._cached["gs_exe"] = gs_exe
         return gs_exe
@@ -750,10 +751,11 @@ grestore
             self.set_color(*gc.get_rgb())
             sfnt = font.get_sfnt()
             try:
-                ps_name = sfnt[(1,0,0,6)]
+                ps_name = sfnt[(1,0,0,6)].decode('macroman')
             except KeyError:
                 ps_name = sfnt[(3,1,0x0409,6)].decode(
-                    'utf-16be').encode('ascii','replace')
+                    'utf-16be')
+            ps_name = ps_name.encode('ascii','replace')
             self.set_font(ps_name, prop.get_size_in_points())
 
             cmap = font.get_charmap()
@@ -1616,8 +1618,7 @@ def get_bbox(tmpfile, bbox):
     """
 
     outfile = tmpfile + '.output'
-    if sys.platform == 'win32': gs_exe = 'gswin32c'
-    else: gs_exe = 'gs'
+    gs_exe = ps_backend_helper.gs_exe
     command = '%s -dBATCH -dNOPAUSE -sDEVICE=bbox "%s"' %\
                 (gs_exe, tmpfile)
     verbose.report(command, 'debug')
