@@ -1,6 +1,8 @@
-from __future__ import division
+from __future__ import division, print_function
 import math
 import os
+import re
+import signal
 import sys
 
 import matplotlib
@@ -48,10 +50,17 @@ def _create_qApp():
     Only one qApp can exist at a time, so check before creating one.
     """
     if QtGui.QApplication.startingUp():
-        if DEBUG: print "Starting up QApplication"
+        if DEBUG: print("Starting up QApplication")
         global qApp
         app = QtGui.QApplication.instance()
         if app is None:
+          
+            # check for DISPLAY env variable on X11 build of Qt
+            if hasattr(QtGui, "QX11Info"):
+                display = os.environ.get('DISPLAY')
+                if display is None or not re.search(':\d', display):
+                    raise RuntimeError('Invalid DISPLAY variable')
+        
             qApp = QtGui.QApplication( [" "] )
             QtCore.QObject.connect( qApp, QtCore.SIGNAL( "lastWindowClosed()" ),
                                 qApp, QtCore.SLOT( "quit()" ) )
@@ -60,8 +69,10 @@ def _create_qApp():
 
 class Show(ShowBase):
     def mainloop(self):
-        QtGui.qApp.exec_()
+        # allow KeyboardInterrupt exceptions to close the plot window.
+        signal.signal(signal.SIGINT, signal.SIG_DFL)
 
+        QtGui.qApp.exec_()
 show = Show()
 
 
@@ -69,9 +80,16 @@ def new_figure_manager( num, *args, **kwargs ):
     """
     Create a new figure manager instance
     """
-    thisFig = Figure( *args, **kwargs )
-    canvas = FigureCanvasQT( thisFig )
-    manager = FigureManagerQT( canvas, num )
+    thisFig = Figure(*args, **kwargs)
+    return new_figure_manager_given_figure(num, thisFig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    canvas = FigureCanvasQT(figure)
+    manager = FigureManagerQT(canvas, num)
     return manager
 
 
@@ -96,12 +114,17 @@ class TimerQT(TimerBase):
         self._timer = QtCore.QTimer()
         QtCore.QObject.connect(self._timer, QtCore.SIGNAL('timeout()'),
             self._on_timer)
+        self._timer_set_interval()
 
     def __del__(self):
         # Probably not necessary in practice, but is good behavior to disconnect
-        TimerBase.__del__(self)
-        QtCore.QObject.disconnect(self._timer , QtCore.SIGNAL('timeout()'),
-            self._on_timer)
+        try:
+            TimerBase.__del__(self)
+            QtCore.QObject.disconnect(self._timer,
+                    QtCore.SIGNAL('timeout()'), self._on_timer)
+        except RuntimeError:
+            # Timer C++ object already deleted
+            pass
 
     def _timer_set_single_shot(self):
         self._timer.setSingleShot(self._single)
@@ -120,12 +143,67 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
     keyvald = { QtCore.Qt.Key_Control : 'control',
                 QtCore.Qt.Key_Shift : 'shift',
                 QtCore.Qt.Key_Alt : 'alt',
-                QtCore.Qt.Key_Return : 'enter'
+                QtCore.Qt.Key_Meta : 'super',
+                QtCore.Qt.Key_Return : 'enter',
+                QtCore.Qt.Key_Left : 'left',
+                QtCore.Qt.Key_Up : 'up',
+                QtCore.Qt.Key_Right : 'right',
+                QtCore.Qt.Key_Down : 'down',
+                QtCore.Qt.Key_Escape : 'escape',
+                QtCore.Qt.Key_F1 : 'f1',
+                QtCore.Qt.Key_F2 : 'f2',
+                QtCore.Qt.Key_F3 : 'f3',
+                QtCore.Qt.Key_F4 : 'f4',
+                QtCore.Qt.Key_F5 : 'f5',
+                QtCore.Qt.Key_F6 : 'f6',
+                QtCore.Qt.Key_F7 : 'f7',
+                QtCore.Qt.Key_F8 : 'f8',
+                QtCore.Qt.Key_F9 : 'f9',
+                QtCore.Qt.Key_F10 : 'f10',
+                QtCore.Qt.Key_F11 : 'f11',
+                QtCore.Qt.Key_F12 : 'f12',
+                QtCore.Qt.Key_Home : 'home',
+                QtCore.Qt.Key_End : 'end',
+                QtCore.Qt.Key_PageUp : 'pageup',
+                QtCore.Qt.Key_PageDown : 'pagedown',
                }
-    # left 1, middle 2, right 3
-    buttond = {1:1, 2:3, 4:2}
+
+    # define the modifier keys which are to be collected on keyboard events.
+    # format is: [(modifier_flag, modifier_name, equivalent_key)
+    _modifier_keys = [
+                      (QtCore.Qt.MetaModifier, 'super', QtCore.Qt.Key_Meta),
+                      (QtCore.Qt.AltModifier, 'alt', QtCore.Qt.Key_Alt),
+                      (QtCore.Qt.ControlModifier, 'ctrl', QtCore.Qt.Key_Control)
+                      ]
+
+    _ctrl_modifier = QtCore.Qt.ControlModifier
+
+    if sys.platform == 'darwin':
+        # in OSX, the control and super (aka cmd/apple) keys are switched, so
+        # switch them back.
+        keyvald.update({
+                        QtCore.Qt.Key_Control : 'super', # cmd/apple key
+                        QtCore.Qt.Key_Meta : 'control',
+                        })
+
+        _modifier_keys = [
+                          (QtCore.Qt.ControlModifier, 'super', QtCore.Qt.Key_Control),
+                          (QtCore.Qt.AltModifier, 'alt', QtCore.Qt.Key_Alt),
+                          (QtCore.Qt.MetaModifier, 'ctrl', QtCore.Qt.Key_Meta),
+                         ]
+
+        _ctrl_modifier = QtCore.Qt.MetaModifier
+
+    # map Qt button codes to MouseEvent's ones:
+    buttond = {QtCore.Qt.LeftButton  : 1,
+               QtCore.Qt.MidButton   : 2,
+               QtCore.Qt.RightButton : 3,
+               # QtCore.Qt.XButton1 : None,
+               # QtCore.Qt.XButton2 : None,
+               }
+
     def __init__( self, figure ):
-        if DEBUG: print 'FigureCanvasQt: ', figure
+        if DEBUG: print('FigureCanvasQt: ', figure)
         _create_qApp()
 
         QtGui.QWidget.__init__( self )
@@ -138,9 +216,6 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
         w,h = self.get_width_height()
         self.resize( w, h )
 
-        QtCore.QObject.connect(self, QtCore.SIGNAL('destroyed()'),
-            self.close_event)
-
     def __timerEvent(self, event):
         # hide until we can test and fix
         self.mpl_idle_event(event)
@@ -156,24 +231,35 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
         x = event.pos().x()
         # flipy so y=0 is bottom of canvas
         y = self.figure.bbox.height - event.pos().y()
-        button = self.buttond[event.button()]
-        FigureCanvasBase.button_press_event( self, x, y, button )
-        if DEBUG: print 'button pressed:', event.button()
+        button = self.buttond.get(event.button())
+        if button is not None:
+            FigureCanvasBase.button_press_event( self, x, y, button )
+        if DEBUG: print('button pressed:', event.button())
+
+    def mouseDoubleClickEvent(self, event):
+        x = event.pos().x()
+        # flipy so y=0 is bottom of canvas
+        y = self.figure.bbox.height - event.pos().y()
+        button = self.buttond.get(event.button())
+        if button is not None:
+            FigureCanvasBase.button_press_event( self, x, y, button, dblclick=True )
+        if DEBUG: print ('button doubleclicked:', event.button())
 
     def mouseMoveEvent( self, event ):
         x = event.x()
         # flipy so y=0 is bottom of canvas
         y = self.figure.bbox.height - event.y()
         FigureCanvasBase.motion_notify_event( self, x, y )
-        #if DEBUG: print 'mouse move'
+        #if DEBUG: print('mouse move')
 
     def mouseReleaseEvent( self, event ):
         x = event.x()
         # flipy so y=0 is bottom of canvas
         y = self.figure.bbox.height - event.y()
-        button = self.buttond[event.button()]
-        FigureCanvasBase.button_release_event( self, x, y, button )
-        if DEBUG: print 'button released'
+        button = self.buttond.get(event.button())
+        if button is not None:
+            FigureCanvasBase.button_release_event( self, x, y, button )
+        if DEBUG: print('button released')
 
     def wheelEvent( self, event ):
         x = event.x()
@@ -183,31 +269,33 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
         steps = event.delta()/120
         if (event.orientation() == QtCore.Qt.Vertical):
             FigureCanvasBase.scroll_event( self, x, y, steps)
-            if DEBUG: print 'scroll event : delta = %i, steps = %i ' % (event.delta(),steps)
+            if DEBUG: print('scroll event : delta = %i, steps = %i ' % (event.delta(),steps))
 
     def keyPressEvent( self, event ):
         key = self._get_key( event )
         if key is None:
             return
         FigureCanvasBase.key_press_event( self, key )
-        if DEBUG: print 'key press', key
+        if DEBUG: print('key press', key)
 
     def keyReleaseEvent( self, event ):
         key = self._get_key(event)
         if key is None:
             return
         FigureCanvasBase.key_release_event( self, key )
-        if DEBUG: print 'key release', key
+        if DEBUG: print('key release', key)
 
-    def resizeEvent( self, event ):
-        if DEBUG: print 'resize (%d x %d)' % (event.size().width(), event.size().height())
+    def resizeEvent(self, event):
         w = event.size().width()
         h = event.size().height()
-        if DEBUG: print "FigureCanvasQtAgg.resizeEvent(", w, ",", h, ")"
+        if DEBUG:
+            print('resize (%d x %d)' % (w, h))
+            print("FigureCanvasQt.resizeEvent(%d, %d)" % (w, h))
         dpival = self.figure.dpi
         winch = w/dpival
         hinch = h/dpival
         self.figure.set_size_inches( winch, hinch )
+        FigureCanvasBase.resize_event(self)
         self.draw()
         self.update()
         QtGui.QWidget.resizeEvent(self, event)
@@ -222,12 +310,32 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
     def _get_key( self, event ):
         if event.isAutoRepeat():
             return None
+
         if event.key() < 256:
-            key = str(event.text())
-        elif event.key() in self.keyvald:
-            key = self.keyvald[ event.key() ]
+            key = unicode(event.text())
+            # if the control key is being pressed, we don't get the correct
+            # characters, so interpret them directly from the event.key().
+            # Unfortunately, this means that we cannot handle key's case
+            # since event.key() is not case sensitive, whereas event.text() is,
+            # Finally, since it is not possible to get the CapsLock state
+            # we cannot accurately compute the case of a pressed key when
+            # ctrl+shift+p is pressed.
+            if int(event.modifiers()) & self._ctrl_modifier:
+                # we always get an uppercase character
+                key = chr(event.key())
+                # if shift is not being pressed, lowercase it (as mentioned,
+                # this does not take into account the CapsLock state)
+                if not int(event.modifiers()) & QtCore.Qt.ShiftModifier:
+                    key = key.lower()
+
         else:
-            key = None
+            key = self.keyvald.get(event.key())
+
+        if key is not None:
+            # prepend the ctrl, alt, super keys if appropriate (sorted in that order)
+            for modifier, prefix, Qt_key in self._modifier_keys:
+                if event.key() != Qt_key and int(event.modifiers()) & modifier == modifier:
+                    key = u'{0}+{1}'.format(prefix, key)
 
         return key
 
@@ -267,7 +375,14 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
             self._idle = True
         if d: QtCore.QTimer.singleShot(0, idle_draw)
 
-class FigureManagerQT( FigureManagerBase ):
+
+class MainWindow(QtGui.QMainWindow):
+    def closeEvent(self, event):
+        self.emit(QtCore.SIGNAL('closing()'))
+        QtGui.QMainWindow.closeEvent(self, event)
+
+
+class FigureManagerQT(FigureManagerBase):
     """
     Public attributes
 
@@ -277,23 +392,31 @@ class FigureManagerQT( FigureManagerBase ):
     window      : The qt.QMainWindow
     """
 
-    def __init__( self, canvas, num ):
-        if DEBUG: print 'FigureManagerQT.%s' % fn_name()
-        FigureManagerBase.__init__( self, canvas, num )
+    def __init__(self, canvas, num):
+        if DEBUG:
+            print('FigureManagerQT.%s' % fn_name())
+        FigureManagerBase.__init__(self, canvas, num)
         self.canvas = canvas
-        self.window = QtGui.QMainWindow()
-        self.window.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.window = MainWindow()
+        self.window.connect(self.window, QtCore.SIGNAL('closing()'),
+                            canvas.close_event)
+        self.window.connect(self.window, QtCore.SIGNAL('closing()'),
+                            self._widgetclosed)
 
         self.window.setWindowTitle("Figure %d" % num)
-        image = os.path.join( matplotlib.rcParams['datapath'],'images','matplotlib.png' )
-        self.window.setWindowIcon(QtGui.QIcon( image ))
+        image = os.path.join(matplotlib.rcParams['datapath'], 'images', 'matplotlib.png')
+        self.window.setWindowIcon(QtGui.QIcon(image))
 
-        # Give the keyboard focus to the figure instead of the manager
-        self.canvas.setFocusPolicy( QtCore.Qt.ClickFocus )
+        # Give the keyboard focus to the figure instead of the
+        # manager; StrongFocus accepts both tab and click to focus and
+        # will enable the canvas to process event w/o clicking.
+        # ClickFocus only takes the focus is the window has been
+        # clicked
+        # on. http://qt-project.org/doc/qt-4.8/qt.html#FocusPolicy-enum or
+        # http://doc.qt.digia.com/qt/qt.html#FocusPolicy-enum
+        self.canvas.setFocusPolicy(QtCore.Qt.StrongFocus)
         self.canvas.setFocus()
 
-        QtCore.QObject.connect( self.window, QtCore.SIGNAL( 'destroyed()' ),
-                            self._widgetclosed )
         self.window._destroying = False
 
         self.toolbar = self._get_toolbar(self.canvas, self.window)
@@ -309,29 +432,35 @@ class FigureManagerQT( FigureManagerBase ):
         # requested size:
         cs = canvas.sizeHint()
         sbs = self.window.statusBar().sizeHint()
-        self.window.resize(cs.width(), cs.height()+tbs_height+sbs.height())
+        self._status_and_tool_height = tbs_height + sbs.height()
+        height = cs.height() + self._status_and_tool_height
+        self.window.resize(cs.width(), height)
 
         self.window.setCentralWidget(self.canvas)
 
         if matplotlib.is_interactive():
             self.window.show()
 
-        # attach a show method to the figure for pylab ease of use
-        self.canvas.figure.show = lambda *args: self.window.show()
-
-        def notify_axes_change( fig ):
-           # This will be called whenever the current axes is changed
-           if self.toolbar is not None:
-               self.toolbar.update()
-        self.canvas.figure.add_axobserver( notify_axes_change )
+        def notify_axes_change(fig):
+            # This will be called whenever the current axes is changed
+            if self.toolbar is not None:
+                self.toolbar.update()
+        self.canvas.figure.add_axobserver(notify_axes_change)
 
     @QtCore.Slot()
-    def _show_message(self,s):
+    def _show_message(self, s):
         # Fixes a PySide segfault.
         self.window.statusBar().showMessage(s)
 
-    def _widgetclosed( self ):
-        if self.window._destroying: return
+    def full_screen_toggle(self):
+        if self.window.isFullScreen():
+            self.window.showNormal()
+        else:
+            self.window.showFullScreen()
+
+    def _widgetclosed(self):
+        if self.window._destroying:
+            return
         self.window._destroying = True
         try:
             Gcf.destroy(self.num)
@@ -341,12 +470,11 @@ class FigureManagerQT( FigureManagerBase ):
             # Gcf can get destroyed before the Gcf.destroy
             # line is run, leading to a useless AttributeError.
 
-
     def _get_toolbar(self, canvas, parent):
         # must be inited after the window, drawingArea and figure
         # attrs are set
         if matplotlib.rcParams['toolbar'] == 'classic':
-            print "Classic toolbar is not supported"
+            print("Classic toolbar is not supported")
         elif matplotlib.rcParams['toolbar'] == 'toolbar2':
             toolbar = NavigationToolbar2QT(canvas, parent, False)
         else:
@@ -355,20 +483,29 @@ class FigureManagerQT( FigureManagerBase ):
 
     def resize(self, width, height):
         'set the canvas size in pixels'
-        self.window.resize(width, height)
+        self.window.resize(width, height + self._status_and_tool_height)
 
     def show(self):
         self.window.show()
 
-    def destroy( self, *args ):
-        if self.window._destroying: return
+    def destroy(self, *args):
+        # check for qApp first, as PySide deletes it in its atexit handler
+        if QtGui.QApplication.instance() is None:
+            return
+        if self.window._destroying:
+            return
         self.window._destroying = True
-        QtCore.QObject.disconnect( self.window, QtCore.SIGNAL( 'destroyed()' ),
-                                   self._widgetclosed )
-        if self.toolbar: self.toolbar.destroy()
-        if DEBUG: print "destroy figure manager"
+        QtCore.QObject.disconnect(self.window, QtCore.SIGNAL('destroyed()'),
+                                  self._widgetclosed)
+        if self.toolbar:
+                self.toolbar.destroy()
+        if DEBUG:
+                print("destroy figure manager")
         self.window.close()
 
+    def get_window_title(self):
+        return str(self.window.windowTitle())
+
     def set_window_title(self, title):
         self.window.setWindowTitle(title)
 
@@ -377,6 +514,9 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
         """ coordinates: should we show the coordinates on the right? """
         self.canvas = canvas
         self.coordinates = coordinates
+        self._actions = {}
+        """A mapping of toolitem method names to their QActions"""
+
         QtGui.QToolBar.__init__( self, parent )
         NavigationToolbar2.__init__( self, canvas )
 
@@ -386,32 +526,23 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
     def _init_toolbar(self):
         self.basedir = os.path.join(matplotlib.rcParams[ 'datapath' ],'images')
 
-        a = self.addAction(self._icon('home.png'), 'Home', self.home)
-        a.setToolTip('Reset original view')
-        a = self.addAction(self._icon('back.png'), 'Back', self.back)
-        a.setToolTip('Back to previous view')
-        a = self.addAction(self._icon('forward.png'), 'Forward', self.forward)
-        a.setToolTip('Forward to next view')
-        self.addSeparator()
-        a = self.addAction(self._icon('move.png'), 'Pan', self.pan)
-        a.setToolTip('Pan axes with left mouse, zoom with right')
-        a = self.addAction(self._icon('zoom_to_rect.png'), 'Zoom', self.zoom)
-        a.setToolTip('Zoom to rectangle')
-        self.addSeparator()
-        a = self.addAction(self._icon('subplots.png'), 'Subplots',
-                self.configure_subplots)
-        a.setToolTip('Configure subplots')
+        for text, tooltip_text, image_file, callback in self.toolitems:
+            if text is None:
+                self.addSeparator()
+            else:
+                a = self.addAction(self._icon(image_file + '.png'),
+                                         text, getattr(self, callback))
+                self._actions[callback] = a
+                if callback in ['zoom', 'pan']:
+                    a.setCheckable(True)
+                if tooltip_text is not None:
+                    a.setToolTip(tooltip_text)
 
         if figureoptions is not None:
             a = self.addAction(self._icon("qt4_editor_options.png"),
                                'Customize', self.edit_parameters)
             a.setToolTip('Edit curves line and axes parameters')
 
-        a = self.addAction(self._icon('filesave.png'), 'Save',
-                self.save_figure)
-        a.setToolTip('Save the figure')
-
-
         self.buttons = {}
 
         # Add the x,y location widget at the right side of the toolbar
@@ -462,6 +593,18 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
 
             figureoptions.figure_edit(axes, self)
 
+    def _update_buttons_checked(self):
+        #sync button checkstates to match active mode
+        self._actions['pan'].setChecked(self._active == 'PAN')
+        self._actions['zoom'].setChecked(self._active == 'ZOOM')
+
+    def pan(self, *args):
+        super(NavigationToolbar2QT, self).pan(*args)
+        self._update_buttons_checked()
+
+    def zoom(self, *args):
+        super(NavigationToolbar2QT, self).zoom(*args)
+        self._update_buttons_checked()
 
     def dynamic_update( self ):
         self.canvas.draw()
@@ -472,9 +615,8 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
             self.locLabel.setText(s.replace(', ', '\n'))
 
     def set_cursor( self, cursor ):
-        if DEBUG: print 'Set cursor' , cursor
-        QtGui.QApplication.restoreOverrideCursor()
-        QtGui.QApplication.setOverrideCursor( QtGui.QCursor( cursord[cursor] ) )
+        if DEBUG: print('Set cursor' , cursor)
+        self.canvas.setCursor(cursord[cursor])
 
     def draw_rubberband( self, event, x0, y0, x1, y1 ):
         height = self.canvas.figure.bbox.height
@@ -484,13 +626,12 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
         w = abs(x1 - x0)
         h = abs(y1 - y0)
 
-        rect = [ int(val)for val in min(x0,x1), min(y0, y1), w, h ]
+        rect = [ int(val)for val in (min(x0,x1), min(y0, y1), w, h) ]
         self.canvas.drawRectangle( rect )
 
     def configure_subplots(self):
         self.adj_window = QtGui.QMainWindow()
         win = self.adj_window
-        win.setAttribute(QtCore.Qt.WA_DeleteOnClose)
 
         win.setWindowTitle("Subplot Configuration Tool")
         image = os.path.join( matplotlib.rcParams['datapath'],'images','matplotlib.png' )
@@ -511,7 +652,9 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
         sorted_filetypes.sort()
         default_filetype = self.canvas.get_default_filetype()
 
-        start = "image." + default_filetype
+        startpath = matplotlib.rcParams.get('savefig.directory', '')
+        startpath = os.path.expanduser(startpath)
+        start = os.path.join(startpath, self.canvas.get_default_filename())
         filters = []
         selectedFilter = None
         for name, exts in sorted_filetypes:
@@ -521,13 +664,18 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
                 selectedFilter = filter
             filters.append(filter)
         filters = ';;'.join(filters)
-
         fname = _getSaveFileName(self, "Choose a filename to save to",
                                         start, filters, selectedFilter)
         if fname:
+            if startpath == '':
+                # explicitly missing key or empty str signals to use cwd
+                matplotlib.rcParams['savefig.directory'] = startpath
+            else:
+                # save dir for next time
+                matplotlib.rcParams['savefig.directory'] = os.path.dirname(unicode(fname))
             try:
                 self.canvas.print_figure( unicode(fname) )
-            except Exception, e:
+            except Exception as e:
                 QtGui.QMessageBox.critical(
                     self, "Error saving file", str(e),
                     QtGui.QMessageBox.Ok, QtGui.QMessageBox.NoButton)
