@@ -1,8 +1,5 @@
-from __future__ import division
+from __future__ import division, print_function
 """
-
- backend_wx.py
-
  A wxPython backend for matplotlib, based (very heavily) on
  backend_template.py and backend_gtk.py
 
@@ -18,13 +15,17 @@ from __future__ import division
 
 """
 
-cvs_id = '$Id$'
+import sys
+import os
+import os.path
+import math
+import StringIO
+import weakref
+import warnings
 
-
-import sys, os, os.path, math, StringIO, weakref, warnings
 import numpy as np
 
-
+from matplotlib.cbook import mplDeprecation
 
 # Debugging settings here...
 # Debug level set here. If the debug level is less than 5, information
@@ -36,6 +37,11 @@ if _DEBUG < 5:
     import traceback, pdb
 _DEBUG_lvls = {1 : 'Low ', 2 : 'Med ', 3 : 'High', 4 : 'Error' }
 
+if sys.version_info[0] >= 3:
+    warnings.warn(
+        "The wx and wxagg backends have not been tested with Python 3.x",
+        ImportWarning)
+
 missingwx = "Matplotlib backend_wx and backend_wxagg require wxPython >=2.8"
 missingwxversion = ("Matplotlib backend_wx and backend_wxagg "
                     "require wxversion, which was not found.")
@@ -71,7 +77,7 @@ except ImportError:
 # there really *is* a problem with the version.
 major, minor = [int(n) for n in backend_version.split('.')[:2]]
 if major < 2 or (major < 3 and minor < 8):
-    print " wxPython version %s was imported." % backend_version
+    print(" wxPython version %s was imported." % backend_version)
     raise ImportError(missingwx)
 
 
@@ -85,12 +91,12 @@ def DEBUG_MSG(string, lvl=3, o=None):
         # one below does.  I think WX is redefining stderr, damned
         # beast
         #print >>sys.stderr, "%s- %s in %s" % (_DEBUG_lvls[lvl], string, cls)
-        print "%s- %s in %s" % (_DEBUG_lvls[lvl], string, cls)
+        print("%s- %s in %s" % (_DEBUG_lvls[lvl], string, cls))
 
 def debug_on_error(type, value, tb):
     """Code due to Thomas Heller - published in Python Cookbook (O'Reilley)"""
     traceback.print_exc(type, value, tb)
-    print
+    print()
     pdb.pm()  # jdh uncomment
 
 class fake_stderr:
@@ -98,7 +104,7 @@ class fake_stderr:
     is probably no console. This redirects stderr to the console, since we know
     that there is one!"""
     def write(self, msg):
-        print "Stderr: %s\n\r" % msg
+        print("Stderr: %s\n\r" % msg)
 
 #if _DEBUG < 5:
 #    sys.excepthook = debug_on_error
@@ -122,6 +128,7 @@ from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
      FigureCanvasBase, FigureManagerBase, NavigationToolbar2, \
      cursors, TimerBase
 from matplotlib.backend_bases import ShowBase
+from matplotlib.backend_bases import _has_pil
 
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.artist import Artist
@@ -183,7 +190,6 @@ class TimerWx(TimerBase):
 
      # Unbinding causes Wx to stop for some reason. Disabling for now.
 #    def __del__(self):
-#        import wx
 #        TimerBase.__del__(self)
 #        self.parent.Bind(wx.EVT_TIMER, None, self._timer)
 
@@ -258,6 +264,7 @@ class RendererWx(RendererBase):
         """
         Initialise a wxWindows renderer instance.
         """
+        RendererBase.__init__(self)
         DEBUG_MSG("__init__()", 1, self)
         if wx.VERSION_STRING < "2.8":
             raise RuntimeError("matplotlib no longer supports wxPython < 2.8 for the Wx backend.\nYou may, however, use the WxAgg backend.")
@@ -357,11 +364,7 @@ class RendererWx(RendererBase):
         gc.gfx_ctx.DrawBitmap(bitmap,int(l),int(self.height-b),int(w),int(-h))
         gc.unselect()
 
-    def draw_text(self, gc, x, y, s, prop, angle, ismath):
-        """
-        Render the matplotlib.text.Text instance
-        None)
-        """
+    def draw_text(self, gc, x, y, s, prop, angle, ismath=False, mtext=None):
         if ismath: s = self.strip_math(s)
         DEBUG_MSG("draw_text()", 1, self)
         gc.select()
@@ -405,7 +408,6 @@ class RendererWx(RendererBase):
         assert self.gc != None, "gc must be defined"
         return self.gc
 
-
     def get_wx_font(self, s, prop):
         """
         Return a wx font.  Cache instances in a font dictionary for
@@ -443,7 +445,6 @@ class RendererWx(RendererBase):
 
         return font
 
-
     def points_to_pixels(self, points):
         """
         convert point measures to pixes using dpi and the pixels per
@@ -451,6 +452,7 @@ class RendererWx(RendererBase):
         """
         return points*(PIXELS_PER_INCH/72.0*self.dpi/72.0)
 
+
 class GraphicsContextWx(GraphicsContextBase):
     """
     The graphics context provides the color, line styles, etc...
@@ -517,7 +519,7 @@ class GraphicsContextWx(GraphicsContextBase):
             self.dc.SelectObject(wx.NullBitmap)
             self.IsSelected = False
 
-    def set_foreground(self, fg, isRGB=None):
+    def set_foreground(self, fg, isRGBA=None):
         """
         Set the foreground color.  fg can be a matlab format string, a
         html hex color string, an rgb unit tuple, or a float between 0
@@ -530,7 +532,7 @@ class GraphicsContextWx(GraphicsContextBase):
         # Same goes for text foreground...
         DEBUG_MSG("set_foreground()", 1, self)
         self.select()
-        GraphicsContextBase.set_foreground(self, fg, isRGB)
+        GraphicsContextBase.set_foreground(self, fg, isRGBA)
 
         self._pen.SetColour(self.get_wxcolour(self.get_rgb()))
         self.gfx_ctx.SetPen(self._pen)
@@ -622,6 +624,7 @@ class GraphicsContextWx(GraphicsContextBase):
             a *= 255
             return wx.Colour(red=int(r), green=int(g), blue=int(b), alpha=int(a))
 
+
 class FigureCanvasWx(FigureCanvasBase, wx.Panel):
     """
     The FigureCanvas contains the figure and does event handling.
@@ -741,11 +744,11 @@ class FigureCanvasWx(FigureCanvasBase, wx.Panel):
         bind(self, wx.EVT_KEY_DOWN, self._onKeyDown)
         bind(self, wx.EVT_KEY_UP, self._onKeyUp)
         bind(self, wx.EVT_RIGHT_DOWN, self._onRightButtonDown)
-        bind(self, wx.EVT_RIGHT_DCLICK, self._onRightButtonDown)
+        bind(self, wx.EVT_RIGHT_DCLICK, self._onRightButtonDClick)
         bind(self, wx.EVT_RIGHT_UP, self._onRightButtonUp)
         bind(self, wx.EVT_MOUSEWHEEL, self._onMouseWheel)
         bind(self, wx.EVT_LEFT_DOWN, self._onLeftButtonDown)
-        bind(self, wx.EVT_LEFT_DCLICK, self._onLeftButtonDown)
+        bind(self, wx.EVT_LEFT_DCLICK, self._onLeftButtonDClick)
         bind(self, wx.EVT_LEFT_UP, self._onLeftButtonUp)
         bind(self, wx.EVT_MOTION, self._onMotion)
         bind(self, wx.EVT_LEAVE_WINDOW, self._onLeave)
@@ -753,7 +756,7 @@ class FigureCanvasWx(FigureCanvasBase, wx.Panel):
         bind(self, wx.EVT_IDLE, self._onIdle)
         #Add middle button events
         bind(self, wx.EVT_MIDDLE_DOWN, self._onMiddleButtonDown)
-        bind(self, wx.EVT_MIDDLE_DCLICK, self._onMiddleButtonDown)
+        bind(self, wx.EVT_MIDDLE_DCLICK, self._onMiddleButtonDClick)
         bind(self, wx.EVT_MIDDLE_UP, self._onMiddleButtonUp)
 
         self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)
@@ -774,194 +777,13 @@ class FigureCanvasWx(FigureCanvasBase, wx.Panel):
         "copy bitmap of canvas to system clipboard"
         bmp_obj = wx.BitmapDataObject()
         bmp_obj.SetBitmap(self.bitmap)
-        wx.TheClipboard.Open()
-        wx.TheClipboard.SetData(bmp_obj)
-        wx.TheClipboard.Close()
-        wx.TheClipboard.Flush()
 
-    def Printer_Init(self):
-        """
-        initialize printer settings using wx methods
-
-        Deprecated.
-        """
-        warnings.warn("Printer* methods will be removed", DeprecationWarning)
-        self.printerData = wx.PrintData()
-        self.printerData.SetPaperId(wx.PAPER_LETTER)
-        self.printerData.SetPrintMode(wx.PRINT_MODE_PRINTER)
-        self.printerPageData= wx.PageSetupDialogData()
-        self.printerPageData.SetMarginBottomRight((25,25))
-        self.printerPageData.SetMarginTopLeft((25,25))
-        self.printerPageData.SetPrintData(self.printerData)
-
-        self.printer_width = 5.5
-        self.printer_margin= 0.5
-
-    def _get_printerData(self):
-        if self._printerData is None:
-            warnings.warn("Printer* methods will be removed", DeprecationWarning)
-            self._printerData = wx.PrintData()
-            self._printerData.SetPaperId(wx.PAPER_LETTER)
-            self._printerData.SetPrintMode(wx.PRINT_MODE_PRINTER)
-        return self._printerData
-    printerData = property(_get_printerData)
-
-    def _get_printerPageData(self):
-        if self._printerPageData is None:
-            warnings.warn("Printer* methods will be removed", DeprecationWarning)
-            self._printerPageData= wx.PageSetupDialogData()
-            self._printerPageData.SetMarginBottomRight((25,25))
-            self._printerPageData.SetMarginTopLeft((25,25))
-            self._printerPageData.SetPrintData(self.printerData)
-        return self._printerPageData
-    printerPageData = property(_get_printerPageData)
-
-    def Printer_Setup(self, event=None):
-        """
-        set up figure for printing.  The standard wx Printer
-        Setup Dialog seems to die easily. Therefore, this setup
-        simply asks for image width and margin for printing.
-        Deprecated.
-        """
-
-        dmsg = """Width of output figure in inches.
-The current aspect ratio will be kept."""
-
-        warnings.warn("Printer* methods will be removed", DeprecationWarning)
-        dlg = wx.Dialog(self, -1, 'Page Setup for Printing' , (-1,-1))
-        df = dlg.GetFont()
-        df.SetWeight(wx.NORMAL)
-        df.SetPointSize(11)
-        dlg.SetFont(df)
-
-        x_wid = wx.TextCtrl(dlg,-1,value="%.2f" % self.printer_width, size=(70,-1))
-        x_mrg = wx.TextCtrl(dlg,-1,value="%.2f" % self.printer_margin,size=(70,-1))
-
-        sizerAll = wx.BoxSizer(wx.VERTICAL)
-        sizerAll.Add(wx.StaticText(dlg,-1,dmsg),
-                    0, wx.ALL | wx.EXPAND, 5)
-
-        sizer = wx.FlexGridSizer(0,3)
-        sizerAll.Add(sizer, 0, wx.ALL | wx.EXPAND, 5)
-
-        sizer.Add(wx.StaticText(dlg,-1,'Figure Width'),
-                    1, wx.ALIGN_LEFT|wx.ALL, 2)
-        sizer.Add(x_wid,
-                    1, wx.ALIGN_LEFT|wx.ALL, 2)
-        sizer.Add(wx.StaticText(dlg,-1,'in'),
-                    1, wx.ALIGN_LEFT|wx.ALL, 2)
-
-        sizer.Add(wx.StaticText(dlg,-1,'Margin'),
-                    1, wx.ALIGN_LEFT|wx.ALL, 2)
-        sizer.Add(x_mrg,
-                    1, wx.ALIGN_LEFT|wx.ALL, 2)
-        sizer.Add(wx.StaticText(dlg,-1,'in'),
-                    1, wx.ALIGN_LEFT|wx.ALL, 2)
-
-        btn = wx.Button(dlg,wx.ID_OK, " OK ")
-        btn.SetDefault()
-        sizer.Add(btn, 1, wx.ALIGN_LEFT, 5)
-        btn = wx.Button(dlg,wx.ID_CANCEL, " CANCEL ")
-        sizer.Add(btn, 1, wx.ALIGN_LEFT, 5)
-
-        dlg.SetSizer(sizerAll)
-        dlg.SetAutoLayout(True)
-        sizerAll.Fit(dlg)
-
-        if dlg.ShowModal() == wx.ID_OK:
-            try:
-                self.printer_width  = float(x_wid.GetValue())
-                self.printer_margin = float(x_mrg.GetValue())
-            except:
-                pass
-
-        if ((self.printer_width + self.printer_margin) > 7.5):
-            self.printerData.SetOrientation(wx.LANDSCAPE)
-        else:
-            self.printerData.SetOrientation(wx.PORTRAIT)
-        dlg.Destroy()
-        return
-
-    def Printer_Setup2(self, event=None):
-        """
-        set up figure for printing.  Using the standard wx Printer
-        Setup Dialog.
-
-        Deprecated.
-        """
-
-        warnings.warn("Printer* methods will be removed", DeprecationWarning)
-        if hasattr(self, 'printerData'):
-            data = wx.PageSetupDialogData()
-            data.SetPrintData(self.printerData)
-        else:
-            data = wx.PageSetupDialogData()
-        data.SetMarginTopLeft( (15, 15) )
-        data.SetMarginBottomRight( (15, 15) )
-
-        dlg = wx.PageSetupDialog(self, data)
-
-        if dlg.ShowModal() == wx.ID_OK:
-            data = dlg.GetPageSetupData()
-            tl = data.GetMarginTopLeft()
-            br = data.GetMarginBottomRight()
-        self.printerData = wx.PrintData(data.GetPrintData())
-        dlg.Destroy()
-
-    def Printer_Preview(self, event=None):
-        """
-        generate Print Preview with wx Print mechanism
-
-        Deprecated.
-        """
-        warnings.warn("Printer* methods will be removed", DeprecationWarning)
-        po1  = PrintoutWx(self, width=self.printer_width,
-                          margin=self.printer_margin)
-        po2  = PrintoutWx(self, width=self.printer_width,
-                          margin=self.printer_margin)
-        self.preview = wx.PrintPreview(po1,po2,self.printerData)
-        if not self.preview.Ok():  print "error with preview"
-
-        self.preview.SetZoom(50)
-        frameInst= self
-        while not isinstance(frameInst, wx.Frame):
-            frameInst= frameInst.GetParent()
-        frame = wx.PreviewFrame(self.preview, frameInst, "Preview")
-        frame.Initialize()
-        frame.SetPosition(self.GetPosition())
-        frame.SetSize((850,650))
-        frame.Centre(wx.BOTH)
-        frame.Show(True)
-        self.gui_repaint()
-
-    def Printer_Print(self, event=None):
-        """
-        Print figure using wx Print mechanism
-
-        Deprecated.
-        """
-        warnings.warn("Printer* methods will be removed", DeprecationWarning)
-        pdd = wx.PrintDialogData()
-        # SetPrintData for 2.4 combatibility
-        pdd.SetPrintData(self.printerData)
-        pdd.SetToPage(1)
-        printer  = wx.Printer(pdd)
-        printout  = PrintoutWx(self, width=int(self.printer_width),
-                               margin=int(self.printer_margin))
-        print_ok = printer.Print(self, printout, True)
-
-        if wx.VERSION_STRING >= '2.5':
-            if not print_ok and not printer.GetLastError() == wx.PRINTER_CANCELLED:
-                wx.MessageBox("""There was a problem printing.
-                Perhaps your current printer is not set correctly?""",
-                              "Printing", wx.OK)
-        else:
-            if not print_ok:
-                wx.MessageBox("""There was a problem printing.
-                Perhaps your current printer is not set correctly?""",
-                              "Printing", wx.OK)
-        printout.Destroy()
-        self.gui_repaint()
+        if not wx.TheClipboard.IsOpened():
+           open_success = wx.TheClipboard.Open()
+           if open_success:
+              wx.TheClipboard.SetData(bmp_obj)
+              wx.TheClipboard.Close()
+              wx.TheClipboard.Flush()
 
     def draw_idle(self):
         """
@@ -1128,9 +950,10 @@ The current aspect ratio will be kept."""
     def print_bmp(self, filename, *args, **kwargs):
         return self._print_image(filename, wx.BITMAP_TYPE_BMP, *args, **kwargs)
 
-    def print_jpeg(self, filename, *args, **kwargs):
-        return self._print_image(filename, wx.BITMAP_TYPE_JPEG, *args, **kwargs)
-    print_jpg = print_jpeg
+    if not _has_pil:
+        def print_jpeg(self, filename, *args, **kwargs):
+            return self._print_image(filename, wx.BITMAP_TYPE_JPEG, *args, **kwargs)
+        print_jpg = print_jpeg
 
     def print_pcx(self, filename, *args, **kwargs):
         return self._print_image(filename, wx.BITMAP_TYPE_PCX, *args, **kwargs)
@@ -1138,9 +961,10 @@ The current aspect ratio will be kept."""
     def print_png(self, filename, *args, **kwargs):
         return self._print_image(filename, wx.BITMAP_TYPE_PNG, *args, **kwargs)
 
-    def print_tiff(self, filename, *args, **kwargs):
-        return self._print_image(filename, wx.BITMAP_TYPE_TIF, *args, **kwargs)
-    print_tif = print_tiff
+    if not _has_pil:
+        def print_tiff(self, filename, *args, **kwargs):
+            return self._print_image(filename, wx.BITMAP_TYPE_TIF, *args, **kwargs)
+        print_tif = print_tiff
 
     def print_xpm(self, filename, *args, **kwargs):
         return self._print_image(filename, wx.BITMAP_TYPE_XPM, *args, **kwargs)
@@ -1159,14 +983,26 @@ The current aspect ratio will be kept."""
 
         self.figure.draw(renderer)
 
+        # image is the object that we call SaveFile on.
+        image = self.bitmap
+        # set the JPEG quality appropriately.  Unfortunately, it is only possible
+        # to set the quality on a wx.Image object.  So if we are saving a JPEG,
+        # convert the wx.Bitmap to a wx.Image, and set the quality.
+        if filetype == wx.BITMAP_TYPE_JPEG:
+           jpeg_quality = kwargs.get('quality',rcParams['savefig.jpeg_quality'])
+           image = self.bitmap.ConvertToImage()
+           image.SetOption(wx.IMAGE_OPTION_QUALITY,str(jpeg_quality))
+
         # Now that we have rendered into the bitmap, save it
         # to the appropriate file type and clean up
         if is_string_like(filename):
-            if not self.bitmap.SaveFile(filename, filetype):
+            if not image.SaveFile(filename, filetype):
                 DEBUG_MSG('print_figure() file save error', 4, self)
                 raise RuntimeError('Could not save figure to %s\n' % (filename))
         elif is_writable_file_like(filename):
-            if not self.bitmap.ConvertToImage().SaveStream(filename, filetype):
+            if not isinstance(image,wx.Image):
+               image = image.ConvertToImage()
+            if not image.SaveStream(filename, filetype):
                 DEBUG_MSG('print_figure() file save error', 4, self)
                 raise RuntimeError('Could not save figure to %s\n' % (filename))
 
@@ -1182,9 +1018,6 @@ The current aspect ratio will be kept."""
             self.draw()
         self.Refresh()
 
-    def get_default_filetype(self):
-        return 'png'
-
     def _onPaint(self, evt):
         """
         Called when wxPaintEvt is generated
@@ -1237,13 +1070,20 @@ The current aspect ratio will be kept."""
         keyval = evt.m_keyCode
         if keyval in self.keyvald:
             key = self.keyvald[keyval]
-        elif keyval <256:
+        elif keyval < 256:
             key = chr(keyval)
+            # wx always returns an uppercase, so make it lowercase if the shift
+            # key is not depressed (NOTE: this will not handle Caps Lock)
+            if not evt.ShiftDown():
+                key = key.lower()
         else:
             key = None
 
-        # why is wx upcasing this?
-        if key is not None: key = key.lower()
+        for meth, prefix in (
+                             [evt.AltDown, 'alt'],
+                             [evt.ControlDown, 'ctrl'], ):
+            if meth():
+                key = '{0}+{1}'.format(prefix, key)
 
         return key
 
@@ -1273,6 +1113,13 @@ The current aspect ratio will be kept."""
         self.CaptureMouse()
         FigureCanvasBase.button_press_event(self, x, y, 3, guiEvent=evt)
 
+    def _onRightButtonDClick(self, evt):
+        """Start measuring on an axis."""
+        x = evt.GetX()
+        y = self.figure.bbox.height - evt.GetY()
+        evt.Skip()
+        self.CaptureMouse()
+        FigureCanvasBase.button_press_event(self, x, y, 3, dblclick=True,guiEvent=evt)
 
     def _onRightButtonUp(self, evt):
         """End measuring on an axis."""
@@ -1290,6 +1137,14 @@ The current aspect ratio will be kept."""
         self.CaptureMouse()
         FigureCanvasBase.button_press_event(self, x, y, 1, guiEvent=evt)
 
+    def _onLeftButtonDClick(self, evt):
+        """Start measuring on an axis."""
+        x = evt.GetX()
+        y = self.figure.bbox.height - evt.GetY()
+        evt.Skip()
+        self.CaptureMouse()
+        FigureCanvasBase.button_press_event(self, x, y, 1, dblclick=True, guiEvent=evt)
+
     def _onLeftButtonUp(self, evt):
         """End measuring on an axis."""
         x = evt.GetX()
@@ -1308,6 +1163,14 @@ The current aspect ratio will be kept."""
         self.CaptureMouse()
         FigureCanvasBase.button_press_event(self, x, y, 2, guiEvent=evt)
 
+    def _onMiddleButtonDClick(self, evt):
+        """Start measuring on an axis."""
+        x = evt.GetX()
+        y = self.figure.bbox.height - evt.GetY()
+        evt.Skip()
+        self.CaptureMouse()
+        FigureCanvasBase.button_press_event(self, x, y, 2, dblclick=True, guiEvent=evt)
+
     def _onMiddleButtonUp(self, evt):
         """End measuring on an axis."""
         x = evt.GetX()
@@ -1377,11 +1240,11 @@ The current aspect ratio will be kept."""
 
 def _create_wx_app():
     """
-    Creates a wx.PySimpleApp instance if a wx.App has not been created.
+    Creates a wx.App instance if it has not been created sofar.
     """
     wxapp = wx.GetApp()
     if wxapp is None:
-        wxapp = wx.PySimpleApp()
+        wxapp = wx.App(False)
         wxapp.SetExitOnFrameDelete(True)
         # retain a reference to the app object so it does not get garbage
         # collected and cause segmentation faults
@@ -1422,6 +1285,14 @@ def new_figure_manager(num, *args, **kwargs):
 
     FigureClass = kwargs.pop('FigureClass', Figure)
     fig = FigureClass(*args, **kwargs)
+    return new_figure_manager_given_figure(num, fig)
+
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    fig = figure
     frame = FigureFrameWx(num, fig)
     figmgr = frame.get_figure_manager()
     if matplotlib.is_interactive():
@@ -1429,6 +1300,7 @@ def new_figure_manager(num, *args, **kwargs):
 
     return figmgr
 
+
 class FigureFrameWx(wx.Frame):
     def __init__(self, num, fig):
         # On non-Windows platform, explicitly set the position - fix
@@ -1448,6 +1320,7 @@ class FigureFrameWx(wx.Frame):
         self.SetStatusBar(statbar)
         self.canvas = self.get_canvas(fig)
         self.canvas.SetInitialSize(wx.Size(fig.bbox.width, fig.bbox.height))
+        self.canvas.SetFocus()
         self.sizer =wx.BoxSizer(wx.VERTICAL)
         self.sizer.Add(self.canvas, 1, wx.TOP | wx.LEFT | wx.EXPAND)
         # By adding toolbar in sizer, we are able to put it at the bottom
@@ -1457,34 +1330,36 @@ class FigureFrameWx(wx.Frame):
 
         if self.toolbar is not None:
             self.toolbar.Realize()
-            if wx.Platform == '__WXMAC__':
-                # Mac platform (OSX 10.3, MacPython) does not seem to cope with
-                # having a toolbar in a sizer. This work-around gets the buttons
-                # back, but at the expense of having the toolbar at the top
-                self.SetToolBar(self.toolbar)
-            else:
-                # On Windows platform, default window size is incorrect, so set
-                # toolbar width to figure width.
-                tw, th = self.toolbar.GetSizeTuple()
-                fw, fh = self.canvas.GetSizeTuple()
-                # By adding toolbar in sizer, we are able to put it at the bottom
-                # of the frame - so appearance is closer to GTK version.
-                # As noted above, doesn't work for Mac.
-                self.toolbar.SetSize(wx.Size(fw, th))
-                self.sizer.Add(self.toolbar, 0, wx.LEFT | wx.EXPAND)
+            # On Windows platform, default window size is incorrect, so set
+            # toolbar width to figure width.
+            tw, th = self.toolbar.GetSizeTuple()
+            fw, fh = self.canvas.GetSizeTuple()
+            # By adding toolbar in sizer, we are able to put it at the bottom
+            # of the frame - so appearance is closer to GTK version.
+            self.toolbar.SetSize(wx.Size(fw, th))
+            self.sizer.Add(self.toolbar, 0, wx.LEFT | wx.EXPAND)
         self.SetSizer(self.sizer)
         self.Fit()
 
         self.canvas.SetMinSize((2, 2))
 
+        # give the window a matplotlib icon rather than the stock one.
+        # This is not currently working on Linux and is untested elsewhere.
+        #icon_path = os.path.join(matplotlib.rcParams['datapath'],
+        #                         'images', 'matplotlib.png')
+        #icon = wx.IconFromBitmap(wx.Bitmap(icon_path))
+        # for xpm type icons try:
+        #icon = wx.Icon(icon_path, wx.BITMAP_TYPE_XPM)
+        #self.SetIcon(icon)
+
         self.figmgr = FigureManagerWx(self.canvas, num, self)
 
         bind(self, wx.EVT_CLOSE, self._onClose)
 
     def _get_toolbar(self, statbar):
-        if matplotlib.rcParams['toolbar']=='classic':
+        if rcParams['toolbar']=='classic':
             toolbar = NavigationToolbarWx(self.canvas, True)
-        elif matplotlib.rcParams['toolbar']=='toolbar2':
+        elif rcParams['toolbar']=='toolbar2':
             toolbar = NavigationToolbar2Wx(self.canvas)
             toolbar.set_status_bar(statbar)
         else:
@@ -1523,6 +1398,7 @@ class FigureFrameWx(wx.Frame):
             wxapp.Yield()
         return True
 
+
 class FigureManagerWx(FigureManagerBase):
     """
     This class contains the FigureCanvas and GUI frame
@@ -1530,8 +1406,6 @@ class FigureManagerWx(FigureManagerBase):
     It is instantiated by GcfWx whenever a new figure is created. GcfWx is
     responsible for managing multiple instances of FigureManagerWx.
 
-    NB: FigureManagerBase is found in _pylab_helpers
-
     public attrs
 
     canvas - a FigureCanvasWx(wx.Panel) instance
@@ -1550,12 +1424,6 @@ class FigureManagerWx(FigureManagerBase):
             if self.tb != None: self.tb.update()
         self.canvas.figure.add_axobserver(notify_axes_change)
 
-        def showfig(*args):
-            frame.Show()
-
-        # attach a show method to the figure
-        self.canvas.figure.show = showfig
-
     def show(self):
         self.frame.Show()
 
@@ -1563,10 +1431,12 @@ class FigureManagerWx(FigureManagerBase):
         DEBUG_MSG("destroy()", 1, self)
         self.frame.Destroy()
         #if self.tb is not None: self.tb.Destroy()
-        import wx
         #wx.GetApp().ProcessIdle()
         wx.WakeUpIdle()
 
+    def get_window_title(self):
+        return self.window.GetTitle()
+
     def set_window_title(self, title):
         self.window.SetTitle(title)
 
@@ -1714,8 +1584,6 @@ class MenuButtonWx(wx.Button):
         self.SetLabel("Axes: %s" % axis_txt[:-1])
 
 
-
-
 cursord = {
     cursors.MOVE : wx.CURSOR_HAND,
     cursors.HAND : wx.CURSOR_HAND,
@@ -1759,57 +1627,33 @@ class NavigationToolbar2Wx(NavigationToolbar2, wx.ToolBar):
         DEBUG_MSG("_init_toolbar", 1, self)
 
         self._parent = self.canvas.GetParent()
-        _NTB2_HOME    =wx.NewId()
-        self._NTB2_BACK    =wx.NewId()
-        self._NTB2_FORWARD =wx.NewId()
-        self._NTB2_PAN     =wx.NewId()
-        self._NTB2_ZOOM    =wx.NewId()
-        _NTB2_SAVE    = wx.NewId()
-        _NTB2_SUBPLOT    =wx.NewId()
 
-        self.SetToolBitmapSize(wx.Size(24,24))
 
-        self.AddSimpleTool(_NTB2_HOME, _load_bitmap('home.png'),
-                           'Home', 'Reset original view')
-        self.AddSimpleTool(self._NTB2_BACK, _load_bitmap('back.png'),
-                           'Back', 'Back navigation view')
-        self.AddSimpleTool(self._NTB2_FORWARD, _load_bitmap('forward.png'),
-                           'Forward', 'Forward navigation view')
-        # todo: get new bitmap
-        self.AddCheckTool(self._NTB2_PAN, _load_bitmap('move.png'),
-                           shortHelp='Pan',
-                           longHelp='Pan with left, zoom with right')
-        self.AddCheckTool(self._NTB2_ZOOM, _load_bitmap('zoom_to_rect.png'),
-                           shortHelp='Zoom', longHelp='Zoom to rectangle')
-
-        self.AddSeparator()
-        self.AddSimpleTool(_NTB2_SUBPLOT, _load_bitmap('subplots.png'),
-                           'Configure subplots', 'Configure subplot parameters')
-
-        self.AddSimpleTool(_NTB2_SAVE, _load_bitmap('filesave.png'),
-                           'Save', 'Save plot contents to file')
-
-        bind(self, wx.EVT_TOOL, self.home, id=_NTB2_HOME)
-        bind(self, wx.EVT_TOOL, self.forward, id=self._NTB2_FORWARD)
-        bind(self, wx.EVT_TOOL, self.back, id=self._NTB2_BACK)
-        bind(self, wx.EVT_TOOL, self.zoom, id=self._NTB2_ZOOM)
-        bind(self, wx.EVT_TOOL, self.pan, id=self._NTB2_PAN)
-        bind(self, wx.EVT_TOOL, self.configure_subplot, id=_NTB2_SUBPLOT)
-        bind(self, wx.EVT_TOOL, self.save, id=_NTB2_SAVE)
+        self.wx_ids = {}
+        for text, tooltip_text, image_file, callback in self.toolitems:
+            if text is None:
+                self.AddSeparator()
+                continue
+            self.wx_ids[text] = wx.NewId()
+            if text in ['Pan', 'Zoom']:
+               self.AddCheckTool(self.wx_ids[text], _load_bitmap(image_file + '.png'),
+                                 shortHelp=text, longHelp=tooltip_text)
+            else:
+               self.AddSimpleTool(self.wx_ids[text], _load_bitmap(image_file + '.png'),
+                                  text, tooltip_text)
+            bind(self, wx.EVT_TOOL, getattr(self, callback), id=self.wx_ids[text])
 
         self.Realize()
 
-
     def zoom(self, *args):
-        self.ToggleTool(self._NTB2_PAN, False)
+        self.ToggleTool(self.wx_ids['Pan'], False)
         NavigationToolbar2.zoom(self, *args)
 
     def pan(self, *args):
-        self.ToggleTool(self._NTB2_ZOOM, False)
+        self.ToggleTool(self.wx_ids['Zoom'], False)
         NavigationToolbar2.pan(self, *args)
 
-
-    def configure_subplot(self, evt):
+    def configure_subplots(self, evt):
         frame = wx.Frame(None, -1, "Configure subplots")
 
         toolfig = Figure((6,3))
@@ -1827,10 +1671,10 @@ class NavigationToolbar2Wx(NavigationToolbar2, wx.ToolBar):
         tool = SubplotTool(self.canvas.figure, toolfig)
         frame.Show()
 
-    def save(self, evt):
+    def save_figure(self, *args):
         # Fetch the required filename and file type.
         filetypes, exts, filter_index = self.canvas._get_imagesave_wildcards()
-        default_file = "image." + self.canvas.get_default_filetype()
+        default_file = self.canvas.get_default_filename()
         dlg = wx.FileDialog(self._parent, "Save to file", "", default_file,
                             filetypes,
                             wx.SAVE|wx.OVERWRITE_PROMPT)
@@ -1851,7 +1695,7 @@ class NavigationToolbar2Wx(NavigationToolbar2, wx.ToolBar):
             try:
                 self.canvas.print_figure(
                     os.path.join(dirname, filename), format=format)
-            except Exception, e:
+            except Exception as e:
                 error_msg_wx(str(e))
 
     def set_cursor(self, cursor):
@@ -1920,17 +1764,12 @@ class NavigationToolbar2Wx(NavigationToolbar2, wx.ToolBar):
     def set_history_buttons(self):
         can_backward = (self._views._pos > 0)
         can_forward = (self._views._pos < len(self._views._elements) - 1)
-        self.EnableTool(self._NTB2_BACK, can_backward)
-        self.EnableTool(self._NTB2_FORWARD, can_forward)
+        self.EnableTool(self.wx_ids['Back'], can_backward)
+        self.EnableTool(self.wx_ids['Forward'], can_forward)
 
 
 class NavigationToolbarWx(wx.ToolBar):
     def __init__(self, canvas, can_kill=False):
-        """
-        figure is the Figure instance that the toolboar controls
-
-        win, if not None, is the wxWindow the Figure is embedded in
-        """
         wx.ToolBar.__init__(self, canvas.GetParent(), -1)
         DEBUG_MSG("__init__()", 1, self)
         self.canvas = canvas
@@ -2055,7 +1894,7 @@ class NavigationToolbarWx(wx.ToolBar):
 
     def update(self):
         """
-        Update the toolbar menu - called when (e.g.) a new subplot
+        Update the toolbar menu - e.g., called when a new subplot
         or axes are added
         """
         DEBUG_MSG("update()", 1, self)
@@ -2121,13 +1960,12 @@ class NavigationToolbarWx(wx.ToolBar):
             direction = -1
         self.button_fn(direction)
 
-    _onSave = NavigationToolbar2Wx.save
+    _onSave = NavigationToolbar2Wx.save_figure
 
     def _onClose(self, evt):
         self.GetParent().Destroy()
 
 
-
 class StatusBarWx(wx.StatusBar):
     """
     A status bar is added to _FigureFrame to allow measurements and the
