@@ -1,21 +1,4 @@
-from __future__ import division
-"""
-
- backend_wxagg.py
-
- A wxPython backend for Agg.  This uses the GUI widgets written by
- Jeremy O'Donoghue (jeremy@o-donoghue.com) and the Agg backend by John
- Hunter (jdhunter@ace.bsd.uchicago.edu)
-
- Copyright (C) 2003-5 Jeremy O'Donoghue, John Hunter, Illinois Institute of
- Technology
-
-
- License: This work is licensed under the matplotlib license( PSF
- compatible). A copy should be included with this source code.
-
-"""
-
+from __future__ import division, print_function
 import matplotlib
 from matplotlib.figure import Figure
 
@@ -26,6 +9,7 @@ from backend_wx import FigureManager, FigureManagerWx, FigureCanvasWx, \
     draw_if_interactive, show, Toolbar, backend_version
 import wx
 
+
 class FigureFrameWxAgg(FigureFrameWx):
     def get_canvas(self, fig):
         return FigureCanvasWxAgg(self, -1, fig)
@@ -40,6 +24,7 @@ class FigureFrameWxAgg(FigureFrameWx):
             toolbar = None
         return toolbar
 
+
 class FigureCanvasWxAgg(FigureCanvasAgg, FigureCanvasWx):
     """
     The FigureCanvas contains the figure and does event handling.
@@ -105,6 +90,7 @@ class FigureCanvasWxAgg(FigureCanvasAgg, FigureCanvasWx):
         if self._isDrawn:
             self.draw()
 
+
 class NavigationToolbar2WxAgg(NavigationToolbar2Wx):
     def get_canvas(self, frame, fig):
         return FigureCanvasWxAgg(frame, -1, fig)
@@ -121,85 +107,25 @@ def new_figure_manager(num, *args, **kwargs):
 
     FigureClass = kwargs.pop('FigureClass', Figure)
     fig = FigureClass(*args, **kwargs)
-    frame = FigureFrameWxAgg(num, fig)
+
+    return new_figure_manager_given_figure(num, fig)
+
+def new_figure_manager_given_figure(num, figure):
+    """
+    Create a new figure manager instance for the given figure.
+    """
+    frame = FigureFrameWxAgg(num, figure)
     figmgr = frame.get_figure_manager()
     if matplotlib.is_interactive():
         figmgr.frame.Show()
     return figmgr
 
 
-#
-# agg/wxPython image conversion functions (wxPython <= 2.6)
-#
-
-def _py_convert_agg_to_wx_image(agg, bbox):
-    """
-    Convert the region of the agg buffer bounded by bbox to a wx.Image.  If
-    bbox is None, the entire buffer is converted.
-
-    Note: agg must be a backend_agg.RendererAgg instance.
-    """
-    image = wx.EmptyImage(int(agg.width), int(agg.height))
-    image.SetData(agg.tostring_rgb())
-
-    if bbox is None:
-        # agg => rgb -> image
-        return image
-    else:
-        # agg => rgb -> image => bitmap => clipped bitmap => image
-        return wx.ImageFromBitmap(_clipped_image_as_bitmap(image, bbox))
-
-
-def _py_convert_agg_to_wx_bitmap(agg, bbox):
-    """
-    Convert the region of the agg buffer bounded by bbox to a wx.Bitmap.  If
-    bbox is None, the entire buffer is converted.
-
-    Note: agg must be a backend_agg.RendererAgg instance.
-    """
-    if bbox is None:
-        # agg => rgb -> image => bitmap
-        return wx.BitmapFromImage(_py_convert_agg_to_wx_image(agg, None))
-    else:
-        # agg => rgb -> image => bitmap => clipped bitmap
-        return _clipped_image_as_bitmap(
-            _py_convert_agg_to_wx_image(agg, None),
-            bbox)
-
-
-def _clipped_image_as_bitmap(image, bbox):
-    """
-    Convert the region of a wx.Image bounded by bbox to a wx.Bitmap.
-    """
-    l, b, width, height = bbox.bounds
-    r = l + width
-    t = b + height
-
-    srcBmp = wx.BitmapFromImage(image)
-    srcDC = wx.MemoryDC()
-    srcDC.SelectObject(srcBmp)
-
-    destBmp = wx.EmptyBitmap(int(width), int(height))
-    destDC = wx.MemoryDC()
-    destDC.SelectObject(destBmp)
-
-    destDC.BeginDrawing()
-    x = int(l)
-    y = int(image.GetHeight() - t)
-    destDC.Blit(0, 0, int(width), int(height), srcDC, x, y)
-    destDC.EndDrawing()
-
-    srcDC.SelectObject(wx.NullBitmap)
-    destDC.SelectObject(wx.NullBitmap)
-
-    return destBmp
-
-
 #
 # agg/wxPython image conversion functions (wxPython >= 2.8)
 #
 
-def _py_WX28_convert_agg_to_wx_image(agg, bbox):
+def _convert_agg_to_wx_image(agg, bbox):
     """
     Convert the region of the agg buffer bounded by bbox to a wx.Image.  If
     bbox is None, the entire buffer is converted.
@@ -216,7 +142,7 @@ def _py_WX28_convert_agg_to_wx_image(agg, bbox):
         return wx.ImageFromBitmap(_WX28_clipped_agg_as_bitmap(agg, bbox))
 
 
-def _py_WX28_convert_agg_to_wx_bitmap(agg, bbox):
+def _convert_agg_to_wx_bitmap(agg, bbox):
     """
     Convert the region of the agg buffer bounded by bbox to a wx.Bitmap.  If
     bbox is None, the entire buffer is converted.
@@ -226,7 +152,7 @@ def _py_WX28_convert_agg_to_wx_bitmap(agg, bbox):
     if bbox is None:
         # agg => rgba buffer -> bitmap
         return wx.BitmapFromBufferRGBA(int(agg.width), int(agg.height),
-            agg.buffer_rgba(0, 0))
+            agg.buffer_rgba())
     else:
         # agg => rgba buffer -> bitmap => clipped bitmap
         return _WX28_clipped_agg_as_bitmap(agg, bbox)
@@ -243,7 +169,7 @@ def _WX28_clipped_agg_as_bitmap(agg, bbox):
     t = b + height
 
     srcBmp = wx.BitmapFromBufferRGBA(int(agg.width), int(agg.height),
-        agg.buffer_rgba(0, 0))
+        agg.buffer_rgba())
     srcDC = wx.MemoryDC()
     srcDC.SelectObject(srcBmp)
 
@@ -260,36 +186,4 @@ def _WX28_clipped_agg_as_bitmap(agg, bbox):
     srcDC.SelectObject(wx.NullBitmap)
     destDC.SelectObject(wx.NullBitmap)
 
-    return destBmp
-
-
-def _use_accelerator(state):
-    """
-    Enable or disable the WXAgg accelerator, if it is present and is also
-    compatible with whatever version of wxPython is in use.
-    """
-    global _convert_agg_to_wx_image
-    global _convert_agg_to_wx_bitmap
-
-    if getattr(wx, '__version__', '0.0')[0:3] < '2.8':
-        # wxPython < 2.8, so use the C++ accelerator or the Python routines
-        if state and _wxagg is not None:
-            _convert_agg_to_wx_image  = _wxagg.convert_agg_to_wx_image
-            _convert_agg_to_wx_bitmap = _wxagg.convert_agg_to_wx_bitmap
-        else:
-            _convert_agg_to_wx_image  = _py_convert_agg_to_wx_image
-            _convert_agg_to_wx_bitmap = _py_convert_agg_to_wx_bitmap
-    else:
-        # wxPython >= 2.8, so use the accelerated Python routines
-        _convert_agg_to_wx_image  = _py_WX28_convert_agg_to_wx_image
-        _convert_agg_to_wx_bitmap = _py_WX28_convert_agg_to_wx_bitmap
-
-
-# try to load the WXAgg accelerator
-try:
-    import _wxagg
-except ImportError:
-    _wxagg = None
-
-# if it's present, use it
-_use_accelerator(True)
+    return destBmp
\ No newline at end of file
