@@ -3,21 +3,23 @@ A collection of modules for collecting, analyzing and plotting
 financial data.   User contributions welcome!
 
 """
-#from __future__ import division
-import os, warnings
+from __future__ import division, print_function
+import contextlib, os, sys, warnings
 from urllib2 import urlopen
 
-try:
+if sys.version_info[0] < 3:
     from hashlib import md5
-except ImportError:
-    from md5 import md5 #Deprecated in 2.5
+else:
+    import hashlib
+    md5 = lambda x: hashlib.md5(x.encode())
+
 import datetime
 
 import numpy as np
 
-from matplotlib import verbose, get_configdir
+from matplotlib import verbose, get_cachedir
 from matplotlib.dates import date2num
-from matplotlib.cbook import iterable
+from matplotlib.cbook import iterable, mkdirs
 from matplotlib.collections import LineCollection, PolyCollection
 from matplotlib.colors import colorConverter
 from matplotlib.lines import Line2D, TICKLEFT, TICKRIGHT
@@ -25,8 +27,14 @@ from matplotlib.patches import Rectangle
 from matplotlib.transforms import Affine2D
 
 
-configdir = get_configdir()
-cachedir = os.path.join(configdir, 'finance.cache')
+cachedir = get_cachedir()
+# cachedir will be None if there is no writable directory.
+if cachedir is not None:
+    cachedir = os.path.join(cachedir, 'finance.cache')
+else:
+    # Should only happen in a restricted environment (such as Google App
+    # Engine). Deal with this gracefully by not caching finance data.
+    cachedir = None
 
 
 stock_dt = np.dtype([('date', object),
@@ -70,7 +78,7 @@ def parse_yahoo_historical(fh, adjusted=True, asobject=False):
       Otherwise return a numpy recarray with
 
         date, year, month, day, d, open, close, high, low,
-        volume, adjusted_close
+        volume, aclose
 
       where d is a floating poing representation of date,
       as returned by date2num, and date is a python standard
@@ -143,7 +151,7 @@ def fetch_historical_yahoo(ticker, date1, date2, cachename=None,dividends=False)
     cachename is the name of the local file cache.  If None, will
     default to the md5 hash or the url (which incorporates the ticker
     and date range)
-    
+
     set dividends=True to return dividends instead of price data.  With
     this option set, parse functions will not work
 
@@ -169,30 +177,32 @@ def fetch_historical_yahoo(ticker, date1, date2, cachename=None,dividends=False)
     else:
         g='d'
 
-    urlFmt = 'http://table.finance.yahoo.com/table.csv?a=%d&b=%d&c=%d&d=%d&e=%d&f=%d&s=%s&y=0&g=%s&ignore=.csv'
+    urlFmt = 'http://ichart.yahoo.com/table.csv?a=%d&b=%d&c=%d&d=%d&e=%d&f=%d&s=%s&y=0&g=%s&ignore=.csv'
 
 
     url =  urlFmt % (d1[0], d1[1], d1[2],
                      d2[0], d2[1], d2[2], ticker, g)
 
 
-    if cachename is None:
+    # Cache the finance data if cachename is supplied, or there is a writable
+    # cache directory.
+    if cachename is None and cachedir is not None:
         cachename = os.path.join(cachedir, md5(url).hexdigest())
-    if os.path.exists(cachename):
-        fh = file(cachename)
-        verbose.report('Using cachefile %s for %s'%(cachename, ticker))
+    if cachename is not None:
+        if os.path.exists(cachename):
+            fh = open(cachename)
+            verbose.report('Using cachefile %s for %s'%(cachename, ticker))
+        else:
+            mkdirs(os.path.abspath(os.path.dirname(cachename)))
+            with contextlib.closing(urlopen(url)) as urlfh:
+                with open(cachename, 'wb') as fh:
+                    fh.write(urlfh.read())
+            verbose.report('Saved %s data to cache file %s'%(ticker, cachename))
+            fh = open(cachename, 'r')
+
+        return fh
     else:
-        if not os.path.isdir(cachedir):
-            os.mkdir(cachedir)
-        urlfh = urlopen(url)
-
-        fh = file(cachename, 'w')
-        fh.write(urlfh.read())
-        fh.close()
-        verbose.report('Saved %s data to cache file %s'%(ticker, cachename))
-        fh = file(cachename, 'r')
-
-    return fh
+        return urlopen(url)
 
 
 def quotes_historical_yahoo(ticker, date1, date2, asobject=False,
@@ -230,7 +240,7 @@ def quotes_historical_yahoo(ticker, date1, date2, asobject=False,
                                             adjusted=adjusted)
         if len(ret) == 0:
             return None
-    except IOError, exc:
+    except IOError as exc:
         warnings.warn('fh failure\n%s'%(exc.strerror[1]))
         return None
 
@@ -563,6 +573,7 @@ def volume_overlay(ax, opens, closes, volumes,
                                    linewidths   = (0.5,),
                                    )
 
+    ax.add_collection(barCollection)
     corners = (0, 0), (len(bars), max(volumes))
     ax.update_datalim(corners)
     ax.autoscale_view()
