@@ -31,7 +31,6 @@ from matplotlib.offsetbox import HPacker, VPacker, TextArea, DrawingArea
 from matplotlib.offsetbox import DraggableOffsetBox
 
 from matplotlib.container import ErrorbarContainer, BarContainer, StemContainer
-from matplotlib import MatplotlibDeprecationWarning as mplDeprecation
 import legend_handler
 
 
@@ -108,7 +107,7 @@ class Legend(Artist):
       'upper center' : 9,
       'center'       : 10,
 
-    loc can be a tuple of the noramilzed coordinate values with
+    loc can be a tuple of the normalized coordinate values with
     respect its parent.
 
     """
@@ -135,18 +134,11 @@ class Legend(Artist):
                  numpoints=None,    # the number of points in the legend line
                  markerscale=None,  # the relative size of legend markers
                                     # vs. original
-                 scatterpoints=3,    # TODO: may be an rcParam
+                 scatterpoints=None,    # number of scatter points
                  scatteryoffsets=None,
                  prop=None,          # properties for the legend texts
                  fontsize=None,        # keyword to set font size directly
 
-                 # the following dimensions are in axes coords
-                 pad=None,            # deprecated; use borderpad
-                 labelsep=None,       # deprecated; use labelspacing
-                 handlelen=None,      # deprecated; use handlelength
-                 handletextsep=None,  # deprecated; use handletextpad
-                 axespad=None,        # deprecated; use borderaxespad
-
                  # spacing & pad defined as a fraction of the font-size
                  borderpad=None,      # the whitespace inside the legend border
                  labelspacing=None,   # the vertical space between the legend
@@ -167,6 +159,9 @@ class Legend(Artist):
                                  # box, none use rc
                  shadow=None,
                  title=None,  # set a title for the legend
+
+                 framealpha=None, # set frame alpha
+
                  bbox_to_anchor=None,  # bbox that the legend will be anchored.
                  bbox_transform=None,  # transform for the bbox
                  frameon=None,  # draw frame
@@ -195,6 +190,7 @@ class Legend(Artist):
         fancybox           if True, draw a frame with a round fancybox.
                            If None, use rc
         shadow             if True, draw a shadow behind legend
+        framealpha         If not None, alpha channel for the frame.
         ncol               number of columns
         borderpad          the fractional whitespace inside the legend border
         labelspacing       the vertical space between the legend entries
@@ -209,7 +205,7 @@ class Legend(Artist):
         ================   ====================================================
 
 
-        The pad and spacing parameters are measured in font-size units.  E.g.,
+        The pad and spacing parameters are measured in font-size units.  e.g.,
         a fontsize of 10 points and a handlelength=5 implies a handlelength of
         50 points.  Values from rcParams will be used if None.
 
@@ -260,13 +256,6 @@ class Legend(Artist):
                 value = localdict[name]
             setattr(self, name, value)
 
-        # Take care the deprecated keywords
-        deprecated_kwds = {"pad": "borderpad",
-                           "labelsep": "labelspacing",
-                           "handlelen": "handlelength",
-                           "handletextsep": "handletextpad",
-                           "axespad": "borderaxespad"}
-
         # convert values of deprecated keywords (ginve in axes coords)
         # to new vaules in a fraction of the font size
 
@@ -274,16 +263,8 @@ class Legend(Artist):
         bbox = parent.bbox
         axessize_fontsize = min(bbox.width, bbox.height) / self._fontsize
 
-        for k, v in deprecated_kwds.iteritems():
-            # use deprecated value if not None and if their newer
-            # counter part is None.
-            if localdict[k] is not None and localdict[v] is None:
-                warnings.warn("Use '%s' instead of '%s'." % (v, k),
-                              mplDeprecation)
-                setattr(self, v, localdict[k] * axessize_fontsize)
-                continue
-
-            # Otherwise, use new keywords
+        for v in ['borderpad', 'labelspacing', 'handlelength',
+                  'handletextpad', 'borderaxespad']:
             if localdict[v] is None:
                 setattr(self, v, rcParams["legend." + v])
             else:
@@ -384,6 +365,9 @@ class Legend(Artist):
         # init with null renderer
         self._init_legend_box(handles, labels)
 
+        if framealpha is not None:
+          self.get_frame().set_alpha(framealpha)
+
         self._loc = loc
 
         self.set_title(title)
@@ -729,7 +713,6 @@ class Legend(Artist):
         assert self.isaxes
 
         ax = self.parent
-        vertices = []
         bboxes = []
         lines = []
 
@@ -750,6 +733,11 @@ class Legend(Artist):
                 transform = handle.get_transform()
                 bboxes.append(handle.get_path().get_extents(transform))
 
+        try:
+            vertices = np.concatenate([l.vertices for l in lines])
+        except ValueError:
+            vertices = np.array([])
+
         return [vertices, bboxes, lines]
 
     def draw_frame(self, b):
@@ -915,10 +903,11 @@ class Legend(Artist):
         verts, bboxes, lines = self._auto_legend_data()
 
         bbox = Bbox.from_bounds(0, 0, width, height)
-        consider = [self._get_anchored_bbox(x, bbox, self.get_bbox_to_anchor(),
-                                            renderer)
-                    for x
-                    in range(1, len(self.codes))]
+        if consider is None:
+            consider = [self._get_anchored_bbox(x, bbox,
+                                                self.get_bbox_to_anchor(),
+                                                renderer)
+                        for x in range(1, len(self.codes))]
 
         #tx, ty = self.legendPatch.get_x(), self.legendPatch.get_y()
 
@@ -926,9 +915,19 @@ class Legend(Artist):
         for l, b in consider:
             legendBox = Bbox.from_bounds(l, b, width, height)
             badness = 0
+            # XXX TODO: If markers are present, it would be good to
+            # take their into account when checking vertex overlaps in
+            # the next line.
             badness = legendBox.count_contains(verts)
             badness += legendBox.count_overlaps(bboxes)
             for line in lines:
+                # FIXME: the following line is ill-suited for lines
+                # that 'spiral' around the center, because the bbox
+                # may intersect with the legend even if the line
+                # itself doesn't. One solution would be to break up
+                # the line into its straight-segment components, but
+                # this may (or may not) result in a significant
+                # slowdown if lines with many vertices are present.
                 if line.intersects_bbox(legendBox):
                     badness += 1
 
