@@ -1,5 +1,15 @@
 """
-Contains a class for managing paths (polylines).
+A module for dealing with the polylines used throughout matplotlib.
+
+The primary class for polyline handling in matplotlib is :class:`Path`.
+Almost all vector drawing makes use of Paths somewhere in the drawing
+pipeline.
+
+Whilst a :class:`Path` instance itself cannot be drawn, there exists
+:class:`~matplotlib.artist.Artist` subclasses which can be used for
+convenient Path visualisation - the two most frequently used of these are
+:class:`~matplotlib.patches.PathPatch` and
+:class:`~matplotlib.collections.PathCollection`.
 """
 
 from __future__ import print_function
@@ -9,13 +19,11 @@ from weakref import WeakValueDictionary
 import numpy as np
 from numpy import ma
 
-from matplotlib._path import point_in_path, get_path_extents, \
-    point_in_path_collection, get_path_collection_extents, \
-    path_in_path, path_intersects_path, convert_path_to_polygons, \
-    cleanup_path, points_in_path
+from matplotlib import _path
 from matplotlib.cbook import simple_linear_interpolation, maxdict
 from matplotlib import rcParams
 
+
 class Path(object):
     """
     :class:`Path` represents a series of possibly disconnected,
@@ -55,9 +63,9 @@ class Path(object):
 
     Users of Path objects should not access the vertices and codes
     arrays directly.  Instead, they should use :meth:`iter_segments`
-    to get the vertex/code pairs.  This is important, since many
-    :class:`Path` objects, as an optimization, do not store a *codes*
-    at all, but have a default one provided for them by
+    or :meth:`cleaned` to get the vertex/code pairs.  This is important,
+    since many :class:`Path` objects, as an optimization, do not store a
+    *codes* at all, but have a default one provided for them by
     :meth:`iter_segments`.
 
     .. note::
@@ -75,40 +83,49 @@ class Path(object):
     LINETO    = 2    # 1 vertex
     CURVE3    = 3    # 2 vertices
     CURVE4    = 4    # 3 vertices
-    CLOSEPOLY = 0x4f # 1 vertex
+    CLOSEPOLY = 79   # 1 vertex
 
-    NUM_VERTICES = [1, 1, 1, 2,
-                    3, 1, 1, 1,
-                    1, 1, 1, 1,
-                    1, 1, 1, 1]
+    #: A dictionary mapping Path codes to the number of vertices that the
+    #: code expects.
+    NUM_VERTICES_FOR_CODE = {STOP: 1,
+                             MOVETO: 1,
+                             LINETO: 1,
+                             CURVE3: 2,
+                             CURVE4: 3,
+                             CLOSEPOLY: 1}
 
     code_type = np.uint8
 
-    def __init__(self, vertices, codes=None, _interpolation_steps=1, closed=False):
+    def __init__(self, vertices, codes=None, _interpolation_steps=1, closed=False,
+                 readonly=False):
         """
         Create a new path with the given vertices and codes.
 
-        *vertices* is an Nx2 numpy float array, masked array or Python
-        sequence.
+        Parameters
+        ----------
+        vertices : array_like
+            The ``(n, 2)`` float array, masked array or sequence of pairs
+            representing the vertices of the path.
 
-        *codes* is an N-length numpy array or Python sequence of type
-        :attr:`matplotlib.path.Path.code_type`.
-
-        These two arrays must have the same length in the first
-        dimension.
-
-        If *codes* is None, *vertices* will be treated as a series of
-        line segments.
-
-        If *vertices* contains masked values, they will be converted
-        to NaNs which are then handled correctly by the Agg
-        PathIterator and other consumers of path data, such as
-        :meth:`iter_segments`.
-
-        *interpolation_steps* is used as a hint to certain projections,
-        such as Polar, that this path should be linearly interpolated
-        immediately before drawing.  This attribute is primarily an
-        implementation detail and is not intended for public use.
+            If *vertices* contains masked values, they will be converted
+            to NaNs which are then handled correctly by the Agg
+            PathIterator and other consumers of path data, such as
+            :meth:`iter_segments`.
+        codes : {None, array_like}, optional
+            n-length array integers representing the codes of the path.
+            If not None, codes must be the same length as vertices.
+            If None, *vertices* will be treated as a series of line segments.
+        _interpolation_steps : int, optional
+            Used as a hint to certain projections, such as Polar, that this
+            path should be linearly interpolated immediately before drawing.
+            This attribute is primarily an implementation detail and is not
+            intended for public use.
+        closed : bool, optional
+            If *codes* is None and closed is True, vertices will be treated as
+            line segments of a closed polygon.
+        readonly : bool, optional
+            Makes the path behave in an immutable way and sets the vertices
+            and codes as read-only arrays.
         """
         if ma.isMaskedArray(vertices):
             vertices = vertices.astype(np.float_).filled(np.nan)
@@ -130,19 +147,154 @@ class Path(object):
         assert vertices.ndim == 2
         assert vertices.shape[1] == 2
 
-        self.should_simplify = (rcParams['path.simplify'] and
-                                (len(vertices) >= 128 and
-                                 (codes is None or np.all(codes <= Path.LINETO))))
-        self.simplify_threshold = rcParams['path.simplify_threshold']
-        self.has_nonfinite = not np.isfinite(vertices).all()
-        self.codes = codes
-        self.vertices = vertices
+        self._vertices = vertices
+        self._codes = codes
         self._interpolation_steps = _interpolation_steps
+        self._update_values()
+
+        if readonly:
+            self._vertices.flags.writeable = False
+            if self._codes is not None:
+                self._codes.flags.writeable = False
+            self._readonly = True
+        else:
+            self._readonly = False
+
+    @classmethod
+    def _fast_from_codes_and_verts(cls, verts, codes, internals=None):
+        """
+        Creates a Path instance without the expense of calling the constructor
+
+        Parameters
+        ----------
+        verts : numpy array
+        codes : numpy array (may not be None)
+        internals : dict or None
+            The attributes that the resulting path should have.
+            Allowed keys are ``readonly``, ``should_simplify``,
+            ``simplify_threshold``, ``has_nonfinite`` and
+            ``interpolation_steps``.
+
+        """
+        internals = internals or {}
+        pth = cls.__new__(cls)
+        pth._vertices = verts
+        pth._codes = codes
+        pth._readonly = internals.pop('readonly', False)
+        pth.should_simplify = internals.pop('should_simplify', True)
+        pth.simplify_threshold = internals.pop('simplify_threshold',
+                                          rcParams['path.simplify_threshold'])
+        pth._has_nonfinite = internals.pop('has_nonfinite', False)
+        pth._interpolation_steps = internals.pop('interpolation_steps', 1)
+        if internals:
+            raise ValueError('Unexpected internals provided to '
+                             '_fast_from_codes_and_verts: '
+                             '{0}'.format('\n *'.join(internals.keys())))
+        return pth
+
+    def _update_values(self):
+        self._should_simplify = (
+            rcParams['path.simplify'] and
+            (len(self._vertices) >= 128 and
+            (self._codes is None or np.all(self._codes <= Path.LINETO))))
+        self._simplify_threshold = rcParams['path.simplify_threshold']
+        self._has_nonfinite = not np.isfinite(self._vertices).all()
+
+    @property
+    def vertices(self):
+        """
+        The list of vertices in the `Path` as an Nx2 numpy array.
+        """
+        return self._vertices
+
+    @vertices.setter
+    def vertices(self, vertices):
+        if self._readonly:
+            raise AttributeError("Can't set vertices on a readonly Path")
+        self._vertices = vertices
+        self._update_values()
+
+    @property
+    def codes(self):
+        """
+        The list of codes in the `Path` as a 1-D numpy array.  Each
+        code is one of `STOP`, `MOVETO`, `LINETO`, `CURVE3`, `CURVE4`
+        or `CLOSEPOLY`.  For codes that correspond to more than one
+        vertex (`CURVE3` and `CURVE4`), that code will be repeated so
+        that the length of `self.vertices` and `self.codes` is always
+        the same.
+        """
+        return self._codes
+
+    @codes.setter
+    def codes(self, codes):
+        if self._readonly:
+            raise AttributeError("Can't set codes on a readonly Path")
+        self._codes = codes
+        self._update_values()
+
+    @property
+    def simplify_threshold(self):
+        """
+        The fraction of a pixel difference below which vertices will
+        be simplified out.
+        """
+        return self._simplify_threshold
+
+    @simplify_threshold.setter
+    def simplify_threshold(self, threshold):
+        self._simplify_threshold = threshold
+
+    @property
+    def has_nonfinite(self):
+        """
+        `True` if the vertices array has nonfinite values.
+        """
+        return self._has_nonfinite
+
+    @property
+    def should_simplify(self):
+        """
+        `True` if the vertices array should be simplified.
+        """
+        return self._should_simplify
+
+    @should_simplify.setter
+    def should_simplify(self, should_simplify):
+        self._should_simplify = should_simplify
+
+    @property
+    def readonly(self):
+        """
+        `True` if the `Path` is read-only.
+        """
+        return self._readonly
+
+    def __copy__(self):
+        """
+        Returns a shallow copy of the `Path`, which will share the
+        vertices and codes with the source `Path`.
+        """
+        import copy
+        return copy.copy(self)
+
+    copy = __copy__
+
+    def __deepcopy__(self):
+        """
+        Returns a deepcopy of the `Path`.  The `Path` will not be
+        readonly, even if the source `Path` is.
+        """
+        return self.__class__(
+            self.vertices.copy(), self.codes.copy(),
+            _interpolation_steps=self._interpolation_steps)
+
+    deepcopy = __deepcopy__
 
     @classmethod
     def make_compound_path_from_polys(cls, XY):
         """
-        (static method) Make a compound path object to draw a number
+        Make a compound path object to draw a number
         of polygons with equal numbers of sides XY is a (numpolys x
         numsides x 2) numpy array of vertices.  Return object is a
         :class:`Path`
@@ -169,24 +321,22 @@ class Path(object):
 
     @classmethod
     def make_compound_path(cls, *args):
-        """
-        (staticmethod) Make a compound path from a list of Path
-        objects.  Only polygons (not curves) are supported.
-        """
-        for p in args:
-            assert p.codes is None
-
+        """Make a compound path from a list of Path objects."""
         lengths = [len(x) for x in args]
         total_length = sum(lengths)
 
         vertices = np.vstack([x.vertices for x in args])
         vertices.reshape((total_length, 2))
 
-        codes = cls.LINETO * np.ones(total_length)
+        codes = np.empty(total_length, dtype=cls.code_type)
         i = 0
-        for length in lengths:
-            codes[i] = cls.MOVETO
-            i += length
+        for path in args:
+            if path.codes is None:
+                codes[i] = cls.MOVETO
+                codes[i + 1:i + len(path.vertices)] = cls.LINETO
+            else:
+                codes[i:i + len(path.codes)] = path.codes
+            i += len(path.vertices)
 
         return cls(vertices, codes)
 
@@ -198,7 +348,7 @@ class Path(object):
 
     def iter_segments(self, transform=None, remove_nans=True, clip=None,
                       snap=False, stroke_width=1.0, simplify=None,
-                      curves=True):
+                      curves=True, sketch=None):
         """
         Iterates over all of the curve segments in the path.  Each
         iteration returns a 2-tuple (*vertices*, *code*), where
@@ -208,46 +358,53 @@ class Path(object):
         Additionally, this method can provide a number of standard
         cleanups and conversions to the path.
 
-        *transform*: if not None, the given affine transformation will
-         be applied to the path.
-
-        *remove_nans*: if True, will remove all NaNs from the path and
-         insert MOVETO commands to skip over them.
-
-        *clip*: if not None, must be a four-tuple (x1, y1, x2, y2)
-         defining a rectangle in which to clip the path.
-
-        *snap*: if None, auto-snap to pixels, to reduce
-         fuzziness of rectilinear lines.  If True, force snapping, and
-         if False, don't snap.
-
-        *stroke_width*: the width of the stroke being drawn.  Needed
-         as a hint for the snapping algorithm.
-
-        *simplify*: if True, perform simplification, to remove
-         vertices that do not affect the appearance of the path.  If
-         False, perform no simplification.  If None, use the
-         should_simplify member variable.
-
-        *curves*: If True, curve segments will be returned as curve
-         segments.  If False, all curves will be converted to line
-         segments.
+        Parameters
+        ----------
+        transform : None or :class:`~matplotlib.transforms.Transform` instance
+            If not None, the given affine transformation will
+            be applied to the path.
+        remove_nans : {False, True}, optional
+            If True, will remove all NaNs from the path and
+            insert MOVETO commands to skip over them.
+        clip : None or sequence, optional
+            If not None, must be a four-tuple (x1, y1, x2, y2)
+            defining a rectangle in which to clip the path.
+        snap : None or bool, optional
+            If None, auto-snap to pixels, to reduce
+            fuzziness of rectilinear lines.  If True, force snapping, and
+            if False, don't snap.
+        stroke_width : float, optional
+            The width of the stroke being drawn.  Needed
+             as a hint for the snapping algorithm.
+        simplify : None or bool, optional
+            If True, perform simplification, to remove
+             vertices that do not affect the appearance of the path.  If
+             False, perform no simplification.  If None, use the
+             should_simplify member variable.
+        curves : {True, False}, optional
+            If True, curve segments will be returned as curve
+            segments.  If False, all curves will be converted to line
+            segments.
+        sketch : None or sequence, optional
+            If not None, must be a 3-tuple of the form
+            (scale, length, randomness), representing the sketch
+            parameters.
         """
-        vertices = self.vertices
-        if not len(vertices):
+        if not len(self):
             return
 
-        codes        = self.codes
+        cleaned = self.cleaned(transform=transform,
+                               remove_nans=remove_nans, clip=clip,
+                               snap=snap, stroke_width=stroke_width,
+                               simplify=simplify, curves=curves,
+                               sketch=sketch)
+        vertices = cleaned.vertices
+        codes = cleaned.codes
+        len_vertices = vertices.shape[0]
 
-        NUM_VERTICES = self.NUM_VERTICES
-        MOVETO       = self.MOVETO
-        LINETO       = self.LINETO
-        CLOSEPOLY    = self.CLOSEPOLY
-        STOP         = self.STOP
-
-        vertices, codes = cleanup_path(self, transform, remove_nans, clip,
-                                       snap, stroke_width, simplify, curves)
-        len_vertices = len(vertices)
+        # Cache these object lookups for performance in the loop.
+        NUM_VERTICES_FOR_CODE = self.NUM_VERTICES_FOR_CODE
+        STOP = self.STOP
 
         i = 0
         while i < len_vertices:
@@ -255,11 +412,37 @@ class Path(object):
             if code == STOP:
                 return
             else:
-                num_vertices = NUM_VERTICES[int(code) & 0xf]
+                num_vertices = NUM_VERTICES_FOR_CODE[code]
                 curr_vertices = vertices[i:i+num_vertices].flatten()
                 yield curr_vertices, code
                 i += num_vertices
 
+    def cleaned(self, transform=None, remove_nans=False, clip=None,
+                  quantize=False, simplify=False, curves=False,
+                  stroke_width=1.0, snap=False, sketch=None):
+        """
+        Cleans up the path according to the parameters returning a new
+        Path instance.
+
+        .. seealso::
+
+            See :meth:`iter_segments` for details of the keyword arguments.
+
+        Returns
+        -------
+        Path instance with cleaned up vertices and codes.
+
+        """
+        vertices, codes = _path.cleanup_path(self, transform,
+                                             remove_nans, clip,
+                                             snap, stroke_width,
+                                             simplify, curves, sketch)
+        internals = {'should_simplify': self.should_simplify and not simplify,
+                     'has_nonfinite': self.has_nonfinite and not remove_nans,
+                     'simplify_threshold': self.simplify_threshold,
+                     'interpolation_steps': self._interpolation_steps}
+        return Path._fast_from_codes_and_verts(vertices, codes, internals)
+
     def transformed(self, transform):
         """
         Return a transformed copy of the path.
@@ -286,7 +469,7 @@ class Path(object):
         """
         if transform is not None:
             transform = transform.frozen()
-        result = point_in_path(point[0], point[1], radius, self, transform)
+        result = _path.point_in_path(point[0], point[1], radius, self, transform)
         return result
 
     def contains_points(self, points, transform=None, radius=0.0):
@@ -302,7 +485,7 @@ class Path(object):
         """
         if transform is not None:
             transform = transform.frozen()
-        result = points_in_path(points, radius, self, transform)
+        result = _path.points_in_path(points, radius, self, transform)
         return result
 
     def contains_path(self, path, transform=None):
@@ -314,7 +497,7 @@ class Path(object):
         """
         if transform is not None:
             transform = transform.frozen()
-        return path_in_path(self, None, path, transform)
+        return _path.path_in_path(self, None, path, transform)
 
     def get_extents(self, transform=None):
         """
@@ -332,7 +515,7 @@ class Path(object):
             if not transform.is_affine:
                 path = self.transformed(transform)
                 transform = None
-        return Bbox(get_path_extents(path, transform))
+        return Bbox(_path.get_path_extents(path, transform))
 
     def intersects_path(self, other, filled=True):
         """
@@ -342,7 +525,7 @@ class Path(object):
         That is, if one path completely encloses the other,
         :meth:`intersects_path` will return True.
         """
-        return path_intersects_path(self, other, filled)
+        return _path.path_intersects_path(self, other, filled)
 
     def intersects_bbox(self, bbox, filled=True):
         """
@@ -402,19 +585,20 @@ class Path(object):
 
         # Deal with the case where there are curves and/or multiple
         # subpaths (using extension code)
-        return convert_path_to_polygons(self, transform, width, height)
+        return _path.convert_path_to_polygons(self, transform, width, height)
 
     _unit_rectangle = None
     @classmethod
     def unit_rectangle(cls):
         """
-        (staticmethod) Returns a :class:`Path` of the unit rectangle
+        Return a :class:`Path` instance of the unit rectangle
         from (0, 0) to (1, 1).
         """
         if cls._unit_rectangle is None:
             cls._unit_rectangle = \
                 cls([[0.0, 0.0], [1.0, 0.0], [1.0, 1.0], [0.0, 1.0], [0.0, 0.0]],
-                    [cls.MOVETO, cls.LINETO, cls.LINETO, cls.LINETO, cls.CLOSEPOLY])
+                    [cls.MOVETO, cls.LINETO, cls.LINETO, cls.LINETO, cls.CLOSEPOLY],
+                    readonly=True)
         return cls._unit_rectangle
 
     _unit_regular_polygons = WeakValueDictionary()
@@ -422,7 +606,7 @@ class Path(object):
     @classmethod
     def unit_regular_polygon(cls, numVertices):
         """
-        (staticmethod) Returns a :class:`Path` for a unit regular
+        Return a :class:`Path` instance for a unit regular
         polygon with the given *numVertices* and radius of 1.0,
         centered at (0, 0).
         """
@@ -441,7 +625,7 @@ class Path(object):
             codes[0] = cls.MOVETO
             codes[1:-1] = cls.LINETO
             codes[-1] = cls.CLOSEPOLY
-            path = cls(verts, codes)
+            path = cls(verts, codes, readonly=True)
             if numVertices <= 16:
                 cls._unit_regular_polygons[numVertices] = path
         return path
@@ -451,7 +635,7 @@ class Path(object):
     @classmethod
     def unit_regular_star(cls, numVertices, innerCircle=0.5):
         """
-        (staticmethod) Returns a :class:`Path` for a unit regular star
+        Return a :class:`Path` for a unit regular star
         with the given numVertices and radius of 1.0, centered at (0,
         0).
         """
@@ -472,7 +656,7 @@ class Path(object):
             codes[0] = cls.MOVETO
             codes[1:-1] = cls.LINETO
             codes[-1] = cls.CLOSEPOLY
-            path = cls(verts, codes)
+            path = cls(verts, codes, readonly=True)
             if numVertices <= 16:
                 cls._unit_regular_polygons[(numVertices, innerCircle)] = path
         return path
@@ -480,7 +664,7 @@ class Path(object):
     @classmethod
     def unit_regular_asterisk(cls, numVertices):
         """
-        (staticmethod) Returns a :class:`Path` for a unit regular
+        Return a :class:`Path` for a unit regular
         asterisk with the given numVertices and radius of 1.0,
         centered at (0, 0).
         """
@@ -491,7 +675,7 @@ class Path(object):
     @classmethod
     def unit_circle(cls):
         """
-        (staticmethod) Returns a :class:`Path` of the unit circle.
+        Return a :class:`Path` of the unit circle.
         The circle is approximated using cubic Bezier curves.  This
         uses 8 splines around the circle using the approach presented
         here:
@@ -546,7 +730,7 @@ class Path(object):
             codes[0] = cls.MOVETO
             codes[-1] = cls.CLOSEPOLY
 
-            cls._unit_circle = cls(vertices, codes)
+            cls._unit_circle = cls(vertices, codes, readonly=True)
         return cls._unit_circle
 
     _unit_circle_righthalf = None
@@ -554,7 +738,7 @@ class Path(object):
     @classmethod
     def unit_circle_righthalf(cls):
         """
-        (staticmethod) Returns a :class:`Path` of the right half
+        Return a :class:`Path` of the right half
         of a unit circle. The circle is approximated using cubic Bezier
         curves.  This uses 4 splines around the circle using the approach
         presented here:
@@ -594,13 +778,13 @@ class Path(object):
             codes[0] = cls.MOVETO
             codes[-1] = cls.CLOSEPOLY
 
-            cls._unit_circle_righthalf = cls(vertices, codes)
+            cls._unit_circle_righthalf = cls(vertices, codes, readonly=True)
         return cls._unit_circle_righthalf
 
     @classmethod
     def arc(cls, theta1, theta2, n=None, is_wedge=False):
         """
-        (staticmethod) Returns an arc on the unit circle from angle
+        Return an arc on the unit circle from angle
         *theta1* to angle *theta2* (in degrees).
 
         If *n* is provided, it is the number of spline segments to make.
@@ -673,12 +857,12 @@ class Path(object):
         vertices[vertex_offset+2:end:3, 0] = xB
         vertices[vertex_offset+2:end:3, 1] = yB
 
-        return cls(vertices, codes)
+        return cls(vertices, codes, readonly=True)
 
     @classmethod
     def wedge(cls, theta1, theta2, n=None):
         """
-        (staticmethod) Returns a wedge of the unit circle from angle
+        Return a wedge of the unit circle from angle
         *theta1* to angle *theta2* (in degrees).
 
         If *n* is provided, it is the number of spline segments to make.
@@ -709,7 +893,22 @@ class Path(object):
         cls._hatch_dict[(hatchpattern, density)] = hatch_path
         return hatch_path
 
-_get_path_collection_extents = get_path_collection_extents
+    def clip_to_bbox(self, bbox, inside=True):
+        """
+        Clip the path to the given bounding box.
+
+        The path must be made up of one or more closed polygons.  This
+        algorithm will not behave correctly for unclosed paths.
+
+        If *inside* is `True`, clip to the inside of the box, otherwise
+        to the outside of the box.
+        """
+        # Use make_compound_path_from_polys
+        verts = _path.clip_path_to_rect(self, bbox, inside)
+        paths = [Path(poly) for poly in verts]
+        return self.make_compound_path(*paths)
+
+
 def get_path_collection_extents(
         master_transform, paths, transforms, offsets, offset_transform):
     """
@@ -740,9 +939,10 @@ def get_path_collection_extents(
     from transforms import Bbox
     if len(paths) == 0:
         raise ValueError("No paths provided")
-    return Bbox.from_extents(*_get_path_collection_extents(
+    return Bbox.from_extents(*_path.get_path_collection_extents(
         master_transform, paths, transforms, offsets, offset_transform))
 
+
 def get_paths_extents(paths, transforms=[]):
     """
     Given a sequence of :class:`Path` objects and optional
@@ -758,5 +958,28 @@ def get_paths_extents(paths, transforms=[]):
     from transforms import Bbox, Affine2D
     if len(paths) == 0:
         raise ValueError("No paths provided")
-    return Bbox.from_extents(*_get_path_collection_extents(
+    return Bbox.from_extents(*_path.get_path_collection_extents(
         Affine2D(), paths, transforms, [], Affine2D()))
+
+
+def _define_deprecated_functions(ns):
+    from cbook import deprecated
+
+    # The C++ functions are not meant to be used directly.
+    # Users should use the more pythonic wrappers in the Path
+    # class instead.
+    for func, alternative in [
+            ('point_in_path', 'path.Path.contains_point'),
+            ('get_path_extents', 'path.Path.get_extents'),
+            ('point_in_path_collection', 'collection.Collection.contains'),
+            ('path_in_path', 'path.Path.contains_path'),
+            ('path_intersects_path', 'path.Path.intersects_path'),
+            ('convert_path_to_polygons', 'path.Path.to_polygons'),
+            ('cleanup_path', 'path.Path.cleaned'),
+            ('points_in_path', 'path.Path.contains_points'),
+            ('clip_path_to_rect', 'path.Path.clip_to_bbox')]:
+        ns[func] = deprecated(
+            since='1.3', alternative=alternative)(getattr(_path, func))
+
+
+_define_deprecated_functions(locals())
