@@ -1,3 +1,4 @@
+from __future__ import print_function
 import math
 import warnings
 
@@ -17,6 +18,197 @@ from matplotlib.transforms import Affine2D, Affine2DBase, Bbox, \
     ScaledTranslation, blended_transform_factory, BboxTransformToMaxOnly
 import matplotlib.spines as mspines
 
+
+class PolarTransform(Transform):
+    """
+    The base polar transform.  This handles projection *theta* and
+    *r* into Cartesian coordinate space *x* and *y*, but does not
+    perform the ultimate affine transformation into the correct
+    position.
+    """
+    input_dims = 2
+    output_dims = 2
+    is_separable = False
+
+    def __init__(self, axis=None, use_rmin=True):
+        Transform.__init__(self)
+        self._axis = axis
+        self._use_rmin = use_rmin
+
+    def transform_non_affine(self, tr):
+        xy = np.empty(tr.shape, np.float_)
+        if self._axis is not None:
+            if self._use_rmin:
+                rmin = self._axis.viewLim.ymin
+            else:
+                rmin = 0
+            theta_offset = self._axis.get_theta_offset()
+            theta_direction = self._axis.get_theta_direction()
+        else:
+            rmin = 0
+            theta_offset = 0
+            theta_direction = 1
+
+        t = tr[:, 0:1]
+        r = tr[:, 1:2]
+        x = xy[:, 0:1]
+        y = xy[:, 1:2]
+
+        t *= theta_direction
+        t += theta_offset
+
+        r = r - rmin
+        mask = r < 0
+        x[:] = np.where(mask, np.nan, r * np.cos(t))
+        y[:] = np.where(mask, np.nan, r * np.sin(t))
+
+        return xy
+    transform_non_affine.__doc__ = Transform.transform_non_affine.__doc__
+
+    def transform_path_non_affine(self, path):
+        vertices = path.vertices
+        if len(vertices) == 2 and vertices[0, 0] == vertices[1, 0]:
+            return Path(self.transform(vertices), path.codes)
+        ipath = path.interpolated(path._interpolation_steps)
+        return Path(self.transform(ipath.vertices), ipath.codes)
+    transform_path_non_affine.__doc__ = Transform.transform_path_non_affine.__doc__
+
+    def inverted(self):
+        return PolarAxes.InvertedPolarTransform(self._axis, self._use_rmin)
+    inverted.__doc__ = Transform.inverted.__doc__
+
+
+class PolarAffine(Affine2DBase):
+    """
+    The affine part of the polar projection.  Scales the output so
+    that maximum radius rests on the edge of the axes circle.
+    """
+    def __init__(self, scale_transform, limits):
+        """
+        *limits* is the view limit of the data.  The only part of
+        its bounds that is used is ymax (for the radius maximum).
+        The theta range is always fixed to (0, 2pi).
+        """
+        Affine2DBase.__init__(self)
+        self._scale_transform = scale_transform
+        self._limits = limits
+        self.set_children(scale_transform, limits)
+        self._mtx = None
+
+    def get_matrix(self):
+        if self._invalid:
+            limits_scaled = self._limits.transformed(self._scale_transform)
+            yscale = limits_scaled.ymax - limits_scaled.ymin
+            affine = Affine2D() \
+                .scale(0.5 / yscale) \
+                .translate(0.5, 0.5)
+            self._mtx = affine.get_matrix()
+            self._inverted = None
+            self._invalid = 0
+        return self._mtx
+    get_matrix.__doc__ = Affine2DBase.get_matrix.__doc__
+
+    def __getstate__(self):
+        return {}
+
+
+class InvertedPolarTransform(Transform):
+    """
+    The inverse of the polar transform, mapping Cartesian
+    coordinate space *x* and *y* back to *theta* and *r*.
+    """
+    input_dims = 2
+    output_dims = 2
+    is_separable = False
+
+    def __init__(self, axis=None, use_rmin=True):
+        Transform.__init__(self)
+        self._axis = axis
+        self._use_rmin = use_rmin
+
+    def transform_non_affine(self, xy):
+        if self._axis is not None:
+            if self._use_rmin:
+                rmin = self._axis.viewLim.ymin
+            else:
+                rmin = 0
+            theta_offset = self._axis.get_theta_offset()
+            theta_direction = self._axis.get_theta_direction()
+        else:
+            rmin = 0
+            theta_offset = 0
+            theta_direction = 1
+
+        x = xy[:, 0:1]
+        y = xy[:, 1:]
+        r = np.sqrt(x*x + y*y)
+        theta = np.arccos(x / r)
+        theta = np.where(y < 0, 2 * np.pi - theta, theta)
+
+        theta -= theta_offset
+        theta *= theta_direction
+
+        r += rmin
+
+        return np.concatenate((theta, r), 1)
+    transform_non_affine.__doc__ = Transform.transform_non_affine.__doc__
+
+    def inverted(self):
+        return PolarAxes.PolarTransform(self._axis, self._use_rmin)
+    inverted.__doc__ = Transform.inverted.__doc__
+
+
+class ThetaFormatter(Formatter):
+    """
+    Used to format the *theta* tick labels.  Converts the native
+    unit of radians into degrees and adds a degree symbol.
+    """
+    def __call__(self, x, pos=None):
+        # \u00b0 : degree symbol
+        if rcParams['text.usetex'] and not rcParams['text.latex.unicode']:
+            return r"$%0.0f^\circ$" % ((x / np.pi) * 180.0)
+        else:
+            # we use unicode, rather than mathtext with \circ, so
+            # that it will work correctly with any arbitrary font
+            # (assuming it has a degree sign), whereas $5\circ$
+            # will only work correctly with one of the supported
+            # math fonts (Computer Modern and STIX)
+            return u"%0.0f\u00b0" % ((x / np.pi) * 180.0)
+
+
+class RadialLocator(Locator):
+    """
+    Used to locate radius ticks.
+
+    Ensures that all ticks are strictly positive.  For all other
+    tasks, it delegates to the base
+    :class:`~matplotlib.ticker.Locator` (which may be different
+    depending on the scale of the *r*-axis.
+    """
+    def __init__(self, base):
+        self.base = base
+
+    def __call__(self):
+        ticks = self.base()
+        return [x for x in ticks if x > 0]
+
+    def autoscale(self):
+        return self.base.autoscale()
+
+    def pan(self, numsteps):
+        return self.base.pan(numsteps)
+
+    def zoom(self, direction):
+        return self.base.zoom(direction)
+
+    def refresh(self):
+        return self.base.refresh()
+
+    def view_limits(self, vmin, vmax):
+        vmin, vmax = self.base.view_limits(vmin, vmax)
+        return 0, vmax
+
+
 class PolarAxes(Axes):
     """
     A polar graph projection, where the input dimensions are *theta*, *r*.
@@ -25,199 +217,6 @@ class PolarAxes(Axes):
     """
     name = 'polar'
 
-    class PolarTransform(Transform):
-        """
-        The base polar transform.  This handles projection *theta* and
-        *r* into Cartesian coordinate space *x* and *y*, but does not
-        perform the ultimate affine transformation into the correct
-        position.
-        """
-        input_dims = 2
-        output_dims = 2
-        is_separable = False
-
-        def __init__(self, axis=None, use_rmin=True):
-            Transform.__init__(self)
-            self._axis = axis
-            self._use_rmin = use_rmin
-
-        def transform(self, tr):
-            xy = np.empty(tr.shape, np.float_)
-            if self._axis is not None:
-                if self._use_rmin:
-                    rmin = self._axis.viewLim.ymin
-                else:
-                    rmin = 0
-                theta_offset = self._axis.get_theta_offset()
-                theta_direction = self._axis.get_theta_direction()
-            else:
-                rmin = 0
-                theta_offset = 0
-                theta_direction = 1
-
-            t = tr[:, 0:1]
-            r = tr[:, 1:2]
-            x = xy[:, 0:1]
-            y = xy[:, 1:2]
-
-            t *= theta_direction
-            t += theta_offset
-
-            if rmin != 0:
-                r = r - rmin
-                mask = r < 0
-                x[:] = np.where(mask, np.nan, r * np.cos(t))
-                y[:] = np.where(mask, np.nan, r * np.sin(t))
-            else:
-                x[:] = r * np.cos(t)
-                y[:] = r * np.sin(t)
-
-            return xy
-        transform.__doc__ = Transform.transform.__doc__
-
-        transform_non_affine = transform
-        transform_non_affine.__doc__ = Transform.transform_non_affine.__doc__
-
-        def transform_path(self, path):
-            vertices = path.vertices
-            if len(vertices) == 2 and vertices[0, 0] == vertices[1, 0]:
-                return Path(self.transform(vertices), path.codes)
-            ipath = path.interpolated(path._interpolation_steps)
-            return Path(self.transform(ipath.vertices), ipath.codes)
-        transform_path.__doc__ = Transform.transform_path.__doc__
-
-        transform_path_non_affine = transform_path
-        transform_path_non_affine.__doc__ = Transform.transform_path_non_affine.__doc__
-
-        def inverted(self):
-            return PolarAxes.InvertedPolarTransform(self._axis, self._use_rmin)
-        inverted.__doc__ = Transform.inverted.__doc__
-
-    class PolarAffine(Affine2DBase):
-        """
-        The affine part of the polar projection.  Scales the output so
-        that maximum radius rests on the edge of the axes circle.
-        """
-        def __init__(self, scale_transform, limits):
-            """
-            *limits* is the view limit of the data.  The only part of
-            its bounds that is used is ymax (for the radius maximum).
-            The theta range is always fixed to (0, 2pi).
-            """
-            Affine2DBase.__init__(self)
-            self._scale_transform = scale_transform
-            self._limits = limits
-            self.set_children(scale_transform, limits)
-            self._mtx = None
-
-        def get_matrix(self):
-            if self._invalid:
-                limits_scaled = self._limits.transformed(self._scale_transform)
-                yscale = limits_scaled.ymax - limits_scaled.ymin
-                affine = Affine2D() \
-                    .scale(0.5 / yscale) \
-                    .translate(0.5, 0.5)
-                self._mtx = affine.get_matrix()
-                self._inverted = None
-                self._invalid = 0
-            return self._mtx
-        get_matrix.__doc__ = Affine2DBase.get_matrix.__doc__
-
-    class InvertedPolarTransform(Transform):
-        """
-        The inverse of the polar transform, mapping Cartesian
-        coordinate space *x* and *y* back to *theta* and *r*.
-        """
-        input_dims = 2
-        output_dims = 2
-        is_separable = False
-
-        def __init__(self, axis=None, use_rmin=True):
-            Transform.__init__(self)
-            self._axis = axis
-            self._use_rmin = use_rmin
-
-        def transform(self, xy):
-            if self._axis is not None:
-                if self._use_rmin:
-                    rmin = self._axis.viewLim.ymin
-                else:
-                    rmin = 0
-                theta_offset = self._axis.get_theta_offset()
-                theta_direction = self._axis.get_theta_direction()
-            else:
-                rmin = 0
-                theta_offset = 0
-                theta_direction = 1
-
-            x = xy[:, 0:1]
-            y = xy[:, 1:]
-            r = np.sqrt(x*x + y*y)
-            theta = np.arccos(x / r)
-            theta = np.where(y < 0, 2 * np.pi - theta, theta)
-
-            theta -= theta_offset
-            theta *= theta_direction
-
-            r += rmin
-
-            return np.concatenate((theta, r), 1)
-        transform.__doc__ = Transform.transform.__doc__
-
-        def inverted(self):
-            return PolarAxes.PolarTransform(self._axis, self._use_rmin)
-        inverted.__doc__ = Transform.inverted.__doc__
-
-    class ThetaFormatter(Formatter):
-        """
-        Used to format the *theta* tick labels.  Converts the native
-        unit of radians into degrees and adds a degree symbol.
-        """
-        def __call__(self, x, pos=None):
-            # \u00b0 : degree symbol
-            if rcParams['text.usetex'] and not rcParams['text.latex.unicode']:
-                return r"$%0.0f^\circ$" % ((x / np.pi) * 180.0)
-            else:
-                # we use unicode, rather than mathtext with \circ, so
-                # that it will work correctly with any arbitrary font
-                # (assuming it has a degree sign), whereas $5\circ$
-                # will only work correctly with one of the supported
-                # math fonts (Computer Modern and STIX)
-                return u"%0.0f\u00b0" % ((x / np.pi) * 180.0)
-
-    class RadialLocator(Locator):
-        """
-        Used to locate radius ticks.
-
-        Ensures that all ticks are strictly positive.  For all other
-        tasks, it delegates to the base
-        :class:`~matplotlib.ticker.Locator` (which may be different
-        depending on the scale of the *r*-axis.
-        """
-        def __init__(self, base):
-            self.base = base
-
-        def __call__(self):
-            ticks = self.base()
-            return [x for x in ticks if x > 0]
-
-        def autoscale(self):
-            return self.base.autoscale()
-
-        def pan(self, numsteps):
-            return self.base.pan(numsteps)
-
-        def zoom(self, direction):
-            return self.base.zoom(direction)
-
-        def refresh(self):
-            return self.base.refresh()
-
-        def view_limits(self, vmin, vmax):
-            vmin, vmax = self.base.view_limits(vmin, vmax)
-            return 0, vmax
-
-
     def __init__(self, *args, **kwargs):
         """
         Create a new Polar Axes for a polar plot.
@@ -228,8 +227,10 @@ class PolarAxes(Axes):
             each pair of data points.  Set to 1 to disable
             interpolation.
         """
+        self.resolution = kwargs.pop('resolution', 1)
+        self._default_theta_offset = kwargs.pop('theta_offset', 0)
+        self._default_theta_direction = kwargs.pop('theta_direction', 1)
 
-        self.resolution = kwargs.pop('resolution', None)
         if self.resolution not in (None, 1):
             warnings.warn(
                 """The resolution kwarg to Polar plots is now ignored.
@@ -258,8 +259,8 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
         # Why do we need to turn on yaxis tick labels, but
         # xaxis tick labels are already on?
 
-        self.set_theta_offset(0)
-        self.set_theta_direction(1)
+        self.set_theta_offset(self._default_theta_offset)
+        self.set_theta_direction(self._default_theta_direction)
 
     def _init_axis(self):
         "move this out of __init__ because non-separable axes don't use it"
@@ -454,8 +455,10 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
         self.yaxis.set_major_locator(
             self.RadialLocator(self.yaxis.get_major_locator()))
 
-    set_rscale = Axes.set_yscale
-    set_rticks = Axes.set_yticks
+    def set_rscale(self, *args, **kwargs):
+        return Axes.set_yscale(self, *args, **kwargs)
+    def set_rticks(self, *args, **kwargs):
+        return Axes.set_yticks(self, *args, **kwargs)
 
     @docstring.dedent_interpd
     def set_thetagrids(self, angles, labels=None, frac=None, fmt=None,
@@ -471,7 +474,7 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
         If *labels* is None, the labels will be ``fmt %% angle``
 
         *frac* is the fraction of the polar axes radius at which to
-        place the label (1 is the edge). Eg. 1.05 is outside the axes
+        place the label (1 is the edge). e.g., 1.05 is outside the axes
         and 0.95 is inside the axes.
 
         Return value is a list of tuples (*line*, *label*), where
@@ -484,6 +487,8 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
 
         ACCEPTS: sequence of floats
         """
+        # Make sure we take into account unitized data
+        angles = self.convert_yunits(angles)
         angles = np.asarray(angles, np.float_)
         self.set_xticks(angles * (np.pi / 180.0))
         if labels is not None:
@@ -521,6 +526,8 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
 
         ACCEPTS: sequence of floats
         """
+        # Make sure we take into account unitized data
+        radii = self.convert_xunits(radii)
         radii = np.asarray(radii)
         rmin = radii.min()
         if rmin <= 0:
@@ -646,6 +653,17 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
             scale = r / startr
             self.set_rmax(p.rmax / scale)
 
+
+# to keep things all self contained, we can put aliases to the Polar classes
+# defined above. This isn't strictly necessary, but it makes some of the
+# code more readable (and provides a backwards compatible Polar API)
+PolarAxes.PolarTransform = PolarTransform
+PolarAxes.PolarAffine = PolarAffine
+PolarAxes.InvertedPolarTransform = InvertedPolarTransform
+PolarAxes.ThetaFormatter = ThetaFormatter
+PolarAxes.RadialLocator = RadialLocator
+
+
 # These are a couple of aborted attempts to project a polar plot using
 # cubic bezier curves.
 
@@ -757,4 +775,3 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
 #             result = self.transform(result)
 #             return mpath.Path(result, codes)
 #         transform_path_non_affine = transform_path
-
