@@ -105,10 +105,28 @@ The plot directive has the following configuration options:
         A dictionary containing any non-standard rcParams that should
         be applied before each plot.
 
-"""
+    plot_apply_rcparams
+        By default, rcParams are applied when `context` option is not used in 
+        a plot  directive.  This configuration option overrides this behaviour 
+        and applies rcParams before each plot.
 
-import sys, os, glob, shutil, imp, warnings, cStringIO, re, textwrap, \
-       traceback, exceptions
+    plot_working_directory
+        By default, the working directory will be changed to the directory of 
+        the example, so the code can get at its data files, if any.  Also its 
+        path will be added to `sys.path` so it can import any helper modules 
+        sitting beside it.  This configuration option can be used to specify 
+        a central directory (also added to `sys.path`) where data files and 
+        helper modules for all code are located. 
+
+    plot_template
+        Provide a customized template for preparing resturctured text.
+        
+
+"""
+from __future__ import print_function
+
+import sys, os, glob, shutil, imp, warnings, cStringIO, re, textwrap
+import traceback
 
 from docutils.parsers.rst import directives
 from docutils import nodes
@@ -283,6 +301,9 @@ def setup(app):
     app.add_config_value('plot_basedir', None, True)
     app.add_config_value('plot_html_show_formats', True, True)
     app.add_config_value('plot_rcparams', {}, True)
+    app.add_config_value('plot_apply_rcparams', False, True)
+    app.add_config_value('plot_working_directory', None, True)
+    app.add_config_value('plot_template', None, True)
 
     app.connect('doctree-read', mark_plot_labels)
 
@@ -393,6 +414,16 @@ TEMPLATE = """
    .. image:: {{ build_dir }}/{{ img.basename }}.pdf
    {% endfor %}
 
+{{ only_texinfo }}
+
+   {% for img in images %}
+   .. image:: {{ build_dir }}/{{ img.basename }}.png
+      {%- for option in options %}
+      {{ option }}
+      {% endfor %}
+
+   {% endfor %}
+
 """
 
 exception_template = """
@@ -444,7 +475,19 @@ def run_code(code, code_path, ns=None, function_name=None):
 
     pwd = os.getcwd()
     old_sys_path = list(sys.path)
-    if code_path is not None:
+    if setup.config.plot_working_directory is not None:
+        try:
+            os.chdir(setup.config.plot_working_directory)
+        except OSError as err:
+            raise OSError(str(err) + '\n`plot_working_directory` option in'
+                          'Sphinx configuration file must be a valid '
+                          'directory path')
+        except TypeError as err:
+            raise TypeError(str(err) + '\n`plot_working_directory` option in '
+                            'Sphinx configuration file must be a string or '
+                            'None')
+        sys.path.insert(0, setup.config.plot_working_directory)
+    elif code_path is not None:
         dirname = os.path.abspath(os.path.dirname(code_path))
         os.chdir(dirname)
         sys.path.insert(0, dirname)
@@ -563,7 +606,7 @@ def render_figures(code, code_path, output_dir, output_base, context,
         ns = {}
 
     for i, code_piece in enumerate(code_pieces):
-        if not context:
+        if not context or config.plot_apply_rcparams:
             clear_state(config.plot_rcparams)
         run_code(code_piece, code_path, ns, function_name)
 
@@ -587,7 +630,7 @@ def render_figures(code, code_path, output_dir, output_base, context,
 
         results.append((code_piece, images))
 
-    if not context:
+    if not context or config.plot_apply_rcparams:
         clear_state(config.plot_rcparams)
 
     return results
@@ -624,9 +667,8 @@ def run(arguments, content, options, state_machine, state, lineno):
         else:
             function_name = None
 
-        fd = open(source_file_name, 'r')
-        code = fd.read()
-        fd.close()
+        with open(source_file_name, 'r') as fd:
+            code = fd.read()
         output_base = os.path.basename(source_file_name)
     else:
         source_file_name = rst_file
@@ -726,6 +768,7 @@ def run(arguments, content, options, state_machine, state, lineno):
 
         only_html = ".. only:: html"
         only_latex = ".. only:: latex"
+        only_texinfo = ".. only:: texinfo"
 
         if j == 0:
             src_link = source_link
@@ -733,13 +776,14 @@ def run(arguments, content, options, state_machine, state, lineno):
             src_link = None
 
         result = format_template(
-            TEMPLATE,
+            config.plot_template or TEMPLATE,
             dest_dir=dest_dir_link,
             build_dir=build_dir_link,
             source_link=src_link,
             multi_image=len(images) > 1,
             only_html=only_html,
             only_latex=only_latex,
+            only_texinfo=only_texinfo,
             options=opts,
             images=images,
             source_code=source_code,
@@ -764,10 +808,12 @@ def run(arguments, content, options, state_machine, state, lineno):
                     shutil.copyfile(fn, destimg)
 
     # copy script (if necessary)
-    if source_file_name == rst_file:
-        target_name = os.path.join(dest_dir, output_base + source_ext)
-        f = open(target_name, 'w')
-        f.write(unescape_doctest(code))
-        f.close()
+    target_name = os.path.join(dest_dir, output_base + source_ext)
+    with open(target_name, 'w') as f:
+        if source_file_name == rst_file:
+            code_escaped = unescape_doctest(code)
+        else:
+            code_escaped = code
+        f.write(code_escaped)
 
     return errors
