@@ -52,10 +52,13 @@ def streamplot(axes, x, y, u, v, density=1, linewidth=None, color=None,
 
         *stream_container* : StreamplotSet
             Container object with attributes
-                lines: `matplotlib.collections.LineCollection` of streamlines
-                arrows: collection of `matplotlib.patches.FancyArrowPatch`
-                        objects representing arrows half-way along stream
-                        lines.
+
+                - lines: `matplotlib.collections.LineCollection` of streamlines
+
+                - arrows: collection of `matplotlib.patches.FancyArrowPatch`
+                  objects representing arrows half-way along stream
+                  lines.
+
             This container will probably change in the future to allow changes
             to the colormap, alpha, etc. for both lines and arrows, but these
             changes should be backward compatible.
@@ -82,6 +85,8 @@ def streamplot(axes, x, y, u, v, density=1, linewidth=None, color=None,
     if use_multicolor_lines:
         assert color.shape == grid.shape
         line_colors = []
+        if np.any(np.isnan(color)):
+            color = np.ma.array(color, mask=np.isnan(color))
     else:
         line_kw['color'] = color
         arrow_kw['color'] = color
@@ -114,7 +119,7 @@ def streamplot(axes, x, y, u, v, density=1, linewidth=None, color=None,
 
     if use_multicolor_lines:
         if norm is None:
-            norm = mcolors.normalize(color.min(), color.max())
+            norm = mcolors.Normalize(color.min(), color.max())
         if cmap is None:
             cmap = cm.get_cmap(matplotlib.rcParams['image.cmap'])
         else:
@@ -197,7 +202,7 @@ class DomainMap(object):
     This class also has methods for adding trajectories to the StreamMask.
     Before adding a trajectory, run `start_trajectory` to keep track of regions
     crossed by a given trajectory. Later, if you decide the trajectory is bad
-    (e.g. if the trajectory is very short) just call `undo_trajectory`.
+    (e.g., if the trajectory is very short) just call `undo_trajectory`.
     """
 
     def __init__(self, grid, mask):
