@@ -1,4 +1,4 @@
-from nose.tools import assert_equal, assert_true
+from nose.tools import assert_equal, assert_true, assert_raises
 from matplotlib.testing.decorators import image_comparison, cleanup
 import matplotlib.pyplot as plt
 
@@ -74,6 +74,36 @@ def test_suptitle():
     fig.suptitle('title', color='g', rotation='30')
 
 
+@image_comparison(baseline_images=['alpha_background'],
+                  # only test png and svg. The PDF output appears correct,
+                  # but Ghostscript does not preserve the background color.
+                  extensions=['png', 'svg'],
+                  savefig_kwarg={'facecolor': (0, 1, 0.4),
+                                 'edgecolor': 'none'})
+def test_alpha():
+    # We want an image which has a background color and an
+    # alpha of 0.4.
+    fig = plt.figure(figsize=[2, 1])
+    fig.set_facecolor((0, 1, 0.4))
+    fig.patch.set_alpha(0.4)
+
+    import matplotlib.patches as mpatches
+    fig.patches.append(mpatches.CirclePolygon([20, 20],
+                                              radius=15,
+                                              alpha=0.6,
+                                              facecolor='red'))
+
+
+@cleanup
+def test_too_many_figures():
+    import warnings
+
+    with warnings.catch_warnings(record=True) as w:
+        for i in range(22):
+            fig = plt.figure()
+    assert len(w) == 1
+
+
 if __name__ == "__main__":
     import nose
     nose.runmodule(argv=['-s', '--with-doctest'], exit=False)
