@@ -7,13 +7,12 @@ from matplotlib.testing.decorators import image_comparison
                   extensions=['png'],
                   remove_text=True)
 def test_zorder():
-    data = [[  66386,  174296,],
-            [  58230,  381139,]]
+    data = [[66386, 174296],
+            [58230, 381139]]
 
     colLabels = ('Freeze', 'Wind')
     rowLabels = ['%d year' % x for x in (100, 50)]
 
-
     cellText = []
     yoff = np.array([0.0] * len(colLabels))
     for row in reversed(data):
