@@ -146,7 +146,7 @@ class Text(Artist):
     """
     zorder = 3
 
-    cached = maxdict(50)
+    _cached = maxdict(50)
 
     def __str__(self):
         return "Text(%g,%g,%s)" % (self._x, self._y, repr(self._text))
@@ -285,8 +285,8 @@ class Text(Artist):
         of a rotated text when necessary.
         """
         key = self.get_prop_tup()
-        if key in self.cached:
-            return self.cached[key]
+        if key in self._cached:
+            return self._cached[key]
 
         horizLayout = []
 
@@ -440,7 +440,7 @@ class Text(Artist):
         xs, ys = xys[:, 0], xys[:, 1]
 
         ret = bbox, zip(lines, whs, xs, ys), descent
-        self.cached[key] = ret
+        self._cached[key] = ret
         return ret
 
     def set_bbox(self, rectprops):
@@ -586,7 +586,8 @@ class Text(Artist):
                                              self._fontproperties, angle)
                     else:
                         path_effect.draw_text(renderer, gc, x, y, clean_line,
-                                             self._fontproperties, angle)
+                                             self._fontproperties, angle,
+                                             ismath=ismath)
             else:
                 if rcParams['text.usetex']:
                     renderer.draw_tex(gc, x, y, clean_line,
