@@ -676,11 +676,20 @@ class _ReducedHCT_Element():
                            [1., 1., 1.], [1., 0., 0.], [-2.,  0., -1.]])
 
     # 3) Loads Gauss points & weights on the 3 sub-_triangles for P2
-    #    exact integral - points at the middle of subtriangles apex
-    gauss_pts = np.array([[0.5, 0.5, 0.], [0.5, 0., 0.5], [0., 0.5, 0.5],
-                          [4./6., 1./6., 1./6.], [1./6., 4./6., 1./6.],
-                          [1./6., 1./6., 4./6.]])
-    gauss_w = np.array([1./9., 1./9., 1./9., 2./9., 2./9., 2./9.])
+    #    exact integral - 3 points on each subtriangles.
+    # NOTE: as the 2nd derivative is discontinuous , we really need those 9
+    # points!
+    n_gauss = 9
+    gauss_pts = np.array([[13./18.,  4./18.,  1./18.],
+                          [ 4./18., 13./18.,  1./18.],
+                          [ 7./18.,  7./18.,  4./18.],
+                          [ 1./18., 13./18.,  4./18.],
+                          [ 1./18.,  4./18., 13./18.],
+                          [ 4./18.,  7./18.,  7./18.],
+                          [ 4./18.,  1./18., 13./18.],
+                          [13./18.,  1./18.,  4./18.],
+                          [ 7./18.,  4./18.,  7./18.]], dtype=np.float64)
+    gauss_w = np.ones([9], dtype=np.float64) / 9.
 
     #  4) Stiffness matrix for curvature energy
     E = np.array([[1., 0., 0.], [0., 1., 0.], [0., 0., 2.]])
@@ -755,16 +764,16 @@ class _ReducedHCT_Element():
         y_sq = y*y
         z_sq = z*z
         dV = _to_matrix_vectorized([
-            [-3.*x_sq, -3.*x_sq],
-            [3.*y_sq, 0.],
-            [0., 3.*z_sq],
-            [-2.*x*z, -2.*x*z+x_sq],
-            [-2.*x*y+x_sq, -2.*x*y],
-            [2.*x*y-y_sq, -y_sq],
-            [2.*y*z, y_sq],
-            [z_sq, 2.*y*z],
-            [-z_sq, 2.*x*z-z_sq],
-            [x*z-y*z, x*y-y*z]])
+            [    -3.*x_sq,     -3.*x_sq],
+            [     3.*y_sq,           0.],
+            [          0.,      3.*z_sq],
+            [     -2.*x*z, -2.*x*z+x_sq],
+            [-2.*x*y+x_sq,      -2.*x*y],
+            [ 2.*x*y-y_sq,        -y_sq],
+            [      2.*y*z,         y_sq],
+            [        z_sq,       2.*y*z],
+            [       -z_sq,  2.*x*z-z_sq],
+            [     x*z-y*z,      x*y-y*z]])
         # Puts back dV in first apex basis
         dV = _prod_vectorized(dV, _extract_submatrices(
             self.rotate_dV, subtri, block_size=2, axis=0))
@@ -831,16 +840,16 @@ class _ReducedHCT_Element():
         y = ksi[:, 1, 0]
         z = ksi[:, 2, 0]
         d2V = _to_matrix_vectorized([
-            [6.*x, 6.*x, 6.*x],
-            [6.*y, 0., 0.],
-            [0., 6.*z, 0.],
-            [2.*z, 2.*z-4.*x, 2.*z-2.*x],
-            [2.*y-4.*x, 2.*y, 2.*y-2.*x],
-            [2.*x-4.*y, 0., -2.*y],
-            [2.*z, 0., 2.*y],
-            [0., 2.*y, 2.*z],
-            [0., 2.*x-4.*z, -2.*z],
-            [-2.*z, -2.*y, x-y-z]])
+            [     6.*x,      6.*x,      6.*x],
+            [     6.*y,        0.,        0.],
+            [       0.,      6.*z,        0.],
+            [     2.*z, 2.*z-4.*x, 2.*z-2.*x],
+            [2.*y-4.*x,      2.*y, 2.*y-2.*x],
+            [2.*x-4.*y,        0.,     -2.*y],
+            [     2.*z,        0.,      2.*y],
+            [       0.,      2.*y,      2.*z],
+            [       0., 2.*x-4.*z,     -2.*z],
+            [    -2.*z,     -2.*y,     x-y-z]])
         # Puts back d2V in first apex basis
         d2V = _prod_vectorized(d2V, _extract_submatrices(
             self.rotate_d2V, subtri, block_size=3, axis=0))
@@ -887,11 +896,11 @@ class _ReducedHCT_Element():
         H_rot, area = self.get_Hrot_from_J(J, return_area=True)
 
         # 3) Computes stiffness matrix
-        # Integration according to Gauss P2 rule for each subtri.
+        # Gauss quadrature.
         K = np.zeros([n, 9, 9], dtype=np.float64)
         weights = self.gauss_w
         pts = self.gauss_pts
-        for igauss in range(6):
+        for igauss in range(self.n_gauss):
             alpha = np.tile(pts[igauss, :], n).reshape(n, 3)
             alpha = np.expand_dims(alpha, 3)
             weight = weights[igauss]
@@ -916,7 +925,8 @@ class _ReducedHCT_Element():
 
         Returns
         -------
-        Returns H_rot used to rotate Hessian from local to global coordinates.
+        Returns H_rot used to rotate Hessian from local basis of first apex,
+        to global coordinates.
         if *return_area* is True, returns also the triangle area (0.5*det(J))
         """
         # Here we try to deal with the simpliest colinear cases ; a null
@@ -1040,8 +1050,8 @@ class _DOF_estimator():
         gradient.
         """
         J = CubicTriInterpolator._get_jacobian(self._tris_pts)
-        tri_z = self.z[self._triangles, :]
-        tri_dz = self.dz[self._triangles, :]
+        tri_z = self.z[self._triangles]
+        tri_dz = self.dz[self._triangles]
         tri_dof = self.get_dof_vec(tri_z, tri_dz, J)
         return tri_dof
 
