@@ -42,11 +42,14 @@ datetime objects::
     units.registry[datetime.date] = DateConverter()
 
 """
+from __future__ import print_function
+from matplotlib.cbook import iterable, is_numlike
 import numpy as np
-from matplotlib.cbook import iterable, is_numlike, is_string_like
+
 
 class AxisInfo:
-    'information to support default axis labeling and tick labeling, and default limits'
+    """information to support default axis labeling and tick labeling, and
+       default limits"""
     def __init__(self, majloc=None, minloc=None,
                  majfmt=None, minfmt=None, label=None,
                  default_limits=None):
@@ -106,6 +109,7 @@ class ConversionInterface:
         else:
             return is_numlike(x)
 
+
 class Registry(dict):
     """
     register types with conversion interface
@@ -117,7 +121,8 @@ class Registry(dict):
     def get_converter(self, x):
         'get the converter interface instance for x, or None'
 
-        if not len(self): return None # nothing registered
+        if not len(self):
+            return None  # nothing registered
         #DISABLED idx = id(x)
         #DISABLED cached = self._cached.get(idx)
         #DISABLED if cached is not None: return cached
@@ -128,13 +133,28 @@ class Registry(dict):
         if classx is not None:
             converter = self.get(classx)
 
+        if isinstance(x, np.ndarray) and x.size:
+            xravel = x.ravel()
+            try:
+                # pass the first value of x that is not masked back to
+                # get_converter
+                if not np.all(xravel.mask):
+                    # some elements are not masked
+                    converter = self.get_converter(
+                        xravel[np.argmin(xravel.mask)])
+                    return converter
+            except AttributeError:
+                # not a masked_array
+                converter = self.get_converter(xravel[0])
+                return converter
+
         if converter is None and iterable(x):
             for thisx in x:
-                # Make sure that recursing might actually lead to a solution, if
-                # we are just going to re-examine another item of the same kind,
-                # then do not look at it.
+                # Make sure that recursing might actually lead to a solution,
+                # if we are just going to re-examine another item of the same
+                # kind, then do not look at it.
                 if classx and classx != getattr(thisx, '__class__', None):
-                    converter = self.get_converter( thisx )
+                    converter = self.get_converter(thisx)
                     return converter
 
         #DISABLED self._cached[idx] = converter
