@@ -92,7 +92,7 @@ class CbarAxesBase(object):
             cb.update_bruteforce(m)
 
         self.cbid = mappable.callbacksSM.connect('changed', on_changed)
-        mappable.set_colorbar(cb, self)
+        mappable.colorbar = cb
 
         self.locator = cb.cbar_axis.get_major_locator()
 
