@@ -67,7 +67,7 @@ colormap_kw_doc = '''
     *format*      [ None | format string | Formatter object ]
                   If None, the
                   :class:`~matplotlib.ticker.ScalarFormatter` is used.
-                  If a format string is given, e.g. '%.3f', that is
+                  If a format string is given, e.g., '%.3f', that is
                   used. An alternative
                   :class:`~matplotlib.ticker.Formatter` object may be
                   given instead.
@@ -144,6 +144,19 @@ For more precise control, you can manually specify the positions of
 the axes objects in which the mappable and the colorbar are drawn.  In
 this case, do not use any of the axes properties kwargs.
 
+It is known that some vector graphics viewer (svg and pdf) renders white gaps
+between segments of the colorbar. This is due to bugs in the viewers not
+matplotlib. As a workaround the colorbar can be rendered with overlapping
+segments::
+
+    cbar = colorbar()
+    cbar.solids.set_edgecolor("face")
+    draw()
+
+However this has negative consequences in other circumstances. Particularly with
+semi transparent images (alpha < 1) and colorbar extensions and is not enabled
+by default see (issue #1188).
+
 returns:
     :class:`~matplotlib.colorbar.Colorbar` instance; see also its base class,
     :class:`~matplotlib.colorbar.ColorbarBase`.  Call the
@@ -518,7 +531,7 @@ class ColorbarBase(cm.ScalarMappable):
 
     def _add_solids(self, X, Y, C):
         '''
-        Draw the colors using :meth:`~matplotlib.axes.Axes.pcolor`;
+        Draw the colors using :meth:`~matplotlib.axes.Axes.pcolormesh`;
         optionally add separators.
         '''
         ## Change to pcolorfast after fixing bugs in some backends...
@@ -544,9 +557,8 @@ class ColorbarBase(cm.ScalarMappable):
         del self.solids
         del self.dividers
 
-        col = self.ax.pcolor(*args, **kw)
-        col.set_antialiased(False) # This is to suppress artifacts. We
-                                   # may use pcolormesh instead.
+        col = self.ax.pcolormesh(*args, **kw)
+
         self.solids = col
         if self.drawedges:
             self.dividers = collections.LineCollection(self._edges(X,Y),
@@ -813,6 +825,6 @@ def colorbar(mappable, cax=None, ax=None, **kw):
         cb.update_bruteforce(m)
 
     cbid = mappable.callbacksSM.connect('changed', on_changed)
-    mappable.set_colorbar(cb, cax)
+    mappable.colorbar = cb
     ax.figure.sca(ax)
     return cb
