@@ -109,7 +109,7 @@ class AxisArtistHelper(object):
             return trans
 
         def get_tick_iterators(self, axes):
-            # iter : iteratable object that yields (c, angle, l) where
+            # iter : iterable object that yields (c, angle, l) where
             # c, angle, l is position, tick angle, and label
 
             return iter_major, iter_minor
@@ -217,7 +217,6 @@ class AxisArtistHelper(object):
             return trans_tick
 
 
-
     class Floating(_Base):
         def __init__(self, nth_coord,
                      value):
@@ -438,9 +437,36 @@ class GridHelperBase(object):
         return not self._force_update
 
 
-    def get_gridlines(self):
+    def get_gridlines(self, which, axis):
+        """
+        Return list of grid lines as a list of paths (list of points).
+
+        *which* : "major" or "minor"
+        *axis* : "both", "x" or "y"
+        """
         return []
 
+    def new_gridlines(self, ax):
+        """
+        Create and return a new GridlineCollection instance.
+
+        *which* : "major" or "minor"
+        *axis* : "both", "x" or "y"
+
+        """
+        gridlines = GridlinesCollection(None, transform=ax.transData,
+                                        colors=rcParams['grid.color'],
+                                        linestyles=rcParams['grid.linestyle'],
+                                        linewidths=rcParams['grid.linewidth'])
+        ax._set_artist_props(gridlines)
+        gridlines.set_grid_helper(self)
+
+        ax.axes._set_artist_props(gridlines)
+        # gridlines.set_clip_path(self.axes.patch)
+        # set_clip_path need to be deferred after Axes.cla is completed.
+        # It is done inside the cla.
+
+        return gridlines
 
 
 class GridHelperRectlinear(GridHelperBase):
@@ -497,33 +523,43 @@ class GridHelperRectlinear(GridHelperBase):
         return axisline
 
 
-    def get_gridlines(self):
+    def get_gridlines(self, which="major", axis="both"):
         """
         return list of gridline coordinates in data coordinates.
+
+        *which* : "major" or "minor"
+        *axis* : "both", "x" or "y"
         """
 
         gridlines = []
 
-        locs = []
-        y1, y2 = self.axes.get_ylim()
-        if self.axes.xaxis._gridOnMajor:
-            locs.extend(self.axes.xaxis.major.locator())
-        if self.axes.xaxis._gridOnMinor:
-            locs.extend(self.axes.xaxis.minor.locator())
 
-        for x in locs:
-            gridlines.append([[x, x], [y1, y2]])
+        if axis in ["both", "x"]:
+            locs = []
+            y1, y2 = self.axes.get_ylim()
+            #if self.axes.xaxis._gridOnMajor:
+            if which in ["both", "major"]:
+                locs.extend(self.axes.xaxis.major.locator())
+            #if self.axes.xaxis._gridOnMinor:
+            if which in ["both", "minor"]:
+                locs.extend(self.axes.xaxis.minor.locator())
+
+            for x in locs:
+                gridlines.append([[x, x], [y1, y2]])
 
 
-        x1, x2 = self.axes.get_xlim()
-        locs = []
-        if self.axes.yaxis._gridOnMajor:
-            locs.extend(self.axes.yaxis.major.locator())
-        if self.axes.yaxis._gridOnMinor:
-            locs.extend(self.axes.yaxis.minor.locator())
+        if axis in ["both", "y"]:
+            x1, x2 = self.axes.get_xlim()
+            locs = []
+            if self.axes.yaxis._gridOnMajor:
+            #if which in ["both", "major"]:
+                locs.extend(self.axes.yaxis.major.locator())
+            if self.axes.yaxis._gridOnMinor:
+            #if which in ["both", "minor"]:
+                locs.extend(self.axes.yaxis.minor.locator())
 
-        for y in locs:
-            gridlines.append([[x1, x2], [y, y]])
+            for y in locs:
+                gridlines.append([[x1, x2], [y, y]])
 
         return gridlines
 
@@ -627,20 +663,25 @@ class Axes(maxes.Axes):
 
     axis = property(_get_axislines)
 
-    def _init_gridlines(self, grid_helper=None):
-        gridlines = GridlinesCollection(None, transform=self.transData,
-                                        colors=rcParams['grid.color'],
-                                        linestyles=rcParams['grid.linestyle'],
-                                        linewidths=rcParams['grid.linewidth'])
-        self._set_artist_props(gridlines)
+    def new_gridlines(self, grid_helper=None):
+        """
+        Create and return a new GridlineCollection instance.
+
+        *which* : "major" or "minor"
+        *axis* : "both", "x" or "y"
+
+        """
         if grid_helper is None:
             grid_helper = self.get_grid_helper()
-        gridlines.set_grid_helper(grid_helper)
 
-        self.axes._set_artist_props(gridlines)
-        # gridlines.set_clip_path(self.axes.patch)
-        # set_clip_path need to be deferred after Axes.cla is completed.
+        gridlines = grid_helper.new_gridlines(self)
+
+        return gridlines
+
+
+    def _init_gridlines(self, grid_helper=None):
         # It is done inside the cla.
+        gridlines = self.new_gridlines(grid_helper)
 
         self.gridlines = gridlines
 
@@ -668,7 +709,7 @@ class Axes(maxes.Axes):
         # axes_grid and the original mpl's grid, because axes_grid
         # explicitly set the visibility of the gridlines.
 
-        super(Axes, self).grid(b, **kwargs)
+        super(Axes, self).grid(b, which=which, axis=axis, **kwargs)
         if not self._axisline_on:
             return
 
@@ -680,6 +721,8 @@ class Axes(maxes.Axes):
             else:
                 b=False
 
+        self.gridlines.set_which(which)
+        self.gridlines.set_axis(axis)
         self.gridlines.set_visible(b)
 
         if len(kwargs):
@@ -767,38 +810,6 @@ class Axes(maxes.Axes):
         return _bbox
 
 
-    def set_xlim(self, left=None, right=None, emit=True, auto=False,
-                 swap_axis=True, **kw):
-
-        x1o, x2o = self.get_xlim()
-
-        maxes.Axes.set_xlim(self, left, right, emit, auto, **kw)
-        x1, x2 = self.get_xlim()
-
-        if not swap_axis:
-            return
-
-        if (x1o > x2o and x1 < x2) or (x1o < x2o and x1 > x2):
-            self.axis["right"], self.axis["left"] = self.axis["left"], self.axis["right"]
-
-            self.axis["left"].set_axis_direction("left")
-            self.axis["right"].set_axis_direction("right")
-
-
-    def set_ylim(self, bottom=None, top=None, emit=True, auto=False,
-                 swap_axis=True, **kw):
-
-        y1o, y2o = self.get_ylim()
-
-        maxes.Axes.set_ylim(self, bottom, top, emit, auto, **kw)
-        y1, y2 = self.get_ylim()
-
-        if y1o > y2o and y1 < y2 or (y1o < y2o and y1 > y2):
-            self.axis["top"], self.axis["bottom"] = self.axis["bottom"], self.axis["top"]
-
-            self.axis["top"].set_axis_direction("top")
-            self.axis["bottom"].set_axis_direction("bottom")
-
 
 
 Subplot = maxes.subplot_class_factory(Axes)
