@@ -1,10 +1,11 @@
 import numpy as np
 from math import degrees
 import math
+import warnings
 
 def atan2(dy, dx):
     if dx == 0 and dx == 0:
-        print "warning"
+        warnings.warn("dx and dy is 0")
         return 0
     else:
         return math.atan2(dy, dx)
@@ -28,7 +29,7 @@ def clip(xlines, ylines, x0, clip="right", xdir=True, ydir=True):
         ysign = 1
     else:
         ysign = -1
-        
+
 
     for x, y in zip(xlines, ylines):
 
@@ -95,7 +96,7 @@ def clip_line_to_rect(xline, yline, bbox):
 
     xdir = x1 > x0
     ydir = y1 > y0
-    
+
     if x1 > x0:
         lx1, ly1, c_right_ = clip([xline], [yline], x1, clip="right", xdir=xdir, ydir=ydir)
         lx2, ly2, c_left_ = clip(lx1, ly1, x0, clip="left", xdir=xdir, ydir=ydir)
@@ -110,7 +111,7 @@ def clip_line_to_rect(xline, yline, bbox):
         ly3, lx3, c_top_ = clip(ly2, lx2, y0, clip="right", xdir=ydir, ydir=xdir)
         ly4, lx4, c_bottom_ = clip(ly3, lx3, y1, clip="left", xdir=ydir, ydir=xdir)
 
-        
+
     # lx1, ly1, c_right_ = clip([xline], [yline], x1, clip="right")
     # lx2, ly2, c_left_ = clip(lx1, ly1, x0, clip="left")
     # ly3, lx3, c_top_ = clip(ly2, lx2, y1, clip="right")
