@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import numpy as np
 import matplotlib.cbook as mcbook
 from matplotlib.transforms import Bbox
@@ -7,7 +9,6 @@ clip_line_to_rect = clip_path.clip_line_to_rect
 import matplotlib.ticker as mticker
 from matplotlib.transforms import Transform
 
-
 # extremes finder
 
 class ExtremeFinderSimple(object):
@@ -345,4 +346,4 @@ if __name__ == "__main__":
 
     fmt = FormatterPrettyPrint()
 
-    print fmt("left", None, locs)
+    print(fmt("left", None, locs))
