@@ -33,10 +33,17 @@ def xlformat_factory(format):
     copy the format, perform any overrides, and attach an xlstyle instance
     copied format is returned
     """
+
+    #if we have created an excel format already using this format,
+    #don't recreate it; mlab.FormatObj override has to make objs with
+    #the same props hash to the same value
+    key = hash(format)
+    fmt_ = xlformat_factory.created_formats.get(key)
+    if fmt_ is not None:
+        return fmt_
+
     format = copy.deepcopy(format)
 
-
-
     xlstyle = excel.XFStyle()
     if isinstance(format, mlab.FormatPercent):
        zeros = ''.join(['0']*format.precision)
@@ -55,8 +62,12 @@ def xlformat_factory(format):
 
     format.xlstyle = xlstyle
 
+    xlformat_factory.created_formats[ key ] = format
+
     return format
 
+xlformat_factory.created_formats = {}
+
 def rec2excel(r, ws, formatd=None, rownum=0, colnum=0, nanstr='NaN', infstr='Inf'):
     """
     save record array r to excel xlwt worksheet ws
@@ -113,7 +124,7 @@ def rec2excel(r, ws, formatd=None, rownum=0, colnum=0, nanstr='NaN', infstr='Inf
                 ws.write(rownum, colnum+i, nanstr)
             elif mlab.safe_isinf(val):
                 sgn = np.sign(val)
-                if sgn<0: s = infstr
+                if sgn>0: s = infstr
                 else: s = '-%s'%infstr
                 ws.write(rownum, colnum+i, s)
             elif format.xlstyle is None:
