@@ -6,6 +6,7 @@
 /* Python API mandates Python.h is included *first* */
 #include "Python.h"
 
+/* TODO: Remove this dependency */
 #include "ft2font.h"
 #include "_image.h"
 #include "_backend_agg.h"
@@ -39,6 +40,7 @@
 
 #include "numpy/arrayobject.h"
 #include "agg_py_transforms.h"
+
 #include "file_compat.h"
 
 #ifndef M_PI
@@ -193,6 +195,7 @@ GCAgg::GCAgg(const Py::Object &gc, double dpi) :
     _VERBOSE("GCAgg::GCAgg");
     linewidth = points_to_pixels(gc.getAttr("_linewidth")) ;
     alpha = Py::Float(gc.getAttr("_alpha"));
+    forced_alpha = Py::Boolean(gc.getAttr("_forced_alpha"));
     color = get_color(gc);
     _set_antialiased(gc);
     _set_linecap(gc);
@@ -202,6 +205,7 @@ GCAgg::GCAgg(const Py::Object &gc, double dpi) :
     _set_clip_path(gc);
     _set_snap(gc);
     _set_hatch_path(gc);
+    _set_sketch_params(gc);
 }
 
 
@@ -219,12 +223,11 @@ GCAgg::get_color(const Py::Object& gc)
     _VERBOSE("GCAgg::get_color");
     Py::Tuple rgb = Py::Tuple(gc.getAttr("_rgb"));
 
-    double alpha = Py::Float(gc.getAttr("_alpha"));
-
     double r = Py::Float(rgb[0]);
     double g = Py::Float(rgb[1]);
     double b = Py::Float(rgb[2]);
-    return agg::rgba(r, g, b, alpha);
+    double a = Py::Float(rgb[3]);
+    return agg::rgba(r, g, b, a);
 }
 
 
@@ -373,6 +376,24 @@ GCAgg::_set_hatch_path(const Py::Object& gc)
         throw Py::Exception();
 }
 
+void
+GCAgg::_set_sketch_params(const Py::Object& gc)
+{
+    _VERBOSE("GCAgg::_get_sketch_params");
+
+    Py::Object method_obj = gc.getAttr("get_sketch_params");
+    Py::Callable method(method_obj);
+    Py::Object result = method.apply(Py::Tuple());
+    if (result.ptr() == Py_None) {
+        sketch_scale = 0.0;
+    } else {
+        Py::Tuple sketch_params(result);
+        sketch_scale = Py::Float(sketch_params[0]);
+        sketch_length = Py::Float(sketch_params[1]);
+        sketch_randomness = Py::Float(sketch_params[2]);
+    }
+}
+
 
 const size_t
 RendererAgg::PIXELS_PER_INCH(96);
@@ -409,7 +430,7 @@ RendererAgg::RendererAgg(unsigned int width, unsigned int height, double dpi,
     renderingBuffer.attach(pixBuffer, width, height, stride);
     pixFmt.attach(renderingBuffer);
     rendererBase.attach(pixFmt);
-    rendererBase.clear(agg::rgba(1, 1, 1, 0));
+    rendererBase.clear(agg::rgba(0, 0, 0, 0));
     rendererAA.attach(rendererBase);
     rendererBin.attach(rendererBase);
     hatchRenderingBuffer.attach(hatchBuffer, HATCH_SIZE, HATCH_SIZE,
@@ -456,7 +477,7 @@ RendererAgg::set_clipbox(const Py::Object& cliprect, R& rasterizer)
 
 
 std::pair<bool, agg::rgba>
-RendererAgg::_get_rgba_face(const Py::Object& rgbFace, double alpha)
+RendererAgg::_get_rgba_face(const Py::Object& rgbFace, double alpha, bool forced_alpha)
 {
     _VERBOSE("RendererAgg::_get_rgba_face");
     std::pair<bool, agg::rgba> face;
@@ -469,7 +490,14 @@ RendererAgg::_get_rgba_face(const Py::Object& rgbFace, double alpha)
     {
         face.first = true;
         Py::Tuple rgb = Py::Tuple(rgbFace);
-        face.second = rgb_to_color(rgb, alpha);
+        if (forced_alpha || rgb.length() < 4)
+        {
+            face.second = rgb_to_color(rgb, alpha);
+        }
+        else
+        {
+            face.second = rgb_to_color(rgb, Py::Float(rgb[3]));
+        }
     }
     return face;
 }
@@ -616,7 +644,11 @@ RendererAgg::render_clippath(const Py::Object& clippath,
         rendererBaseAlphaMask.clear(agg::gray8(0, 0));
         transformed_path_t transformed_clippath(clippath_iter, trans);
         agg::conv_curve<transformed_path_t> curved_clippath(transformed_clippath);
-        theRasterizer.add_path(curved_clippath);
+        try {
+            theRasterizer.add_path(curved_clippath);
+        } catch (std::overflow_error &e) {
+            throw Py::OverflowError(e.what());
+        }
         rendererAlphaMask.color(agg::gray8(255, 255));
         agg::render_scanlines(theRasterizer, scanlineAlphaMask, rendererAlphaMask);
         lastclippath = clippath;
@@ -677,7 +709,7 @@ RendererAgg::draw_markers(const Py::Tuple& args)
     curve_t            path_curve(path_snapped);
     path_curve.rewind(0);
 
-    facepair_t face = _get_rgba_face(face_obj, gc.alpha);
+    facepair_t face = _get_rgba_face(face_obj, gc.alpha, gc.forced_alpha);
 
     //maxim's suggestions for cached scanlines
     agg::scanline_storage_aa8 scanlines;
@@ -695,7 +727,11 @@ RendererAgg::draw_markers(const Py::Tuple& args)
         unsigned fillSize = 0;
         if (face.first)
         {
-            theRasterizer.add_path(marker_path_curve);
+            try {
+                theRasterizer.add_path(marker_path_curve);
+            } catch (std::overflow_error &e) {
+                throw Py::OverflowError(e.what());
+            }
             agg::render_scanlines(theRasterizer, slineP8, scanlines);
             fillSize = scanlines.byte_size();
             if (fillSize >= MARKER_CACHE_SIZE)
@@ -710,7 +746,11 @@ RendererAgg::draw_markers(const Py::Tuple& args)
         stroke.line_cap(gc.cap);
         stroke.line_join(gc.join);
         theRasterizer.reset();
-        theRasterizer.add_path(stroke);
+        try {
+            theRasterizer.add_path(stroke);
+        } catch (std::overflow_error &e) {
+            throw Py::OverflowError(e.what());
+        }
         agg::render_scanlines(theRasterizer, slineP8, scanlines);
         unsigned strokeSize = scanlines.byte_size();
         if (strokeSize >= MARKER_CACHE_SIZE)
@@ -981,7 +1021,11 @@ RendererAgg::draw_text_image(const Py::Tuple& args)
     span_gen_type output_span_generator(&image_span_generator, gc.color);
     renderer_type ri(rendererBase, sa, output_span_generator);
 
-    theRasterizer.add_path(rect2);
+    try {
+        theRasterizer.add_path(rect2);
+    } catch (std::overflow_error &e) {
+        throw Py::OverflowError(e.what());
+    }
     agg::render_scanlines(theRasterizer, slineP8, ri);
 
     return Py::Object();
@@ -1090,7 +1134,7 @@ RendererAgg::draw_image(const Py::Tuple& args)
         inv_mtx.invert();
 
         typedef agg::span_allocator<agg::rgba8> color_span_alloc_type;
-        typedef agg::image_accessor_clip<agg::pixfmt_rgba32>
+        typedef agg::image_accessor_clip<agg::pixfmt_rgba32_plain>
             image_accessor_type;
         typedef agg::span_interpolator_linear<> interpolator_type;
         typedef agg::span_image_filter_rgba_nn<image_accessor_type,
@@ -1118,7 +1162,11 @@ RendererAgg::draw_image(const Py::Tuple& args)
             amask_ren_type r(pfa);
             renderer_type_alpha ri(r, sa, spans);
 
-            theRasterizer.add_path(rect2);
+            try {
+                theRasterizer.add_path(rect2);
+            } catch (std::overflow_error &e) {
+                throw Py::OverflowError(e.what());
+            }
             agg::render_scanlines(theRasterizer, scanlineAlphaMask, ri);
         }
         else
@@ -1132,7 +1180,11 @@ RendererAgg::draw_image(const Py::Tuple& args)
             ren_type r(pixFmt);
             renderer_type ri(r, sa, spans);
 
-            theRasterizer.add_path(rect2);
+            try {
+                theRasterizer.add_path(rect2);
+            } catch (std::overflow_error &e) {
+                throw Py::OverflowError(e.what());
+            }
             agg::render_scanlines(theRasterizer, slineP8, ri);
         }
 
@@ -1167,7 +1219,11 @@ void RendererAgg::_draw_path(path_t& path, bool has_clippath,
     // Render face
     if (face.first)
     {
-        theRasterizer.add_path(path);
+        try {
+            theRasterizer.add_path(path);
+        } catch (std::overflow_error &e) {
+            throw Py::OverflowError(e.what());
+        }
 
         if (gc.isaa)
         {
@@ -1234,9 +1290,17 @@ void RendererAgg::_draw_path(path_t& path, bool has_clippath,
         rb.clear(agg::rgba(0.0, 0.0, 0.0, 0.0));
         rs.color(gc.color);
 
-        theRasterizer.add_path(hatch_path_curve);
+        try {
+            theRasterizer.add_path(hatch_path_curve);
+        } catch (std::overflow_error &e) {
+            throw Py::OverflowError(e.what());
+        }
         agg::render_scanlines(theRasterizer, slineP8, rs);
-        theRasterizer.add_path(hatch_path_stroke);
+        try {
+            theRasterizer.add_path(hatch_path_stroke);
+        } catch (std::overflow_error &e) {
+            throw Py::OverflowError(e.what());
+        }
         agg::render_scanlines(theRasterizer, slineP8, rs);
 
         // Put clipping back on, if originally set on entry to this
@@ -1253,8 +1317,22 @@ void RendererAgg::_draw_path(path_t& path, bool has_clippath,
         agg::span_allocator<agg::rgba8> sa;
         img_source_type img_src(hatch_img_pixf);
         span_gen_type sg(img_src, 0, 0);
-        theRasterizer.add_path(path);
-        agg::render_scanlines_aa(theRasterizer, slineP8, rendererBase, sa, sg);
+        try {
+            theRasterizer.add_path(path);
+        } catch (std::overflow_error &e) {
+            throw Py::OverflowError(e.what());
+        }
+
+        if (has_clippath)
+        {
+           pixfmt_amask_type pfa(pixFmt, alphaMask);
+           amask_ren_type ren(pfa);
+           agg::render_scanlines_aa(theRasterizer, slineP8, ren, sa, sg);
+        }
+        else
+        {
+           agg::render_scanlines_aa(theRasterizer, slineP8, rendererBase, sa, sg);
+        }
     }
 
     // Render stroke
@@ -1271,7 +1349,11 @@ void RendererAgg::_draw_path(path_t& path, bool has_clippath,
             stroke.width(linewidth);
             stroke.line_cap(gc.cap);
             stroke.line_join(gc.join);
-            theRasterizer.add_path(stroke);
+            try {
+                theRasterizer.add_path(stroke);
+            } catch (std::overflow_error &e) {
+                throw Py::OverflowError(e.what());
+            }
         }
         else
         {
@@ -1292,7 +1374,11 @@ void RendererAgg::_draw_path(path_t& path, bool has_clippath,
             stroke.line_cap(gc.cap);
             stroke.line_join(gc.join);
             stroke.width(linewidth);
-            theRasterizer.add_path(stroke);
+            try {
+                theRasterizer.add_path(stroke);
+            } catch (std::overflow_error &e) {
+                throw Py::OverflowError(e.what());
+            }
         }
 
         if (gc.isaa)
@@ -1340,6 +1426,7 @@ RendererAgg::draw_path(const Py::Tuple& args)
     typedef PathSnapper<clipped_t>             snapped_t;
     typedef PathSimplifier<snapped_t>          simplify_t;
     typedef agg::conv_curve<simplify_t>        curve_t;
+    typedef Sketch<curve_t>                    sketch_t;
 
     _VERBOSE("RendererAgg::draw_path");
     args.verify_length(3, 4);
@@ -1351,7 +1438,7 @@ RendererAgg::draw_path(const Py::Tuple& args)
     if (args.size() == 4)
         face_obj = args[3];
 
-    facepair_t face = _get_rgba_face(face_obj, gc.alpha);
+    facepair_t face = _get_rgba_face(face_obj, gc.alpha, gc.forced_alpha);
 
     theRasterizer.reset_clipping();
     rendererBase.reset_clipping(true);
@@ -1373,10 +1460,11 @@ RendererAgg::draw_path(const Py::Tuple& args)
     snapped_t          snapped(clipped, gc.snap_mode, path.total_vertices(), snapping_linewidth);
     simplify_t         simplified(snapped, simplify, path.simplify_threshold());
     curve_t            curve(simplified);
+    sketch_t           sketch(curve, gc.sketch_scale, gc.sketch_length, gc.sketch_randomness);
 
     try
     {
-        _draw_path(curve, has_clippath, face, gc);
+        _draw_path(sketch, has_clippath, face, gc);
     }
     catch (const char* e)
     {
@@ -1663,7 +1751,7 @@ RendererAgg::draw_path_collection(const Py::Tuple& args)
 
     try
     {
-        _draw_path_collection_generic<PathListGenerator, 0, 1>
+        _draw_path_collection_generic<PathListGenerator, 1, 1>
         (gc,
          master_transform,
          gc.cliprect,
@@ -1889,7 +1977,12 @@ RendererAgg::_draw_gouraud_triangle(const double* points,
         tpoints[4], tpoints[5],
         0.5);
 
-    theRasterizer.add_path(span_gen);
+    try {
+        theRasterizer.add_path(span_gen);
+    } catch (std::overflow_error &e) {
+        throw Py::OverflowError(e.what()
+                                );
+    }
 
     if (has_clippath)
     {
@@ -2040,7 +2133,6 @@ RendererAgg::write_rgba(const Py::Tuple& args)
         if ((py_file = npy_PyFile_OpenFile(py_fileobj.ptr(), (char *)"wb")) == NULL) {
             throw Py::Exception();
         }
-        close_file = true;
     }
     else
     {
@@ -2051,7 +2143,9 @@ RendererAgg::write_rgba(const Py::Tuple& args)
     {
         if (fwrite(pixBuffer, 1, NUMBYTES, fp) != NUMBYTES)
         {
-            npy_PyFile_DupClose(py_file, fp);
+            if (npy_PyFile_DupClose(py_file, fp)) {
+              throw Py::RuntimeError("Error closing dupe file handle");
+            }
 
             if (close_file) {
                 npy_PyFile_CloseFile(py_file);
@@ -2061,7 +2155,9 @@ RendererAgg::write_rgba(const Py::Tuple& args)
             throw Py::RuntimeError("Error writing to file");
         }
 
-        npy_PyFile_DupClose(py_file, fp);
+        if (npy_PyFile_DupClose(py_file, fp)) {
+          throw Py::RuntimeError("Error closing dupe file handle");
+        }
 
         if (close_file) {
             npy_PyFile_CloseFile(py_file);
@@ -2329,7 +2425,7 @@ RendererAgg::clear(const Py::Tuple& args)
     _VERBOSE("RendererAgg::clear");
 
     args.verify_length(0);
-    rendererBase.clear(agg::rgba(1, 1, 1, 0));
+    rendererBase.clear(agg::rgba(0, 0, 0, 0));
 
     return Py::Object();
 }
