@@ -1,3 +1,4 @@
+
 /* -*- mode: c++; c-basic-offset: 4 -*- */
 
 #include <pygobject.h>
@@ -121,6 +122,7 @@ private:
                               destbuffer,
                               deststride);
 
+        gdk_gc_destroy(gc);
         if (needfree)
         {
             delete [] destbuffer;
@@ -131,9 +133,7 @@ private:
     }
 };
 
-
-extern "C"
-DL_EXPORT(void)
+PyMODINIT_FUNC
 init_gtkagg(void)
 {
     init_pygobject();
