@@ -33,7 +33,7 @@
 #include "mplutils.h"
 
 
-typedef agg::pixfmt_rgba32 pixfmt;
+typedef agg::pixfmt_rgba32_plain pixfmt;
 typedef agg::pixfmt_rgba32_pre pixfmt_pre;
 typedef agg::renderer_base<pixfmt> renderer_base;
 typedef agg::span_interpolator_linear<> interpolator_type;
@@ -202,10 +202,10 @@ Image::as_rgba_str(const Py::Tuple& args, const Py::Dict& kwargs)
     std::pair<agg::int8u*, bool> bufpair = _get_output_buffer();
 
     #if PY3K
-    Py::Object ret =  Py::asObject(Py_BuildValue("lly#", rowsOut, colsOut,
+    Py::Object ret =  Py::asObject(Py_BuildValue("nny#", rowsOut, colsOut,
                                    bufpair.first, colsOut * rowsOut * 4));
     #else
-    Py::Object ret =  Py::asObject(Py_BuildValue("lls#", rowsOut, colsOut,
+    Py::Object ret =  Py::asObject(Py_BuildValue("nns#", rowsOut, colsOut,
                                    bufpair.first, colsOut * rowsOut * 4));
     #endif
 
@@ -272,7 +272,7 @@ Image::color_conv(const Py::Tuple& args)
     }
 #endif
 
-    PyObject* o = Py_BuildValue("llN", rowsOut, colsOut, py_buffer);
+    PyObject* o = Py_BuildValue("nnN", rowsOut, colsOut, py_buffer);
     return Py::asObject(o);
 }
 
@@ -290,7 +290,7 @@ Image::buffer_rgba(const Py::Tuple& args)
 
     args.verify_length(0);
     int row_len = colsOut * 4;
-    PyObject* o = Py_BuildValue("lls#", rowsOut, colsOut,
+    PyObject* o = Py_BuildValue("nns#", rowsOut, colsOut,
                                 rbufOut, row_len * rowsOut);
     return Py::asObject(o);
 }
@@ -406,10 +406,6 @@ Image::resize(const Py::Tuple& args, const Py::Dict& kwargs)
 
     typedef agg::span_allocator<agg::rgba8> span_alloc_type;
     span_alloc_type sa;
-    agg::rgba8 background(agg::rgba8(int(255*bg.r),
-                                     int(255*bg.g),
-                                     int(255*bg.b),
-                                     int(255*bg.a)));
 
     // the image path
     agg::path_storage path;
@@ -440,15 +436,11 @@ Image::resize(const Py::Tuple& args, const Py::Dict& kwargs)
 
     case NEAREST:
     {
-        if (colsIn == numcols && rowsIn == numrows) {
-            memcpy(bufferOut, bufferIn, colsIn * rowsIn * 4);
-        } else {
-            typedef agg::span_image_filter_rgba_nn<img_accessor_type, interpolator_type> span_gen_type;
-            typedef agg::renderer_scanline_aa<renderer_base, span_alloc_type, span_gen_type> renderer_type;
-            span_gen_type sg(ia, interpolator);
-            renderer_type ri(rb, sa, sg);
-            agg::render_scanlines(ras, sl, ri);
-        }
+        typedef agg::span_image_filter_rgba_nn<img_accessor_type, interpolator_type> span_gen_type;
+        typedef agg::renderer_scanline_aa<renderer_base, span_alloc_type, span_gen_type> renderer_type;
+        span_gen_type sg(ia, interpolator);
+        renderer_type ri(rb, sa, sg);
+        agg::render_scanlines(ras, sl, ri);
     }
     break;
 
@@ -804,6 +796,8 @@ _image_module::from_images(const Py::Tuple& args)
     Py::Tuple tup;
 
     size_t ox(0), oy(0), thisx(0), thisy(0);
+    float alpha;
+    bool apply_alpha;
 
     //copy image 0 output buffer into return images output buffer
     Image* imo = new Image;
@@ -824,13 +818,23 @@ _image_module::from_images(const Py::Tuple& args)
     pixfmt pixf(*imo->rbufOut);
     renderer_base rb(pixf);
 
-    rb.clear(agg::rgba(1, 1, 1, 1));
+    rb.clear(agg::rgba(0, 0, 0, 0));
     for (size_t imnum = 0; imnum < N; imnum++)
     {
         tup = Py::Tuple(tups[imnum]);
         Image* thisim = static_cast<Image*>(tup[0].ptr());
         ox = (long)Py::Int(tup[1]);
         oy = (long)Py::Int(tup[2]);
+        if (tup.size() <= 3 || tup[3].ptr() == Py_None)
+        {
+            apply_alpha = false;
+        }
+        else
+        {
+            apply_alpha = true;
+            alpha = Py::Float(tup[3]);
+        }
+
         bool isflip = (thisim->rbufOut->stride()) < 0;
         //std::cout << "from images " << isflip << "; stride=" << thisim->rbufOut->stride() << std::endl;
         size_t ind = 0;
@@ -859,7 +863,14 @@ _image_module::from_images(const Py::Tuple& args)
                 p.r = *(thisim->bufferOut + ind++);
                 p.g = *(thisim->bufferOut + ind++);
                 p.b = *(thisim->bufferOut + ind++);
-                p.a = *(thisim->bufferOut + ind++);
+                if (apply_alpha)
+                {
+                    p.a = (pixfmt::value_type) *(thisim->bufferOut + ind++) * alpha;
+                }
+                else
+                {
+                    p.a = *(thisim->bufferOut + ind++);
+                }
                 pixf.blend_pixel(thisx, thisy, p, 255);
             }
         }
