@@ -1,3 +1,5 @@
+/* -*- mode: c; c-basic-offset: 4 -*- */
+
 /*
   cntr.c
   General purpose contour tracer for quadrilateral meshes.
@@ -11,14 +13,20 @@
     was written by following the Python "Extending and Embedding"
     tutorial.
 
-  $Id: cntr.c 8364 2010-06-01 19:06:28Z mdboom $
+  $Id$
  */
 
 #include <Python.h>
 #include "structmember.h"
 #include <stdlib.h>
 #include <stdio.h>
-#include "numerix.h"
+#include "numpy/arrayobject.h"
+
+#if PY_MAJOR_VERSION >= 3
+#define PY3K 1
+#else
+#define PY3K 0
+#endif
 
 /* Note that all arrays in these routines are Fortran-style,
    in the sense that the "i" index varies fastest; the dimensions
@@ -1364,8 +1372,8 @@ int reorder(double *xpp, double *ypp, short *kpp,
     int maxnsegs = npts/2 + 1;
 
     /* allocate maximum possible size--gross overkill */
-    i0 = malloc(maxnsegs * sizeof(int));
-    i1 = malloc(maxnsegs * sizeof(int));
+    i0 = (int *)malloc(maxnsegs * sizeof(int));
+    i1 = (int *)malloc(maxnsegs * sizeof(int));
 
     /* Find the segments. */
     iseg = 0;
@@ -1398,7 +1406,7 @@ int reorder(double *xpp, double *ypp, short *kpp,
 
     /* Find the subpaths as sets of connected segments. */
 
-    subp = malloc(nsegs * sizeof(int));
+    subp = (int *)malloc(nsegs * sizeof(int));
     for (i=0; i<nsegs; i++) subp[i] = -1;
 
     nsp = 0;
@@ -1743,7 +1751,11 @@ static void
 Cntr_dealloc(Cntr* self)
 {
     Cntr_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    #if PY3K
+        Py_TYPE(self)->tp_free((PyObject*)self);
+    #else
+        self->ob_type->tp_free((PyObject*)self);
+    #endif
 }
 
 static PyObject *
@@ -1774,7 +1786,7 @@ Cntr_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 static int
 Cntr_init(Cntr *self, PyObject *args, PyObject *kwds)
 {
-    static char *kwlist[] = {"x", "y", "z", "mask", NULL};
+    static const char *kwlist[] = {"x", "y", "z", "mask", NULL};
     PyObject *xarg, *yarg, *zarg, *marg;
     PyArrayObject *xpa, *ypa, *zpa, *mpa;
     long iMax, jMax;
@@ -1782,7 +1794,7 @@ Cntr_init(Cntr *self, PyObject *args, PyObject *kwds)
 
     marg = NULL;
 
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "OOO|O", kwlist,
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "OOO|O", (char **)kwlist,
                                       &xarg, &yarg, &zarg, &marg))
         return -1;
     if (marg == Py_None)
@@ -1804,7 +1816,7 @@ Cntr_init(Cntr *self, PyObject *args, PyObject *kwds)
                                                       PyArray_DOUBLE, 2, 2);
     if (marg)
         mpa = (PyArrayObject *) PyArray_ContiguousFromObject(marg,
-                                                      PyArray_SBYTE, 2, 2);
+                                                      PyArray_BYTE, 2, 2);
     else
         mpa = NULL;
 
@@ -1856,9 +1868,9 @@ Cntr_trace(Cntr *self, PyObject *args, PyObject *kwds)
     double levels[2] = {0.0, -1e100};
     int nlevels = 2;
     long nchunk = 0L;
-    static char *kwlist[] = {"level0", "level1",  "nchunk", NULL};
+    static const char *kwlist[] = {"level0", "level1",  "nchunk", NULL};
 
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "d|dl", kwlist,
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "d|dl", (char **)kwlist,
                                       levels, levels+1, &nchunk))
     {
         return NULL;
@@ -1913,8 +1925,12 @@ static PyMethodDef Cntr_methods[] = {
 };
 
 static PyTypeObject CntrType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                         /*ob_size*/
+    #if PY3K
+        PyVarObject_HEAD_INIT(NULL, 0)
+    #else
+        PyObject_HEAD_INIT(NULL)
+        0,                         /*ob_size*/
+    #endif
     "cntr.Cntr",               /*tp_name*/
     sizeof(Cntr),              /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -1958,24 +1974,54 @@ static PyMethodDef module_methods[] = {
     {NULL}  /* Sentinel */
 };
 
+#if PY3K
+static PyModuleDef cntr_module = {
+    PyModuleDef_HEAD_INIT,
+    "_cntr",
+    "Contouring engine as an extension type (numpy).",
+    -1,
+    module_methods,
+    NULL, NULL, NULL, NULL
+};
+
+#define ERROR_RETURN return NULL
+
+PyMODINIT_FUNC
+PyInit__cntr(void)
+#else
+#define ERROR_RETURN return
+
 PyMODINIT_FUNC
 init_cntr(void)
+#endif
 {
     PyObject* m;
 
-    if (PyType_Ready(&CntrType) < 0)
-        return;
+    if (PyType_Ready(&CntrType) < 0) {
+        ERROR_RETURN;
+    }
 
-    m = Py_InitModule3("_cntr", module_methods,
-                       "Contouring engine as an extension type (numpy).");
+    #if PY3K
+        m = PyModule_Create(&cntr_module);
+    #else
+        m = Py_InitModule3("_cntr", module_methods,
+                           "Contouring engine as an extension type (numpy).");
+    #endif
+
+    if (m == NULL) {
+        ERROR_RETURN;
+    }
 
-    if (m == NULL)
-      return;
     PyModule_AddIntConstant(m, "_slitkind", (long)kind_slit_up );
     /* We can add all the point_kinds values later if we need them. */
     import_array();
+
     Py_INCREF(&CntrType);
     PyModule_AddObject(m, "Cntr", (PyObject *)&CntrType);
+
+    #if PY3K
+        return m;
+    #endif
 }
 
 
