@@ -1621,13 +1621,16 @@ FT2Font::get_glyph_name(const Py::Tuple & args)
 
     if (!FT_HAS_GLYPH_NAMES(face))
     {
-        snprintf(buffer, 128, "uni%04x", glyph_number);
+        /* Note that this generated name must match the name that
+           is generated by ttconv in ttfont_CharStrings_getname. */
+        PyOS_snprintf(buffer, 128, "uni%08x", glyph_number);
     } else {
         if (FT_Get_Glyph_Name(face, glyph_number, buffer, 128))
         {
             throw Py::RuntimeError("Could not get glyph names.");
         }
-    }
+     }
+
     return Py::String(buffer);
 }
 PYCXX_VARARGS_METHOD_DECL(FT2Font, get_glyph_name)
@@ -1744,9 +1747,10 @@ FT2Font::get_sfnt(const Py::Tuple & args)
         key[1] = Py::Int(sfnt.encoding_id);
         key[2] = Py::Int(sfnt.language_id);
         key[3] = Py::Int(sfnt.name_id);
-        names[key] = Py::String((char *) sfnt.string,
-                                (int) sfnt.string_len,
-                                "latin-1");
+
+        names[key] = Py::asObject
+            (PyBytes_FromStringAndSize(
+                (const char *)sfnt.string, sfnt.string_len));
     }
     return names;
 }
