@@ -21,14 +21,13 @@ extern "C"
 #include FT_TRUETYPE_TABLES_H
 }
 
-
 // the freetype string rendered into a width, height buffer
-class FT2Image : public Py::PythonExtension<FT2Image>
+class FT2Image : public Py::PythonClass<FT2Image>
 {
 public:
-    // FT2Image();
-    FT2Image(unsigned long width, unsigned long height);
-    ~FT2Image();
+    FT2Image(Py::PythonClassInstance *self, Py::Tuple &args, Py::Dict &kwds);
+    virtual ~FT2Image();
+    static Py::PythonClassObject<FT2Image> factory(int width, int height);
 
     static void init_type();
 
@@ -66,7 +65,6 @@ public:
     Py::Object py_as_rgb_str(const Py::Tuple & args);
     static char as_rgba_str__doc__ [];
     Py::Object py_as_rgba_str(const Py::Tuple & args);
-
     Py::Object py_get_width(const Py::Tuple & args);
     Py::Object py_get_height(const Py::Tuple & args);
 
@@ -75,35 +73,31 @@ private:
     unsigned char *_buffer;
     unsigned long _width;
     unsigned long _height;
-    FT2Image* _rgbCopy;
-    FT2Image* _rgbaCopy;
-
-    void makeRgbCopy();
-    void makeRgbaCopy();
 
     void resize(long width, long height);
 };
 
-
-class Glyph : public Py::PythonExtension<Glyph>
+class Glyph : public Py::PythonClass<Glyph>
 {
 public:
-    Glyph(const FT_Face&, const FT_Glyph&, size_t);
-    ~Glyph();
-    int setattr(const char *_name, const Py::Object &value);
-    Py::Object getattr(const char *_name);
+    Glyph(Py::PythonClassInstance *self, Py::Tuple &args, Py::Dict &kwds) :
+        Py::PythonClass<Glyph>::PythonClass(self, args, kwds) { }
+    virtual ~Glyph();
+    static Py::PythonClassObject<Glyph> factory(const FT_Face&, const FT_Glyph&, size_t, long);
+    int setattro(const Py::String &name, const Py::Object &value);
+    Py::Object getattro(const Py::String &name);
     static void init_type(void);
     size_t glyphInd;
 private:
     Py::Dict __dict__;
 };
 
-class FT2Font : public Py::PythonExtension<FT2Font>
+class FT2Font : public Py::PythonClass<FT2Font>
 {
 
 public:
-    FT2Font(std::string);
-    ~FT2Font();
+    FT2Font(Py::PythonClassInstance *self, Py::Tuple &args, Py::Dict &kwds);
+    virtual ~FT2Font();
     static void init_type(void);
     Py::Object clear(const Py::Tuple & args);
     Py::Object set_size(const Py::Tuple & args);
@@ -117,9 +111,9 @@ public:
     Py::Object get_width_height(const Py::Tuple & args);
     Py::Object get_descent(const Py::Tuple & args);
     Py::Object draw_rect_filled(const Py::Tuple & args);
-    Py::Object get_xys(const Py::Tuple & args);
-    Py::Object draw_glyphs_to_bitmap(const Py::Tuple & args);
-    Py::Object draw_glyph_to_bitmap(const Py::Tuple & args);
+    Py::Object get_xys(const Py::Tuple & args, const Py::Dict & kws);
+    Py::Object draw_glyphs_to_bitmap(const Py::Tuple & args, const Py::Dict & kws);
+    Py::Object draw_glyph_to_bitmap(const Py::Tuple & args, const Py::Dict & kws);
     Py::Object get_glyph_name(const Py::Tuple & args);
     Py::Object get_charmap(const Py::Tuple & args);
     Py::Object get_sfnt(const Py::Tuple & args);
@@ -128,10 +122,10 @@ public:
     Py::Object get_sfnt_table(const Py::Tuple & args);
     Py::Object get_image(const Py::Tuple & args);
     Py::Object attach_file(const Py::Tuple & args);
-    int setattr(const char *_name, const Py::Object &value);
-    Py::Object getattr(const char *_name);
+    int setattro(const Py::String &name, const Py::Object &value);
+    Py::Object getattro(const Py::String &name);
     Py::Object get_path();
-    FT2Image* image;
+    Py::Object image;
 
 private:
     Py::Dict __dict__;
@@ -144,7 +138,7 @@ private:
     double angle;
     double ptsize;
     double dpi;
-
+    long hinting_factor;
 
     FT_BBox compute_string_bbox();
     void set_scalable_attributes();
@@ -180,27 +174,8 @@ class ft2font_module : public Py::ExtensionModule<ft2font_module>
 
 {
 public:
-    ft2font_module()
-            : Py::ExtensionModule<ft2font_module>("ft2font")
-    {
-        FT2Image::init_type();
-        Glyph::init_type();
-        FT2Font::init_type();
-
-        add_varargs_method("FT2Font", &ft2font_module::new_ft2font,
-                           "FT2Font");
-        add_varargs_method("FT2Image", &ft2font_module::new_ft2image,
-                           "FT2Image");
-        initialize("The ft2font module");
-    }
-
-    ~ft2font_module();
-    //static FT_Library ft2Library;
-
-private:
-
-    Py::Object new_ft2font(const Py::Tuple &args);
-    Py::Object new_ft2image(const Py::Tuple &args);
+    ft2font_module();
+    virtual ~ft2font_module();
 };
 
 #endif
