@@ -1,3 +1,5 @@
+/* -*- mode: c; c-basic-offset: 4 -*- */
+
 #include <Python.h>
 #include "structmember.h"
 #include <stdlib.h>
@@ -24,8 +26,8 @@ int pnpoly_api(int npol, double *xp, double *yp, double x, double y)
   int i, j, c = 0;
   for (i = 0, j = npol-1; i < npol; j = i++) {
     if ((((yp[i]<=y) && (y<yp[j])) ||
-	 ((yp[j]<=y) && (y<yp[i]))) &&
-	(x < (xp[j] - xp[i]) * (y - yp[i]) / (yp[j] - yp[i]) + xp[i]))
+         ((yp[j]<=y) && (y<yp[i]))) &&
+        (x < (xp[j] - xp[i]) * (y - yp[i]) / (yp[j] - yp[i]) + xp[i]))
 
       c = !c;
   }
@@ -50,7 +52,7 @@ pnpoly(PyObject *self, PyObject *args)
   if (verts == NULL)
     {
       PyErr_SetString(PyExc_ValueError,
-		      "Arguments verts must be a Nx2 array.");
+                      "Arguments verts must be a Nx2 array.");
       Py_XDECREF(verts);
       return NULL;
 
@@ -61,7 +63,7 @@ pnpoly(PyObject *self, PyObject *args)
   if (verts->dimensions[1]!=2)
     {
       PyErr_SetString(PyExc_ValueError,
-		      "Arguments verts must be a Nx2 array.");
+                      "Arguments verts must be a Nx2 array.");
       Py_XDECREF(verts);
       return NULL;
 
@@ -118,7 +120,7 @@ points_inside_poly(PyObject *self, PyObject *args)
   if (verts == NULL)
     {
       PyErr_SetString(PyExc_ValueError,
-		      "Argument verts must be a Nx2 array.");
+                      "Argument verts must be a Nx2 array.");
       Py_XDECREF(verts);
       return NULL;
 
@@ -129,7 +131,7 @@ points_inside_poly(PyObject *self, PyObject *args)
   if (verts->dimensions[1]!=2)
     {
       PyErr_SetString(PyExc_ValueError,
-		      "Arguments verts must be a Nx2 array.");
+                      "Arguments verts must be a Nx2 array.");
       Py_XDECREF(verts);
       return NULL;
 
@@ -163,7 +165,7 @@ points_inside_poly(PyObject *self, PyObject *args)
   if (xypoints == NULL)
     {
       PyErr_SetString(PyExc_ValueError,
-		      "Arguments xypoints must an Nx2 array.");
+                      "Arguments xypoints must an Nx2 array.");
       Py_XDECREF(verts);
       Py_XDECREF(xypoints);
       PyMem_Free(xv);
@@ -175,7 +177,7 @@ points_inside_poly(PyObject *self, PyObject *args)
   if (xypoints->dimensions[1]!=2)
     {
       PyErr_SetString(PyExc_ValueError,
-		      "Arguments xypoints must be a Nx2 array.");
+                      "Arguments xypoints must be a Nx2 array.");
 
       Py_XDECREF(verts);
       Py_XDECREF(xypoints);
@@ -229,14 +231,14 @@ static PyMethodDef module_methods[] = {
         "Return a boolean ndarray, True for points inside the polygon.\n\n"
         "*xypoints*\n    a sequence of N x,y pairs.\n"
         "*xyverts*\n    sequence of x,y vertices of the polygon.\n"
-        "*mask*    an ndarray of length N.\n\n"
+        "*mask*\n   an ndarray of length N.\n\n"
         "A point on the boundary may be treated as inside or outside.\n"
         "See `pnpoly <http://www.ecse.rpi.edu/Homepages/wrf/Research/Short_Notes/pnpoly.html>`_\n"},
   {NULL}  /* Sentinel */
 };
 
 PyMODINIT_FUNC
-     initnxutils(void)
+initnxutils(void)
 {
   PyObject* m;
 
