@@ -31,6 +31,7 @@
 #include "pprdrv.h"
 #include "truetype.h"
 #include <sstream>
+#include <Python.h>
 
 /*==========================================================================
 ** Convert the indicated Truetype font file to a type 42 or type 3
@@ -166,6 +167,13 @@ BYTE *GetTable(struct TTFONT *font, const char *name)
 
 } /* end of GetTable() */
 
+static void utf16be_to_ascii(char *dst, char *src, size_t length) {
+    ++src;
+    for (; *src != 0 && length; dst++, src += 2, --length) {
+        *dst = *src;
+    }
+}
+
 /*--------------------------------------------------------------------
 ** Load the 'name' table, get information from it,
 ** and store that information in the font structure.
@@ -311,6 +319,21 @@ void Read_name(struct TTFONT *font)
                 font->PostName[length]=(char)NULL;
                 replace_newlines_with_spaces(font->PostName);
 
+#ifdef DEBUG_TRUETYPE
+                debug("font->PostName=\"%s\"",font->PostName);
+#endif
+                continue;
+            }
+
+            /* Microsoft-format PostScript name */
+            if ( platform == 3 && nameid == 6 )
+            {
+                free(font->PostName);
+                font->PostName = (char*)calloc(sizeof(char),length+1);
+                utf16be_to_ascii(font->PostName, (char *)strings+offset, length);
+                font->PostName[length/2]=(char)NULL;
+                replace_newlines_with_spaces(font->PostName);
+
 #ifdef DEBUG_TRUETYPE
                 debug("font->PostName=\"%s\"",font->PostName);
 #endif
@@ -967,6 +990,20 @@ const char *ttfont_CharStrings_getname(struct TTFONT *font, int charindex)
     char *ptr;
     ULONG len;
 
+    Fixed post_format;
+
+    /* The 'post' table format number. */
+    post_format = getFixed( font->post_table );
+
+    if ( post_format.whole != 2 || post_format.fraction != 0 )
+    {
+        /* We don't have a glyph name table, so generate a name.
+           This generated name must match exactly the name that is
+           generated by FT2Font in get_glyph_name */
+        PyOS_snprintf(temp, 80, "uni%08x", charindex);
+        return temp;
+    }
+
     GlyphIndex = (int)getUSHORT( font->post_table + 34 + (charindex * 2) );
 
     if ( GlyphIndex <= 257 )            /* If a standard Apple name, */
@@ -1011,11 +1048,6 @@ void ttfont_CharStrings(TTStreamWriter& stream, struct TTFONT *font, std::vector
     /* The 'post' table format number. */
     post_format = getFixed( font->post_table );
 
-    if ( post_format.whole != 2 || post_format.fraction != 0 )
-    {
-        throw TTException("TrueType fontdoes not have a format 2.0 'post' table");
-    }
-
     /* Emmit the start of the PostScript code to define the dictionary. */
     stream.printf("/CharStrings %d dict dup begin\n", glyph_ids.size());
 
